(function (factory) {
    typeof define === 'function' && define.amd ? define(factory) :
    factory();
}((function () { 'use strict';

    function invariant(condition, message, Err = Error) {
        if (!condition) {
            throw new Err(message);
        }
    }

    /**
     * https://tc39.es/ecma262/#sec-toobject
     * @param arg
     */
    function toObject(arg) {
        if (arg == null) {
            throw new TypeError('undefined/null cannot be converted to object');
        }
        return Object(arg);
    }
    /**
     * https://tc39.es/ecma262/#sec-tostring
     */
    function toString(o) {
        // Only symbol is irregular...
        if (typeof o === 'symbol') {
            throw TypeError('Cannot convert a Symbol value to a string');
        }
        return String(o);
    }
    /**
     * https://tc39.es/ecma402/#sec-getoption
     * @param opts
     * @param prop
     * @param type
     * @param values
     * @param fallback
     */
    function getOption(opts, prop, type, values, fallback) {
        // const descriptor = Object.getOwnPropertyDescriptor(opts, prop);
        let value = opts[prop];
        if (value !== undefined) {
            if (type !== 'boolean' && type !== 'string') {
                throw new TypeError('invalid type');
            }
            if (type === 'boolean') {
                value = Boolean(value);
            }
            if (type === 'string') {
                value = toString(value);
            }
            if (values !== undefined && !values.filter(val => val == value).length) {
                throw new RangeError(`${value} is not within ${values.join(', ')}`);
            }
            return value;
        }
        return fallback;
    }
    function setInternalSlot(map, pl, field, value) {
        if (!map.get(pl)) {
            map.set(pl, Object.create(null));
        }
        const slots = map.get(pl);
        slots[field] = value;
    }
    function getInternalSlot(map, pl, field) {
        return getMultiInternalSlots(map, pl, field)[field];
    }
    function getMultiInternalSlots(map, pl, ...fields) {
        const slots = map.get(pl);
        if (!slots) {
            throw new TypeError(`${pl} InternalSlot has not been initialized`);
        }
        return fields.reduce((all, f) => {
            all[f] = slots[f];
            return all;
        }, Object.create(null));
    }
    const NOT_A_Z_REGEX = /[^A-Z]/;
    /**
     * This follows https://tc39.es/ecma402/#sec-case-sensitivity-and-case-mapping
     * @param str string to convert
     */
    function toUpperCase(str) {
        return str.replace(/([a-z])/g, (_, c) => c.toUpperCase());
    }
    /**
     * https://tc39.es/proposal-unified-intl-numberformat/section6/locales-currencies-tz_proposed_out.html#sec-iswellformedcurrencycode
     * @param currency
     */
    function isWellFormedCurrencyCode(currency) {
        currency = toUpperCase(currency);
        if (currency.length !== 3) {
            return false;
        }
        if (NOT_A_Z_REGEX.test(currency)) {
            return false;
        }
        return true;
    }

    /**
     * IE11-safe version of getCanonicalLocales since it's ES2016
     * @param locales locales
     */
    function getCanonicalLocales(locales) {
        // IE11
        const { getCanonicalLocales } = Intl;
        if (typeof getCanonicalLocales === 'function') {
            return getCanonicalLocales(locales);
        }
        // NOTE: we must NOT call `supportedLocalesOf` of a formatjs polyfill, or their implementation
        // will even eventually call this method recursively. Here we use `Intl.DateTimeFormat` since it
        // is not polyfilled by `@formatjs`.
        // TODO: Fix TypeScript type def for this bc undefined is just fine
        return Intl.DateTimeFormat.supportedLocalesOf(locales);
    }

    function createResolveLocale(getDefaultLocale) {
        const lookupMatcher = createLookupMatcher(getDefaultLocale);
        const bestFitMatcher = createBestFitMatcher(getDefaultLocale);
        /**
         * https://tc39.es/ecma402/#sec-resolvelocale
         */
        return function resolveLocale(availableLocales, requestedLocales, options, relevantExtensionKeys, localeData) {
            const matcher = options.localeMatcher;
            let r;
            if (matcher === 'lookup') {
                r = lookupMatcher(availableLocales, requestedLocales);
            }
            else {
                r = bestFitMatcher(availableLocales, requestedLocales);
            }
            let foundLocale = r.locale;
            const result = { locale: '', dataLocale: foundLocale };
            let supportedExtension = '-u';
            for (const key of relevantExtensionKeys) {
                const foundLocaleData = localeData[foundLocale];
                invariant(typeof foundLocaleData === 'object' && foundLocaleData !== null, `locale data ${key} must be an object`);
                const keyLocaleData = foundLocaleData[key];
                invariant(Array.isArray(keyLocaleData), `keyLocaleData for ${key} must be an array`);
                let value = keyLocaleData[0];
                invariant(typeof value === 'string' || value === null, 'value must be string or null');
                let supportedExtensionAddition = '';
                if (r.extension) {
                    const requestedValue = unicodeExtensionValue(r.extension, key);
                    if (requestedValue !== undefined) {
                        if (requestedValue !== '') {
                            if (~keyLocaleData.indexOf(requestedValue)) {
                                value = requestedValue;
                                supportedExtensionAddition = `-${key}-${value}`;
                            }
                        }
                        else if (~requestedValue.indexOf('true')) {
                            value = 'true';
                            supportedExtensionAddition = `-${key}`;
                        }
                    }
                }
                if (key in options) {
                    const optionsValue = options[key];
                    invariant(typeof optionsValue === 'string' ||
                        typeof optionsValue === 'undefined' ||
                        optionsValue === null, 'optionsValue must be String, Undefined or Null');
                    if (~keyLocaleData.indexOf(optionsValue)) {
                        if (optionsValue !== value) {
                            value = optionsValue;
                            supportedExtensionAddition = '';
                        }
                    }
                }
                result[key] = value;
                supportedExtension += supportedExtensionAddition;
            }
            if (supportedExtension.length > 2) {
                const privateIndex = foundLocale.indexOf('-x-');
                if (privateIndex === -1) {
                    foundLocale = foundLocale + supportedExtension;
                }
                else {
                    const preExtension = foundLocale.slice(0, privateIndex);
                    const postExtension = foundLocale.slice(privateIndex, foundLocale.length);
                    foundLocale = preExtension + supportedExtension + postExtension;
                }
                foundLocale = getCanonicalLocales(foundLocale)[0];
            }
            result.locale = foundLocale;
            return result;
        };
    }
    /**
     * https://tc39.es/ecma402/#sec-unicodeextensionvalue
     * @param extension
     * @param key
     */
    function unicodeExtensionValue(extension, key) {
        invariant(key.length === 2, 'key must have 2 elements');
        const size = extension.length;
        let searchValue = `-${key}-`;
        let pos = extension.indexOf(searchValue);
        if (pos !== -1) {
            const start = pos + 4;
            let end = start;
            let k = start;
            let done = false;
            while (!done) {
                const e = extension.indexOf('-', k);
                let len;
                if (e === -1) {
                    len = size - k;
                }
                else {
                    len = e - k;
                }
                if (len === 2) {
                    done = true;
                }
                else if (e === -1) {
                    end = size;
                    done = true;
                }
                else {
                    end = e;
                    k = e + 1;
                }
            }
            return extension.slice(start, end);
        }
        searchValue = `-${key}`;
        pos = extension.indexOf(searchValue);
        if (pos !== -1 && pos + 3 === size) {
            return '';
        }
        return undefined;
    }
    const UNICODE_EXTENSION_SEQUENCE_REGEX = /-u(?:-[0-9a-z]{2,8})+/gi;
    /**
     * https://tc39.es/ecma402/#sec-bestavailablelocale
     * @param availableLocales
     * @param locale
     */
    function bestAvailableLocale(availableLocales, locale) {
        let candidate = locale;
        while (true) {
            if (~availableLocales.indexOf(candidate)) {
                return candidate;
            }
            let pos = candidate.lastIndexOf('-');
            if (!~pos) {
                return undefined;
            }
            if (pos >= 2 && candidate[pos - 2] === '-') {
                pos -= 2;
            }
            candidate = candidate.slice(0, pos);
        }
    }
    function createLookupMatcher(getDefaultLocale) {
        /**
         * https://tc39.es/ecma402/#sec-lookupmatcher
         */
        return function lookupMatcher(availableLocales, requestedLocales) {
            const result = { locale: '' };
            for (const locale of requestedLocales) {
                const noExtensionLocale = locale.replace(UNICODE_EXTENSION_SEQUENCE_REGEX, '');
                const availableLocale = bestAvailableLocale(availableLocales, noExtensionLocale);
                if (availableLocale) {
                    result.locale = availableLocale;
                    if (locale !== noExtensionLocale) {
                        result.extension = locale.slice(noExtensionLocale.length + 1, locale.length);
                    }
                    return result;
                }
            }
            result.locale = getDefaultLocale();
            return result;
        };
    }
    function createBestFitMatcher(getDefaultLocale) {
        return function bestFitMatcher(availableLocales, requestedLocales) {
            const result = { locale: '' };
            for (const locale of requestedLocales) {
                const noExtensionLocale = locale.replace(UNICODE_EXTENSION_SEQUENCE_REGEX, '');
                const availableLocale = bestAvailableLocale(availableLocales, noExtensionLocale);
                if (availableLocale) {
                    result.locale = availableLocale;
                    if (locale !== noExtensionLocale) {
                        result.extension = locale.slice(noExtensionLocale.length + 1, locale.length);
                    }
                    return result;
                }
            }
            result.locale = getDefaultLocale();
            return result;
        };
    }
    function getLocaleHierarchy(locale, aliases, parentLocales) {
        const results = [locale];
        if (aliases[locale]) {
            locale = aliases[locale];
            results.push(locale);
        }
        const parentLocale = parentLocales[locale];
        if (parentLocale) {
            results.push(parentLocale);
        }
        const localeParts = locale.split('-');
        for (let i = localeParts.length; i > 1; i--) {
            results.push(localeParts.slice(0, i - 1).join('-'));
        }
        return results;
    }
    function lookupSupportedLocales(availableLocales, requestedLocales) {
        const subset = [];
        for (const locale of requestedLocales) {
            const noExtensionLocale = locale.replace(UNICODE_EXTENSION_SEQUENCE_REGEX, '');
            const availableLocale = bestAvailableLocale(availableLocales, noExtensionLocale);
            if (availableLocale) {
                subset.push(availableLocale);
            }
        }
        return subset;
    }
    function supportedLocales(availableLocales, requestedLocales, options) {
        let matcher = 'best fit';
        if (options !== undefined) {
            options = toObject(options);
            matcher = getOption(options, 'localeMatcher', 'string', ['lookup', 'best fit'], 'best fit');
        }
        if (matcher === 'best fit') {
            return lookupSupportedLocales(availableLocales, requestedLocales);
        }
        return lookupSupportedLocales(availableLocales, requestedLocales);
    }
    class MissingLocaleDataError extends Error {
        constructor() {
            super(...arguments);
            this.type = 'MISSING_LOCALE_DATA';
        }
    }
    function unpackData(locale, localeData, 
    /** By default shallow merge the dictionaries. */
    reducer = (all, d) => (Object.assign(Object.assign({}, all), d))) {
        const localeHierarchy = getLocaleHierarchy(locale, localeData.aliases, localeData.parentLocales);
        const dataToMerge = localeHierarchy
            .map(l => localeData.data[l])
            .filter(Boolean);
        if (!dataToMerge.length) {
            throw new MissingLocaleDataError(`Missing locale data for "${locale}", lookup hierarchy: ${localeHierarchy.join(', ')}`);
        }
        dataToMerge.reverse();
        return dataToMerge.reduce(reducer, {});
    }

    class DisplayNames {
        constructor(locales, options = Object.create(null)) {
            if (new.target === undefined) {
                throw TypeError(`Constructor Intl.DisplayNames requires 'new'`);
            }
            const requestedLocales = getCanonicalLocales(locales);
            const matcher = getOption(options, 'localeMatcher', 'string', ['lookup', 'best fit'], 'best fit');
            const r = createResolveLocale(DisplayNames.getDefaultLocale)(DisplayNames.availableLocales, requestedLocales, { localeMatcher: matcher }, [], // there is no relevantExtensionKeys
            DisplayNames.localeData);
            const style = getOption(options, 'style', 'string', ['narrow', 'short', 'long'], 'long');
            setSlot(this, 'style', style);
            const type = getOption(options, 'type', 'string', ['language', 'currency', 'region', 'script'], 'language');
            setSlot(this, 'type', type);
            const fallback = getOption(options, 'fallback', 'string', ['code', 'none'], 'code');
            setSlot(this, 'fallback', fallback);
            setSlot(this, 'locale', r.locale);
            const { dataLocale } = r;
            const dataLocaleData = DisplayNames.localeData[dataLocale];
            invariant(dataLocaleData !== undefined, `locale data for ${r.locale} does not exist.`);
            setSlot(this, 'localeData', dataLocaleData);
        }
        static supportedLocalesOf(locales, options) {
            return supportedLocales(DisplayNames.availableLocales, getCanonicalLocales(locales), options);
        }
        static __addLocaleData(...data) {
            for (const datum of data) {
                const availableLocales = Object.keys([
                    ...datum.availableLocales,
                    ...Object.keys(datum.aliases),
                    ...Object.keys(datum.parentLocales),
                ].reduce((all, k) => {
                    all[k] = true;
                    return all;
                }, {}));
                for (const locale of availableLocales) {
                    try {
                        DisplayNames.localeData[locale] = unpackData(locale, datum);
                    }
                    catch (e) {
                        // If we can't unpack this data, ignore the locale
                    }
                }
            }
            DisplayNames.availableLocales = Object.keys(DisplayNames.localeData);
            if (!DisplayNames.__defaultLocale) {
                DisplayNames.__defaultLocale = DisplayNames.availableLocales[0];
            }
        }
        of(code) {
            checkReceiver(this, 'of');
            const type = getSlot(this, 'type');
            const codeAsString = toString(code);
            if (!isValidCodeForDisplayNames(type, codeAsString)) {
                throw RangeError('invalid code for Intl.DisplayNames.prototype.of');
            }
            const { localeData, style, fallback } = getMultiInternalSlots(__INTERNAL_SLOT_MAP__, this, 'localeData', 'style', 'fallback');
            // Canonicalize the case.
            let canonicalCode;
            // This is only used to store extracted language region.
            let regionSubTag;
            switch (type) {
                // Normalize the locale id and remove the region.
                case 'language': {
                    canonicalCode = getCanonicalLocales(codeAsString)[0];
                    const regionMatch = /-([a-z]{2}|\d{3})\b/i.exec(canonicalCode);
                    if (regionMatch) {
                        // Remove region subtag
                        canonicalCode =
                            canonicalCode.substring(0, regionMatch.index) +
                                canonicalCode.substring(regionMatch.index + regionMatch[0].length);
                        regionSubTag = regionMatch[1];
                    }
                    break;
                }
                // currency code should be all upper-case.
                case 'currency':
                    canonicalCode = codeAsString.toUpperCase();
                    break;
                // script code should be title case
                case 'script':
                    canonicalCode =
                        codeAsString[0] + codeAsString.substring(1).toLowerCase();
                    break;
                // region shold be all upper-case
                case 'region':
                    canonicalCode = codeAsString.toUpperCase();
                    break;
            }
            const typesData = localeData.types[type];
            // If the style of choice does not exist, fallback to "long".
            const name = typesData[style][canonicalCode] || typesData.long[canonicalCode];
            if (name !== undefined) {
                // If there is a region subtag in the language id, use locale pattern to interpolate the region
                if (regionSubTag) {
                    // Retrieve region display names
                    const regionsData = localeData.types.region;
                    const regionDisplayName = regionsData[style][regionSubTag] || regionsData.long[regionSubTag];
                    if (regionDisplayName || fallback === 'code') {
                        // Interpolate into locale-specific pattern.
                        const pattern = localeData.patterns.locale;
                        return pattern
                            .replace('{0}', name)
                            .replace('{1}', regionDisplayName || regionSubTag);
                    }
                }
                else {
                    return name;
                }
            }
            if (fallback === 'code') {
                return codeAsString;
            }
        }
        resolvedOptions() {
            checkReceiver(this, 'resolvedOptions');
            return Object.assign({}, getMultiInternalSlots(__INTERNAL_SLOT_MAP__, this, 'locale', 'style', 'type', 'fallback'));
        }
        static getDefaultLocale() {
            return DisplayNames.__defaultLocale;
        }
    }
    DisplayNames.localeData = {};
    DisplayNames.availableLocales = [];
    DisplayNames.__defaultLocale = 'en';
    DisplayNames.polyfilled = true;
    // https://tc39.es/proposal-intl-displaynames/#sec-isvalidcodefordisplaynames
    function isValidCodeForDisplayNames(type, code) {
        switch (type) {
            case 'language':
                // subset of unicode_language_id
                // languageCode ["-" scriptCode] ["-" regionCode] *("-" variant)
                // where:
                // - languageCode is either a two letters ISO 639-1 language code or a three letters ISO 639-2 language code.
                // - scriptCode is should be an ISO-15924 four letters script code
                // - regionCode is either an ISO-3166 two letters region code, or a three digits UN M49 Geographic Regions.
                return /^[a-z]{2,3}(-[a-z]{4})?(-([a-z]{2}|\d{3}))?(-([a-z\d]{5,8}|\d[a-z\d]{3}))*$/i.test(code);
            case 'region':
                // unicode_region_subtag
                return /^([a-z]{2}|\d{3})$/i.test(code);
            case 'script':
                // unicode_script_subtag
                return /^[a-z]{4}$/i.test(code);
            case 'currency':
                return isWellFormedCurrencyCode(code);
        }
    }
    try {
        // IE11 does not have Symbol
        if (typeof Symbol !== 'undefined' && Symbol.toStringTag) {
            Object.defineProperty(DisplayNames.prototype, Symbol.toStringTag, {
                value: 'Intl.DisplayNames',
                configurable: true,
                enumerable: false,
                writable: false,
            });
        }
        Object.defineProperty(DisplayNames, 'length', {
            value: 0,
            writable: false,
            enumerable: false,
            configurable: true,
        });
    }
    catch (e) {
        // Make test 262 compliant
    }
    const __INTERNAL_SLOT_MAP__ = new WeakMap();
    function getSlot(instance, key) {
        return getInternalSlot(__INTERNAL_SLOT_MAP__, instance, key);
    }
    function setSlot(instance, key, value) {
        setInternalSlot(__INTERNAL_SLOT_MAP__, instance, key, value);
    }
    function checkReceiver(receiver, methodName) {
        if (!(receiver instanceof DisplayNames)) {
            throw TypeError(`Method Intl.DisplayNames.prototype.${methodName} called on incompatible receiver`);
        }
    }

    if (!Intl.DisplayNames) {
        Object.defineProperty(Intl, 'DisplayNames', {
            value: DisplayNames,
            enumerable: false,
            writable: true,
            configurable: true,
        });
    }

    if (Intl.DisplayNames && typeof Intl.DisplayNames.__addLocaleData === 'function') {
      Intl.DisplayNames.__addLocaleData(
        {"data":{"ar":{"types":{"language":{"long":{"aa":"الأفارية","ab":"الأبخازية","ace":"الأتشينيزية","ach":"الأكولية","ada":"الأدانجمية","ady":"الأديغة","ae":"الأفستية","af":"الأفريقانية","afh":"الأفريهيلية","agq":"الأغم","ain":"الآينوية","ak":"الأكانية","akk":"الأكادية","ale":"الأليوتية","alt":"الألطائية الجنوبية","am":"الأمهرية","an":"الأراغونية","ang":"الإنجليزية القديمة","anp":"الأنجيكا","ar":"العربية","ar-001":"العربية الفصحى الحديثة","arc":"الآرامية","arn":"المابودونغونية","arp":"الأراباهو","ars":"اللهجة النجدية","arw":"الأراواكية","as":"الأسامية","asa":"الآسو","ast":"الأسترية","av":"الأوارية","awa":"الأوادية","ay":"الأيمارا","az":"الأذربيجانية","ba":"الباشكيرية","bal":"البلوشية","ban":"البالينية","bas":"الباسا","bax":"بامن","bbj":"لغة الغومالا","be":"البيلاروسية","bej":"البيجا","bem":"البيمبا","bez":"بينا","bfd":"لغة البافوت","bg":"البلغارية","bgn":"البلوشية الغربية","bho":"البهوجبورية","bi":"البيسلامية","bik":"البيكولية","bin":"البينية","bkm":"لغة الكوم","bla":"السيكسيكية","bm":"البامبارا","bn":"البنغالية","bo":"التبتية","br":"البريتونية","bra":"البراجية","brx":"البودو","bs":"البوسنية","bss":"أكوس","bua":"البرياتية","bug":"البجينيزية","bum":"لغة البولو","byn":"البلينية","byv":"لغة الميدومبا","ca":"الكتالانية","cad":"الكادو","car":"الكاريبية","cay":"الكايوجية","cch":"الأتسام","ccp":"تشاكما","ce":"الشيشانية","ceb":"السيبيوانية","cgg":"تشيغا","ch":"التشامورو","chb":"التشيبشا","chg":"التشاجاتاي","chk":"التشكيزية","chm":"الماري","chn":"الشينوك جارجون","cho":"الشوكتو","chp":"الشيباوايان","chr":"الشيروكي","chy":"الشايان","ckb":"السورانية الكردية","co":"الكورسيكية","cop":"القبطية","cr":"الكرى","crh":"لغة تتار القرم","crs":"الفرنسية الكريولية السيشيلية","cs":"التشيكية","csb":"الكاشبايان","cu":"سلافية كنسية","cv":"التشوفاشي","cy":"الويلزية","da":"الدانمركية","dak":"الداكوتا","dar":"الدارجوا","dav":"تيتا","de":"الألمانية","de-AT":"الألمانية النمساوية","de-CH":"الألمانية العليا السويسرية","del":"الديلوير","den":"السلافية","dgr":"الدوجريب","din":"الدنكا","dje":"الزارمية","doi":"الدوجرية","dsb":"صوربيا السفلى","dua":"الديولا","dum":"الهولندية الوسطى","dv":"المالديفية","dyo":"جولا فونيا","dyu":"الدايلا","dz":"الزونخاية","dzg":"القرعانية","ebu":"إمبو","ee":"الإيوي","efi":"الإفيك","egy":"المصرية القديمة","eka":"الإكاجك","el":"اليونانية","elx":"الإمايت","en":"الإنجليزية","en-AU":"الإنجليزية الأسترالية","en-CA":"الإنجليزية الكندية","en-GB":"الإنجليزية البريطانية","en-US":"الإنجليزية الأمريكية","enm":"الإنجليزية الوسطى","eo":"الإسبرانتو","es":"الإسبانية","es-419":"الإسبانية أمريكا اللاتينية","es-ES":"الإسبانية الأوروبية","es-MX":"الإسبانية المكسيكية","et":"الإستونية","eu":"الباسكية","ewo":"الإيوندو","fa":"الفارسية","fan":"الفانج","fat":"الفانتي","ff":"الفولانية","fi":"الفنلندية","fil":"الفلبينية","fj":"الفيجية","fo":"الفاروية","fon":"الفون","fr":"الفرنسية","fr-CA":"الفرنسية الكندية","fr-CH":"الفرنسية السويسرية","frc":"الفرنسية الكاجونية","frm":"الفرنسية الوسطى","fro":"الفرنسية القديمة","frr":"الفريزينية الشمالية","frs":"الفريزينية الشرقية","fur":"الفريلايان","fy":"الفريزيان","ga":"الأيرلندية","gaa":"الجا","gag":"الغاغوز","gan":"الغان الصينية","gay":"الجايو","gba":"الجبيا","gd":"الغيلية الأسكتلندية","gez":"الجعزية","gil":"لغة أهل جبل طارق","gl":"الجاليكية","gmh":"الألمانية العليا الوسطى","gn":"الغوارانية","goh":"الألمانية العليا القديمة","gon":"الجندي","gor":"الجورونتالو","got":"القوطية","grb":"الجريبو","grc":"اليونانية القديمة","gsw":"الألمانية السويسرية","gu":"الغوجاراتية","guz":"الغيزية","gv":"المنكية","gwi":"غوتشن","ha":"الهوسا","hai":"الهيدا","hak":"الهاكا الصينية","haw":"لغة هاواي","he":"العبرية","hi":"الهندية","hil":"الهيليجينون","hit":"الحثية","hmn":"الهمونجية","ho":"الهيري موتو","hr":"الكرواتية","hsb":"الصوربية العليا","hsn":"شيانغ الصينية","ht":"الكريولية الهايتية","hu":"الهنغارية","hup":"الهبا","hy":"الأرمنية","hz":"الهيريرو","ia":"اللّغة الوسيطة","iba":"الإيبان","ibb":"الإيبيبيو","id":"الإندونيسية","ie":"الإنترلينج","ig":"الإيجبو","ii":"السيتشيون يي","ik":"الإينبياك","ilo":"الإيلوكو","inh":"الإنجوشية","io":"الإيدو","is":"الأيسلندية","it":"الإيطالية","iu":"الإينكتيتت","ja":"اليابانية","jbo":"اللوجبان","jgo":"نغومبا","jmc":"الماتشامية","jpr":"الفارسية اليهودية","jrb":"العربية اليهودية","jv":"الجاوية","ka":"الجورجية","kaa":"الكارا-كالباك","kab":"القبيلية","kac":"الكاتشين","kaj":"الجو","kam":"الكامبا","kaw":"الكوي","kbd":"الكاباردايان","kbl":"كانمبو","kcg":"التايابية","kde":"ماكونده","kea":"كابوفيرديانو","kfo":"الكورو","kg":"الكونغو","kha":"الكازية","kho":"الخوتانيز","khq":"كويرا تشيني","ki":"الكيكيو","kj":"الكيونياما","kk":"الكازاخستانية","kkj":"لغة الكاكو","kl":"الكالاليست","kln":"كالينجين","km":"الخميرية","kmb":"الكيمبندو","kn":"الكانادا","ko":"الكورية","koi":"كومي-بيرماياك","kok":"الكونكانية","kos":"الكوسراين","kpe":"الكبيل","kr":"الكانوري","krc":"الكاراتشاي-بالكار","krl":"الكاريلية","kru":"الكوروخ","ks":"الكشميرية","ksb":"شامبالا","ksf":"لغة البافيا","ksh":"لغة الكولونيان","ku":"الكردية","kum":"القموقية","kut":"الكتيناي","kv":"الكومي","kw":"الكورنية","ky":"القيرغيزية","la":"اللاتينية","lad":"اللادينو","lag":"لانجي","lah":"اللاهندا","lam":"اللامبا","lb":"اللكسمبورغية","lez":"الليزجية","lg":"الغاندا","li":"الليمبورغية","lkt":"لاكوتا","ln":"اللينجالا","lo":"اللاوية","lol":"منغولى","lou":"الكريولية اللويزيانية","loz":"اللوزي","lrc":"اللرية الشمالية","lt":"الليتوانية","lu":"اللوبا كاتانغا","lua":"اللبا-لؤلؤ","lui":"اللوسينو","lun":"اللوندا","luo":"اللو","lus":"الميزو","luy":"لغة اللويا","lv":"اللاتفية","mad":"المادريز","mag":"الماجا","mai":"المايثيلي","mak":"الماكاسار","man":"الماندينغ","mas":"الماساي","mde":"مابا","mdf":"الموكشا","mdr":"الماندار","men":"الميند","mer":"الميرو","mfe":"المورسيانية","mg":"الملغاشي","mga":"الأيرلندية الوسطى","mgh":"ماخاوا-ميتو","mgo":"ميتا","mh":"المارشالية","mi":"الماورية","mic":"الميكماكيونية","min":"المينانجكاباو","mk":"المقدونية","ml":"المالايالامية","mn":"المنغولية","mnc":"المانشو","mni":"المانيبورية","moh":"الموهوك","mos":"الموسي","mr":"الماراثية","ms":"الماليزية","mt":"المالطية","mua":"مندنج","mul":"لغات متعددة","mus":"الكريك","mwl":"الميرانديز","mwr":"الماروارية","my":"البورمية","myv":"الأرزية","mzn":"المازندرانية","na":"النورو","nan":"مين-نان الصينية","nap":"النابولية","naq":"لغة الناما","nb":"النرويجية بوكمال","nd":"النديبيل الشمالية","nds":"الألمانية السفلى","nds-NL":"السكسونية السفلى","ne":"النيبالية","new":"النوارية","ng":"الندونجا","nia":"النياس","niu":"النيوي","nl":"الهولندية","nl-BE":"الفلمنكية","nmg":"كواسيو","nn":"النرويجية نينورسك","nnh":"لغة النجيمبون","no":"النرويجية","nog":"النوجاي","non":"النورس القديم","nqo":"أنكو","nr":"النديبيل الجنوبي","nso":"السوتو الشمالية","nus":"النوير","nv":"النافاجو","nwc":"النوارية التقليدية","ny":"النيانجا","nym":"النيامويزي","nyn":"النيانكول","nyo":"النيورو","nzi":"النزيما","oc":"الأوكسيتانية","oj":"الأوجيبوا","om":"الأورومية","or":"الأورية","os":"الأوسيتيك","osa":"الأوساج","ota":"التركية العثمانية","pa":"البنجابية","pag":"البانجاسينان","pal":"البهلوية","pam":"البامبانجا","pap":"البابيامينتو","pau":"البالوان","pcm":"البدجنية النيجيرية","peo":"الفارسية القديمة","phn":"الفينيقية","pi":"البالية","pl":"البولندية","pon":"البوهنبيايان","prg":"البروسياوية","pro":"البروفانسية القديمة","ps":"البشتو","pt":"البرتغالية","pt-BR":"البرتغالية البرازيلية","pt-PT":"البرتغالية الأوروبية","qu":"الكويتشوا","quc":"الكيشية","raj":"الراجاسثانية","rap":"الراباني","rar":"الراروتونجاني","rm":"الرومانشية","rn":"الرندي","ro":"الرومانية","ro-MD":"المولدوفية","rof":"الرومبو","rom":"الغجرية","root":"الجذر","ru":"الروسية","rup":"الأرومانيان","rw":"الكينيارواندا","rwk":"الروا","sa":"السنسكريتية","sad":"السانداوي","sah":"الساخيّة","sam":"الآرامية السامرية","saq":"سامبورو","sas":"الساساك","sat":"السانتالية","sba":"نامبي","sbp":"سانغو","sc":"السردينية","scn":"الصقلية","sco":"الأسكتلندية","sd":"السندية","sdh":"الكردية الجنوبية","se":"سامي الشمالية","see":"السنيكا","seh":"سينا","sel":"السيلكب","ses":"كويرابورو سيني","sg":"السانجو","sga":"الأيرلندية القديمة","sh":"صربية-كرواتية","shi":"تشلحيت","shn":"الشان","shu":"العربية التشادية","si":"السنهالية","sid":"السيدامو","sk":"السلوفاكية","sl":"السلوفانية","sm":"الساموائية","sma":"السامي الجنوبي","smj":"اللول سامي","smn":"الإيناري سامي","sms":"السكولت سامي","sn":"الشونا","snk":"السونينك","so":"الصومالية","sog":"السوجدين","sq":"الألبانية","sr":"الصربية","srn":"السرانان تونجو","srr":"السرر","ss":"السواتي","ssy":"لغة الساهو","st":"السوتو الجنوبية","su":"السوندانية","suk":"السوكوما","sus":"السوسو","sux":"السومارية","sv":"السويدية","sw":"السواحلية","sw-CD":"الكونغو السواحلية","swb":"القمرية","syc":"سريانية تقليدية","syr":"السريانية","ta":"التاميلية","te":"التيلوغوية","tem":"التيمن","teo":"تيسو","ter":"التيرينو","tet":"التيتم","tg":"الطاجيكية","th":"التايلاندية","ti":"التغرينية","tig":"التيغرية","tiv":"التيف","tk":"التركمانية","tkl":"التوكيلاو","tl":"التاغالوغية","tlh":"الكلينجون","tli":"التلينغيتية","tmh":"التاماشيك","tn":"التسوانية","to":"التونغية","tog":"تونجا - نياسا","tpi":"التوك بيسين","tr":"التركية","trv":"لغة التاروكو","ts":"السونجا","tsi":"التسيمشيان","tt":"التترية","tum":"التامبوكا","tvl":"التوفالو","tw":"التوي","twq":"تاساواق","ty":"التاهيتية","tyv":"التوفية","tzm":"الأمازيغية وسط الأطلس","udm":"الأدمرت","ug":"الأويغورية","uga":"اليجاريتيك","uk":"الأوكرانية","umb":"الأمبندو","und":"لغة غير معروفة","ur":"الأوردية","uz":"الأوزبكية","vai":"الفاي","ve":"الفيندا","vi":"الفيتنامية","vo":"لغة الفولابوك","vot":"الفوتيك","vun":"الفونجو","wa":"الولونية","wae":"الوالسر","wal":"الولاياتا","war":"الواراي","was":"الواشو","wbp":"وارلبيري","wo":"الولوفية","wuu":"الوو الصينية","xal":"الكالميك","xh":"الخوسا","xog":"السوغا","yao":"الياو","yap":"اليابيز","yav":"يانجبن","ybb":"يمبا","yi":"اليديشية","yo":"اليوروبا","yue":"الكَنْتُونية","za":"الزهيونج","zap":"الزابوتيك","zbl":"رموز المعايير الأساسية","zen":"الزيناجا","zgh":"التمازيغية المغربية القياسية","zh":"الصينية","zh-Hans":"الصينية المبسطة","zh-Hant":"الصينية التقليدية","zu":"الزولو","zun":"الزونية","zxx":"بدون محتوى لغوي","zza":"زازا"},"short":{"az":"الأذرية","en-GB":"الإنجليزية المملكة المتحدة","en-US":"الإنجليزية الولايات المتحدة"},"narrow":{}},"region":{"long":{"142":"آسيا","143":"وسط آسيا","145":"غرب آسيا","150":"أوروبا","151":"شرق أوروبا","154":"شمال أوروبا","155":"غرب أوروبا","202":"أفريقيا جنوب الصحراء الكبرى","419":"أمريكا اللاتينية","001":"العالم","002":"أفريقيا","003":"أمريكا الشمالية","005":"أمريكا الجنوبية","009":"أوقيانوسيا","011":"غرب أفريقيا","013":"أمريكا الوسطى","014":"شرق أفريقيا","015":"شمال أفريقيا","017":"وسط أفريقيا","018":"أفريقيا الجنوبية","019":"الأمريكتان","021":"شمال أمريكا","029":"الكاريبي","030":"شرق آسيا","034":"جنوب آسيا","035":"جنوب شرق آسيا","039":"جنوب أوروبا","053":"أسترالاسيا","054":"ميلانيزيا","057":"الجزر الميكرونيزية","061":"بولينيزيا","AC":"جزيرة أسينشيون","AD":"أندورا","AE":"الإمارات العربية المتحدة","AF":"أفغانستان","AG":"أنتيغوا وبربودا","AI":"أنغويلا","AL":"ألبانيا","AM":"أرمينيا","AO":"أنغولا","AQ":"أنتاركتيكا","AR":"الأرجنتين","AS":"ساموا الأمريكية","AT":"النمسا","AU":"أستراليا","AW":"أروبا","AX":"جزر آلاند","AZ":"أذربيجان","BA":"البوسنة والهرسك","BB":"بربادوس","BD":"بنغلاديش","BE":"بلجيكا","BF":"بوركينا فاسو","BG":"بلغاريا","BH":"البحرين","BI":"بوروندي","BJ":"بنين","BL":"سان بارتليمي","BM":"برمودا","BN":"بروناي","BO":"بوليفيا","BQ":"هولندا الكاريبية","BR":"البرازيل","BS":"جزر البهاما","BT":"بوتان","BV":"جزيرة بوفيه","BW":"بوتسوانا","BY":"بيلاروس","BZ":"بليز","CA":"كندا","CC":"جزر كوكوس (كيلينغ)","CD":"الكونغو - كينشاسا","CF":"جمهورية أفريقيا الوسطى","CG":"الكونغو - برازافيل","CH":"سويسرا","CI":"ساحل العاج","CK":"جزر كوك","CL":"تشيلي","CM":"الكاميرون","CN":"الصين","CO":"كولومبيا","CP":"جزيرة كليبيرتون","CR":"كوستاريكا","CU":"كوبا","CV":"الرأس الأخضر","CW":"كوراساو","CX":"جزيرة كريسماس","CY":"قبرص","CZ":"التشيك","DE":"ألمانيا","DG":"دييغو غارسيا","DJ":"جيبوتي","DK":"الدانمرك","DM":"دومينيكا","DO":"جمهورية الدومينيكان","DZ":"الجزائر","EA":"سيوتا وميليلا","EC":"الإكوادور","EE":"إستونيا","EG":"مصر","EH":"الصحراء الغربية","ER":"إريتريا","ES":"إسبانيا","ET":"إثيوبيا","EU":"الاتحاد الأوروبي","EZ":"منطقة اليورو","FI":"فنلندا","FJ":"فيجي","FK":"جزر فوكلاند","FM":"ميكرونيزيا","FO":"جزر فارو","FR":"فرنسا","GA":"الغابون","GB":"المملكة المتحدة","GD":"غرينادا","GE":"جورجيا","GF":"غويانا الفرنسية","GG":"غيرنزي","GH":"غانا","GI":"جبل طارق","GL":"غرينلاند","GM":"غامبيا","GN":"غينيا","GP":"غوادلوب","GQ":"غينيا الاستوائية","GR":"اليونان","GS":"جورجيا الجنوبية وجزر ساندويتش الجنوبية","GT":"غواتيمالا","GU":"غوام","GW":"غينيا بيساو","GY":"غيانا","HK":"هونغ كونغ الصينية (منطقة إدارية خاصة)","HM":"جزيرة هيرد وجزر ماكدونالد","HN":"هندوراس","HR":"كرواتيا","HT":"هايتي","HU":"هنغاريا","IC":"جزر الكناري","ID":"إندونيسيا","IE":"أيرلندا","IL":"إسرائيل","IM":"جزيرة مان","IN":"الهند","IO":"الإقليم البريطاني في المحيط الهندي","IQ":"العراق","IR":"إيران","IS":"آيسلندا","IT":"إيطاليا","JE":"جيرسي","JM":"جامايكا","JO":"الأردن","JP":"اليابان","KE":"كينيا","KG":"قيرغيزستان","KH":"كمبوديا","KI":"كيريباتي","KM":"جزر القمر","KN":"سانت كيتس ونيفيس","KP":"كوريا الشمالية","KR":"كوريا الجنوبية","KW":"الكويت","KY":"جزر كايمان","KZ":"كازاخستان","LA":"لاوس","LB":"لبنان","LC":"سانت لوسيا","LI":"ليختنشتاين","LK":"سريلانكا","LR":"ليبيريا","LS":"ليسوتو","LT":"ليتوانيا","LU":"لوكسمبورغ","LV":"لاتفيا","LY":"ليبيا","MA":"المغرب","MC":"موناكو","MD":"مولدوفا","ME":"الجبل الأسود","MF":"سان مارتن","MG":"مدغشقر","MH":"جزر مارشال","MK":"مقدونيا الشمالية","ML":"مالي","MM":"ميانمار (بورما)","MN":"منغوليا","MO":"منطقة ماكاو الإدارية الخاصة","MP":"جزر ماريانا الشمالية","MQ":"جزر المارتينيك","MR":"موريتانيا","MS":"مونتسرات","MT":"مالطا","MU":"موريشيوس","MV":"جزر المالديف","MW":"ملاوي","MX":"المكسيك","MY":"ماليزيا","MZ":"موزمبيق","NA":"ناميبيا","NC":"كاليدونيا الجديدة","NE":"النيجر","NF":"جزيرة نورفولك","NG":"نيجيريا","NI":"نيكاراغوا","NL":"هولندا","NO":"النرويج","NP":"نيبال","NR":"ناورو","NU":"نيوي","NZ":"نيوزيلندا","OM":"عُمان","PA":"بنما","PE":"بيرو","PF":"بولينيزيا الفرنسية","PG":"بابوا غينيا الجديدة","PH":"الفلبين","PK":"باكستان","PL":"بولندا","PM":"سان بيير ومكويلون","PN":"جزر بيتكيرن","PR":"بورتوريكو","PS":"الأراضي الفلسطينية","PT":"البرتغال","PW":"بالاو","PY":"باراغواي","QA":"قطر","QO":"أوقيانوسيا النائية","RE":"روينيون","RO":"رومانيا","RS":"صربيا","RU":"روسيا","RW":"رواندا","SA":"المملكة العربية السعودية","SB":"جزر سليمان","SC":"سيشل","SD":"السودان","SE":"السويد","SG":"سنغافورة","SH":"سانت هيلينا","SI":"سلوفينيا","SJ":"سفالبارد وجان ماين","SK":"سلوفاكيا","SL":"سيراليون","SM":"سان مارينو","SN":"السنغال","SO":"الصومال","SR":"سورينام","SS":"جنوب السودان","ST":"ساو تومي وبرينسيبي","SV":"السلفادور","SX":"سانت مارتن","SY":"سوريا","SZ":"إسواتيني","TA":"تريستان دا كونا","TC":"جزر توركس وكايكوس","TD":"تشاد","TF":"الأقاليم الجنوبية الفرنسية","TG":"توغو","TH":"تايلاند","TJ":"طاجيكستان","TK":"توكيلو","TL":"تيمور - ليشتي","TM":"تركمانستان","TN":"تونس","TO":"تونغا","TR":"تركيا","TT":"ترينيداد وتوباغو","TV":"توفالو","TW":"تايوان","TZ":"تنزانيا","UA":"أوكرانيا","UG":"أوغندا","UM":"جزر الولايات المتحدة النائية","UN":"الأمم المتحدة","US":"الولايات المتحدة","UY":"أورغواي","UZ":"أوزبكستان","VA":"الفاتيكان","VC":"سانت فنسنت وجزر غرينادين","VE":"فنزويلا","VG":"جزر فيرجن البريطانية","VI":"جزر فيرجن التابعة للولايات المتحدة","VN":"فيتنام","VU":"فانواتو","WF":"جزر والس وفوتونا","WS":"ساموا","XA":"XA","XB":"XB","XK":"كوسوفو","YE":"اليمن","YT":"مايوت","ZA":"جنوب أفريقيا","ZM":"زامبيا","ZW":"زيمبابوي","ZZ":"منطقة غير معروفة"},"short":{"GB":"المملكة المتحدة","HK":"هونغ كونغ","MO":"مكاو","PS":"فلسطين","UN":"الأمم المتحدة","US":"الولايات المتحدة"},"narrow":{}},"script":{"long":{"Adlm":"Adlm","Aghb":"Aghb","Ahom":"Ahom","Arab":"العربية","Armi":"Armi","Armn":"الأرمينية","Avst":"Avst","Bali":"البالية","Bamu":"Bamu","Bass":"Bass","Batk":"الباتاك","Beng":"البنغالية","Bhks":"Bhks","Blis":"رموز بليس","Bopo":"البوبوموفو","Brah":"الهندوسية","Brai":"البرايل","Bugi":"البجينيز","Buhd":"البهيدية","Cakm":"Cakm","Cans":"مقاطع كندية أصلية موحدة","Cari":"الكارية","Cham":"التشامية","Cher":"الشيروكي","Cirt":"السيرث","Copt":"القبطية","Cprt":"القبرصية","Cyrl":"السيريلية","Cyrs":"السيريلية السلافية الكنسية القديمة","Deva":"الديفاناجاري","Dogr":"Dogr","Dsrt":"الديسيريت","Dupl":"Dupl","Egyd":"الديموطيقية","Egyh":"الهيراطيقية","Egyp":"الهيروغليفية","Elba":"Elba","Elym":"Elym","Ethi":"الأثيوبية","Geok":"الأبجدية الجورجية - أسومتافرلي و نسخري","Geor":"الجورجية","Glag":"الجلاجوليتيك","Gong":"Gong","Gonm":"Gonm","Goth":"القوطية","Gran":"Gran","Grek":"اليونانية","Gujr":"التاغجراتية","Guru":"الجرمخي","Hanb":"هانب","Hang":"الهانغول","Hani":"الهان","Hano":"الهانونو","Hans":"المبسطة","Hant":"التقليدية","Hatr":"Hatr","Hebr":"العبرية","Hira":"الهيراجانا","Hluw":"Hluw","Hmng":"الباهوه همونج","Hmnp":"Hmnp","Hrkt":"أبجدية مقطعية يابانية","Hung":"المجرية القديمة","Inds":"اندس - هارابان","Ital":"الإيطالية القديمة","Jamo":"جامو","Java":"الجاوية","Jpan":"اليابانية","Kali":"الكياه لى","Kana":"الكتكانا","Khar":"الخاروشتى","Khmr":"الخميرية","Khoj":"Khoj","Knda":"الكانادا","Kore":"الكورية","Kthi":"Kthi","Lana":"الانا","Laoo":"اللاو","Latf":"اللاتينية - متغير فراكتر","Latg":"اللاتينية - متغير غيلى","Latn":"اللاتينية","Lepc":"الليبتشا - رونج","Limb":"الليمبو","Lina":"الخطية أ","Linb":"الخطية ب","Lisu":"Lisu","Lyci":"الليسية","Lydi":"الليدية","Mahj":"Mahj","Maka":"Maka","Mand":"المانداينية","Mani":"Mani","Marc":"Marc","Maya":"المايا الهيروغليفية","Medf":"Medf","Mend":"Mend","Merc":"Merc","Mero":"الميرويتيك","Mlym":"الماليالام","Modi":"Modi","Mong":"المغولية","Moon":"مون","Mroo":"Mroo","Mtei":"Mtei","Mult":"Mult","Mymr":"الميانمار","Nand":"Nand","Narb":"العربية الشمالية القديمة","Nbat":"Nbat","Newa":"Newa","Nkoo":"أنكو","Nshu":"Nshu","Ogam":"الأوجهام","Olck":"Olck","Orkh":"الأورخون","Orya":"الأوريا","Osge":"Osge","Osma":"الأوسمانيا","Palm":"Palm","Pauc":"Pauc","Perm":"البيرميكية القديمة","Phag":"الفاجسبا","Phli":"Phli","Phlp":"Phlp","Phnx":"الفينيقية","Plrd":"الصوتيات الجماء","Prti":"Prti","Qaag":"Qaag","Rjng":"Rjng","Rohg":"Rohg","Roro":"رنجورنجو","Runr":"الروني","Samr":"Samr","Sara":"الساراتي","Sarb":"العربية الجنوبية القديمة","Saur":"Saur","Sgnw":"Sgnw","Shaw":"الشواني","Shrd":"Shrd","Sidd":"Sidd","Sind":"Sind","Sinh":"السينهالا","Sogd":"Sogd","Sogo":"Sogo","Sora":"Sora","Soyo":"Soyo","Sund":"السوندانية","Sylo":"السيلوتي ناغري","Syrc":"السريانية","Syre":"السريانية الأسترنجيلية","Syrj":"السريانية الغربية","Syrn":"السريانية الشرقية","Tagb":"التاجبانوا","Takr":"Takr","Tale":"التاي لي","Talu":"التاى لى الجديد","Taml":"التاميلية","Tang":"Tang","Tavt":"Tavt","Telu":"التيلجو","Teng":"التينجوار","Tfng":"التيفيناغ","Tglg":"التغالوغية","Thaa":"الثعنة","Thai":"التايلاندية","Tibt":"التبتية","Tirh":"Tirh","Ugar":"الأجاريتيكية","Vaii":"الفاي","Visp":"الكلام المرئي","Wara":"Wara","Wcho":"Wcho","Xpeo":"الفارسية القديمة","Xsux":"الكتابة المسمارية الأكدية السومرية","Yiii":"اليي","Zanb":"Zanb","Zinh":"الموروث","Zmth":"تدوين رياضي","Zsye":"إيموجي","Zsym":"رموز","Zxxx":"غير مكتوب","Zyyy":"عام","Zzzz":"نظام كتابة غير معروف"},"short":{},"narrow":{}},"currency":{"long":{"ADP":"بيستا أندوري","AED":"درهم إماراتي","AFA":"أفغاني - 1927-2002","AFN":"أفغاني","ALK":"ALK","ALL":"ليك ألباني","AMD":"درام أرميني","ANG":"غيلدر أنتيلي هولندي","AOA":"كوانزا أنغولي","AOK":"كوانزا أنجولي - 1977-1990","AON":"كوانزا أنجولي جديدة - 1990-2000","AOR":"كوانزا أنجولي معدلة - 1995 - 1999","ARA":"استرال أرجنتيني","ARL":"ARL","ARM":"ARM","ARP":"بيزو أرجنتيني - 1983-1985","ARS":"بيزو أرجنتيني","ATS":"شلن نمساوي","AUD":"دولار أسترالي","AWG":"فلورن أروبي","AZM":"مانات أذريبجاني","AZN":"مانات أذربيجان","BAD":"دينار البوسنة والهرسك","BAM":"مارك البوسنة والهرسك قابل للتحويل","BAN":"BAN","BBD":"دولار بربادوسي","BDT":"تاكا بنغلاديشي","BEC":"فرنك بلجيكي قابل للتحويل","BEF":"فرنك بلجيكي","BEL":"فرنك بلجيكي مالي","BGL":"BGL","BGM":"BGM","BGN":"ليف بلغاري","BGO":"BGO","BHD":"دينار بحريني","BIF":"فرنك بروندي","BMD":"دولار برمودي","BND":"دولار بروناي","BOB":"بوليفيانو بوليفي","BOL":"BOL","BOP":"بيزو بوليفي","BOV":"مفدول بوليفي","BRB":"نوفو كروزايرو برازيلي - 1967-1986","BRC":"كروزادو برازيلي","BRE":"كروزايرو برازيلي - 1990-1993","BRL":"ريال برازيلي","BRN":"BRN","BRR":"BRR","BRZ":"BRZ","BSD":"دولار باهامي","BTN":"نولتوم بوتاني","BUK":"كيات بورمي","BWP":"بولا بتسواني","BYB":"روبل بيلاروسي جديد - 1994-1999","BYN":"روبل بيلاروسي","BYR":"روبل بيلاروسي (٢٠٠٠–٢٠١٦)","BZD":"دولار بليزي","CAD":"دولار كندي","CDF":"فرنك كونغولي","CHE":"CHE","CHF":"فرنك سويسري","CHW":"CHW","CLE":"CLE","CLF":"CLF","CLP":"بيزو تشيلي","CNH":"يوان صيني (في الخارج)","CNX":"CNX","CNY":"يوان صيني","COP":"بيزو كولومبي","COU":"COU","CRC":"كولن كوستاريكي","CSD":"دينار صربي قديم","CSK":"كرونة تشيكوسلوفاكيا","CUC":"بيزو كوبي قابل للتحويل","CUP":"بيزو كوبي","CVE":"اسكودو الرأس الأخضر","CYP":"جنيه قبرصي","CZK":"كرونة تشيكية","DDM":"أوستمارك ألماني شرقي","DEM":"مارك ألماني","DJF":"فرنك جيبوتي","DKK":"كرونة دنماركية","DOP":"بيزو الدومنيكان","DZD":"دينار جزائري","ECS":"ECS","ECV":"ECV","EEK":"كرونة استونية","EGP":"جنيه مصري","ERN":"ناكفا أريتري","ESA":"ESA","ESB":"ESB","ESP":"بيزيتا إسباني","ETB":"بير أثيوبي","EUR":"يورو","FIM":"ماركا فنلندي","FJD":"دولار فيجي","FKP":"جنيه جزر فوكلاند","FRF":"فرنك فرنسي","GBP":"جنيه إسترليني","GEK":"GEK","GEL":"لارى جورجي","GHC":"سيدي غاني","GHS":"سيدي غانا","GIP":"جنيه جبل طارق","GMD":"دلاسي غامبي","GNF":"فرنك غينيا","GNS":"سيلي غينيا","GQE":"اكويل جونينا غينيا الاستوائيّة","GRD":"دراخما يوناني","GTQ":"كوتزال غواتيمالا","GWE":"اسكود برتغالي غينيا","GWP":"بيزو غينيا بيساو","GYD":"دولار غيانا","HKD":"دولار هونغ كونغ","HNL":"ليمبيرا هنداروس","HRD":"دينار كرواتي","HRK":"كونا كرواتي","HTG":"جوردى هايتي","HUF":"فورينت هنغاري","IDR":"روبية إندونيسية","IEP":"جنيه إيرلندي","ILP":"جنيه إسرائيلي","ILR":"ILR","ILS":"شيكل إسرائيلي جديد","INR":"روبية هندي","IQD":"دينار عراقي","IRR":"ريال إيراني","ISJ":"ISJ","ISK":"كرونة أيسلندية","ITL":"ليرة إيطالية","JMD":"دولار جامايكي","JOD":"دينار أردني","JPY":"ين ياباني","KES":"شلن كينيي","KGS":"سوم قيرغستاني","KHR":"رييال كمبودي","KMF":"فرنك جزر القمر","KPW":"وون كوريا الشمالية","KRH":"KRH","KRO":"KRO","KRW":"وون كوريا الجنوبية","KWD":"دينار كويتي","KYD":"دولار جزر كيمن","KZT":"تينغ كازاخستاني","LAK":"كيب لاوسي","LBP":"جنيه لبناني","LKR":"روبية سريلانكية","LRD":"دولار ليبيري","LSL":"لوتي ليسوتو","LTL":"ليتا ليتوانية","LTT":"تالوناس ليتواني","LUC":"فرنك لوكسمبرج قابل للتحويل","LUF":"فرنك لوكسمبرج","LUL":"فرنك لوكسمبرج المالي","LVL":"لاتس لاتفيا","LVR":"روبل لاتفيا","LYD":"دينار ليبي","MAD":"درهم مغربي","MAF":"فرنك مغربي","MCF":"MCF","MDC":"MDC","MDL":"ليو مولدوفي","MGA":"أرياري مدغشقر","MGF":"فرنك مدغشقر","MKD":"دينار مقدوني","MKN":"MKN","MLF":"فرنك مالي","MMK":"كيات ميانمار","MNT":"توغروغ منغولي","MOP":"باتاكا ماكاوي","MRO":"أوقية موريتانية - 1973-2017","MRU":"أوقية موريتانية","MTL":"ليرة مالطية","MTP":"جنيه مالطي","MUR":"روبية موريشيوسية","MVP":"MVP","MVR":"روفيه جزر المالديف","MWK":"كواشا مالاوي","MXN":"بيزو مكسيكي","MXP":"بيزو فضي مكسيكي - 1861-1992","MXV":"MXV","MYR":"رينغيت ماليزي","MZE":"اسكود موزمبيقي","MZM":"MZM","MZN":"متكال موزمبيقي","NAD":"دولار ناميبي","NGN":"نايرا نيجيري","NIC":"كوردوبة نيكاراجوا","NIO":"قرطبة نيكاراغوا","NLG":"جلدر هولندي","NOK":"كرونة نرويجية","NPR":"روبية نيبالي","NZD":"دولار نيوزيلندي","OMR":"ريال عماني","PAB":"بالبوا بنمي","PEI":"PEI","PEN":"سول بيروفي","PES":"PES","PGK":"كينا بابوا غينيا الجديدة","PHP":"بيزو فلبيني","PKR":"روبية باكستاني","PLN":"زلوتي بولندي","PLZ":"زلوتي بولندي - 1950-1995","PTE":"اسكود برتغالي","PYG":"غواراني باراغواي","QAR":"ريال قطري","RHD":"دولار روديسي","ROL":"ليو روماني قديم","RON":"ليو روماني","RSD":"دينار صربي","RUB":"روبل روسي","RUR":"روبل روسي - 1991-1998","RWF":"فرنك رواندي","SAR":"ريال سعودي","SBD":"دولار جزر سليمان","SCR":"روبية سيشيلية","SDD":"دينار سوداني","SDG":"جنيه سوداني","SDP":"جنيه سوداني قديم","SEK":"كرونة سويدية","SGD":"دولار سنغافوري","SHP":"جنيه سانت هيلين","SIT":"تولار سلوفيني","SKK":"كرونة سلوفاكية","SLL":"ليون سيراليوني","SOS":"شلن صومالي","SRD":"دولار سورينامي","SRG":"جلدر سورينامي","SSP":"جنيه جنوب السودان","STD":"دوبرا ساو تومي وبرينسيبي - 1977-2017","STN":"دوبرا ساو تومي وبرينسيبي","SUR":"روبل سوفيتي","SVC":"كولون سلفادوري","SYP":"ليرة سورية","SZL":"ليلانجيني سوازيلندي","THB":"باخت تايلاندي","TJR":"روبل طاجيكستاني","TJS":"سوموني طاجيكستاني","TMM":"مانات تركمنستاني","TMT":"مانات تركمانستان","TND":"دينار تونسي","TOP":"بانغا تونغا","TPE":"اسكود تيموري","TRL":"ليرة تركي","TRY":"ليرة تركية","TTD":"دولار ترينداد وتوباغو","TWD":"دولار تايواني","TZS":"شلن تنزاني","UAH":"هريفنيا أوكراني","UAK":"UAK","UGS":"شلن أوغندي - 1966-1987","UGX":"شلن أوغندي","USD":"دولار أمريكي","USN":"دولار أمريكي (اليوم التالي)‏","USS":"دولار أمريكي (نفس اليوم)‏","UYI":"UYI","UYP":"بيزو أوروجواي - 1975-1993","UYU":"بيزو اوروغواي","UYW":"UYW","UZS":"سوم أوزبكستاني","VEB":"بوليفار فنزويلي - 1871-2008","VEF":"بوليفار فنزويلي - 2008–2018","VES":"بوليفار فنزويلي","VND":"دونج فيتنامي","VNN":"VNN","VUV":"فاتو فانواتو","WST":"تالا ساموا","XAF":"فرنك وسط أفريقي","XAG":"فضة","XAU":"ذهب","XBA":"الوحدة الأوروبية المركبة","XBB":"الوحدة المالية الأوروبية","XBC":"الوحدة الحسابية الأوروبية","XBD":"(XBD)وحدة الحساب الأوروبية","XCD":"دولار شرق الكاريبي","XDR":"حقوق السحب الخاصة","XEU":"وحدة النقد الأوروبية","XFO":"فرنك فرنسي ذهبي","XFU":"(UIC)فرنك فرنسي","XOF":"فرنك غرب أفريقي","XPD":"بالاديوم","XPF":"فرنك سي إف بي","XPT":"البلاتين","XRE":"XRE","XSU":"XSU","XTS":"كود اختبار العملة","XUA":"XUA","XXX":"عملة غير معروفة","YDD":"دينار يمني","YER":"ريال يمني","YUD":"دينار يوغسلافي","YUM":"YUM","YUN":"دينار يوغسلافي قابل للتحويل","YUR":"YUR","ZAL":"راند جنوب أفريقيا -مالي","ZAR":"راند جنوب أفريقيا","ZMK":"كواشا زامبي - 1968-2012","ZMW":"كواشا زامبي","ZRN":"زائير زائيري جديد","ZRZ":"زائير زائيري","ZWD":"دولار زمبابوي","ZWL":"دولار زمبابوي 2009","ZWR":"ZWR"},"short":{},"narrow":{}}},"patterns":{"locale":"{0} ({1})"}}},"availableLocales":["ar"],"aliases":{},"parentLocales":{}},
    {"data":{"de":{"types":{"language":{"long":{"aa":"Afar","ab":"Abchasisch","ace":"Aceh","ach":"Acholi","ada":"Adangme","ady":"Adygeisch","ae":"Avestisch","aeb":"Tunesisches Arabisch","af":"Afrikaans","afh":"Afrihili","agq":"Aghem","ain":"Ainu","ak":"Akan","akk":"Akkadisch","akz":"Alabama","ale":"Aleutisch","aln":"Gegisch","alt":"Süd-Altaisch","am":"Amharisch","an":"Aragonesisch","ang":"Altenglisch","anp":"Angika","ar":"Arabisch","ar-001":"Modernes Hocharabisch","arc":"Aramäisch","arn":"Mapudungun","aro":"Araona","arp":"Arapaho","arq":"Algerisches Arabisch","ars":"Arabisch (Nadschd)","arw":"Arawak","ary":"Marokkanisches Arabisch","arz":"Ägyptisches Arabisch","as":"Assamesisch","asa":"Asu","ase":"Amerikanische Gebärdensprache","ast":"Asturianisch","av":"Awarisch","avk":"Kotava","awa":"Awadhi","ay":"Aymara","az":"Aserbaidschanisch","ba":"Baschkirisch","bal":"Belutschisch","ban":"Balinesisch","bar":"Bairisch","bas":"Basaa","bax":"Bamun","bbc":"Batak Toba","bbj":"Ghomala","be":"Weißrussisch","bej":"Bedauye","bem":"Bemba","bew":"Betawi","bez":"Bena","bfd":"Bafut","bfq":"Badaga","bg":"Bulgarisch","bgn":"Westliches Belutschi","bho":"Bhodschpuri","bi":"Bislama","bik":"Bikol","bin":"Bini","bjn":"Banjaresisch","bkm":"Kom","bla":"Blackfoot","bm":"Bambara","bn":"Bengalisch","bo":"Tibetisch","bpy":"Bishnupriya","bqi":"Bachtiarisch","br":"Bretonisch","bra":"Braj-Bhakha","brh":"Brahui","brx":"Bodo","bs":"Bosnisch","bss":"Akoose","bua":"Burjatisch","bug":"Buginesisch","bum":"Bulu","byn":"Blin","byv":"Medumba","ca":"Katalanisch","cad":"Caddo","car":"Karibisch","cay":"Cayuga","cch":"Atsam","ccp":"Chakma","ce":"Tschetschenisch","ceb":"Cebuano","cgg":"Rukiga","ch":"Chamorro","chb":"Chibcha","chg":"Tschagataisch","chk":"Chuukesisch","chm":"Mari","chn":"Chinook","cho":"Choctaw","chp":"Chipewyan","chr":"Cherokee","chy":"Cheyenne","ckb":"Zentralkurdisch","co":"Korsisch","cop":"Koptisch","cps":"Capiznon","cr":"Cree","crh":"Krimtatarisch","crs":"Seychellenkreol","cs":"Tschechisch","csb":"Kaschubisch","cu":"Kirchenslawisch","cv":"Tschuwaschisch","cy":"Walisisch","da":"Dänisch","dak":"Dakota","dar":"Darginisch","dav":"Taita","de":"Deutsch","de-AT":"Österreichisches Deutsch","de-CH":"Schweizer Hochdeutsch","del":"Delaware","den":"Slave","dgr":"Dogrib","din":"Dinka","dje":"Zarma","doi":"Dogri","dsb":"Niedersorbisch","dtp":"Zentral-Dusun","dua":"Duala","dum":"Mittelniederländisch","dv":"Dhivehi","dyo":"Diola","dyu":"Dyula","dz":"Dzongkha","dzg":"Dazaga","ebu":"Embu","ee":"Ewe","efi":"Efik","egl":"Emilianisch","egy":"Ägyptisch","eka":"Ekajuk","el":"Griechisch","elx":"Elamisch","en":"Englisch","en-AU":"Englisch (Australien)","en-CA":"Englisch (Kanada)","en-GB":"Englisch (Vereinigtes Königreich)","en-US":"Englisch (Vereinigte Staaten)","enm":"Mittelenglisch","eo":"Esperanto","es":"Spanisch","es-419":"Spanisch (Lateinamerika)","es-ES":"Spanisch (Spanien)","es-MX":"Spanisch (Mexiko)","esu":"Zentral-Alaska-Yupik","et":"Estnisch","eu":"Baskisch","ewo":"Ewondo","ext":"Extremadurisch","fa":"Persisch","fan":"Pangwe","fat":"Fanti","ff":"Ful","fi":"Finnisch","fil":"Filipino","fit":"Meänkieli","fj":"Fidschi","fo":"Färöisch","fon":"Fon","fr":"Französisch","fr-CA":"Französisch (Kanada)","fr-CH":"Französisch (Schweiz)","frc":"Cajun","frm":"Mittelfranzösisch","fro":"Altfranzösisch","frp":"Frankoprovenzalisch","frr":"Nordfriesisch","frs":"Ostfriesisch","fur":"Friaulisch","fy":"Westfriesisch","ga":"Irisch","gaa":"Ga","gag":"Gagausisch","gan":"Gan","gay":"Gayo","gba":"Gbaya","gbz":"Gabri","gd":"Schottisches Gälisch","gez":"Geez","gil":"Kiribatisch","gl":"Galicisch","glk":"Gilaki","gmh":"Mittelhochdeutsch","gn":"Guaraní","goh":"Althochdeutsch","gom":"Goa-Konkani","gon":"Gondi","gor":"Mongondou","got":"Gotisch","grb":"Grebo","grc":"Altgriechisch","gsw":"Schweizerdeutsch","gu":"Gujarati","guc":"Wayúu","gur":"Farefare","guz":"Gusii","gv":"Manx","gwi":"Kutchin","ha":"Haussa","hai":"Haida","hak":"Hakka","haw":"Hawaiisch","he":"Hebräisch","hi":"Hindi","hif":"Fidschi-Hindi","hil":"Hiligaynon","hit":"Hethitisch","hmn":"Miao","ho":"Hiri-Motu","hr":"Kroatisch","hsb":"Obersorbisch","hsn":"Xiang","ht":"Haiti-Kreolisch","hu":"Ungarisch","hup":"Hupa","hy":"Armenisch","hz":"Herero","ia":"Interlingua","iba":"Iban","ibb":"Ibibio","id":"Indonesisch","ie":"Interlingue","ig":"Igbo","ii":"Yi","ik":"Inupiak","ilo":"Ilokano","inh":"Inguschisch","io":"Ido","is":"Isländisch","it":"Italienisch","iu":"Inuktitut","izh":"Ischorisch","ja":"Japanisch","jam":"Jamaikanisch-Kreolisch","jbo":"Lojban","jgo":"Ngomba","jmc":"Machame","jpr":"Jüdisch-Persisch","jrb":"Jüdisch-Arabisch","jut":"Jütisch","jv":"Javanisch","ka":"Georgisch","kaa":"Karakalpakisch","kab":"Kabylisch","kac":"Kachin","kaj":"Jju","kam":"Kamba","kaw":"Kawi","kbd":"Kabardinisch","kbl":"Kanembu","kcg":"Tyap","kde":"Makonde","kea":"Kabuverdianu","ken":"Kenyang","kfo":"Koro","kg":"Kongolesisch","kgp":"Kaingang","kha":"Khasi","kho":"Sakisch","khq":"Koyra Chiini","khw":"Khowar","ki":"Kikuyu","kiu":"Kirmanjki","kj":"Kwanyama","kk":"Kasachisch","kkj":"Kako","kl":"Grönländisch","kln":"Kalenjin","km":"Khmer","kmb":"Kimbundu","kn":"Kannada","ko":"Koreanisch","koi":"Komi-Permjakisch","kok":"Konkani","kos":"Kosraeanisch","kpe":"Kpelle","kr":"Kanuri","krc":"Karatschaiisch-Balkarisch","kri":"Krio","krj":"Kinaray-a","krl":"Karelisch","kru":"Oraon","ks":"Kaschmiri","ksb":"Shambala","ksf":"Bafia","ksh":"Kölsch","ku":"Kurdisch","kum":"Kumükisch","kut":"Kutenai","kv":"Komi","kw":"Kornisch","ky":"Kirgisisch","la":"Latein","lad":"Ladino","lag":"Langi","lah":"Lahnda","lam":"Lamba","lb":"Luxemburgisch","lez":"Lesgisch","lfn":"Lingua Franca Nova","lg":"Ganda","li":"Limburgisch","lij":"Ligurisch","liv":"Livisch","lkt":"Lakota","lmo":"Lombardisch","ln":"Lingala","lo":"Laotisch","lol":"Mongo","lou":"Kreol (Louisiana)","loz":"Lozi","lrc":"Nördliches Luri","lt":"Litauisch","ltg":"Lettgallisch","lu":"Luba-Katanga","lua":"Luba-Lulua","lui":"Luiseno","lun":"Lunda","luo":"Luo","lus":"Lushai","luy":"Luhya","lv":"Lettisch","lzh":"Klassisches Chinesisch","lzz":"Lasisch","mad":"Maduresisch","maf":"Mafa","mag":"Khotta","mai":"Maithili","mak":"Makassarisch","man":"Malinke","mas":"Massai","mde":"Maba","mdf":"Mokschanisch","mdr":"Mandaresisch","men":"Mende","mer":"Meru","mfe":"Morisyen","mg":"Madagassisch","mga":"Mittelirisch","mgh":"Makhuwa-Meetto","mgo":"Meta’","mh":"Marschallesisch","mi":"Maori","mic":"Micmac","min":"Minangkabau","mk":"Mazedonisch","ml":"Malayalam","mn":"Mongolisch","mnc":"Mandschurisch","mni":"Meithei","moh":"Mohawk","mos":"Mossi","mr":"Marathi","mrj":"Bergmari","ms":"Malaiisch","mt":"Maltesisch","mua":"Mundang","mul":"Mehrsprachig","mus":"Muskogee","mwl":"Mirandesisch","mwr":"Marwari","mwv":"Mentawai","my":"Birmanisch","mye":"Myene","myv":"Ersja-Mordwinisch","mzn":"Masanderanisch","na":"Nauruisch","nan":"Min Nan","nap":"Neapolitanisch","naq":"Nama","nb":"Norwegisch Bokmål","nd":"Nord-Ndebele","nds":"Niederdeutsch","nds-NL":"Niedersächsisch","ne":"Nepalesisch","new":"Newari","ng":"Ndonga","nia":"Nias","niu":"Niue","njo":"Ao-Naga","nl":"Niederländisch","nl-BE":"Flämisch","nmg":"Kwasio","nn":"Norwegisch Nynorsk","nnh":"Ngiemboon","no":"Norwegisch","nog":"Nogai","non":"Altnordisch","nov":"Novial","nqo":"N’Ko","nr":"Süd-Ndebele","nso":"Nord-Sotho","nus":"Nuer","nv":"Navajo","nwc":"Alt-Newari","ny":"Nyanja","nym":"Nyamwezi","nyn":"Nyankole","nyo":"Nyoro","nzi":"Nzima","oc":"Okzitanisch","oj":"Ojibwa","om":"Oromo","or":"Oriya","os":"Ossetisch","osa":"Osage","ota":"Osmanisch","pa":"Punjabi","pag":"Pangasinan","pal":"Mittelpersisch","pam":"Pampanggan","pap":"Papiamento","pau":"Palau","pcd":"Picardisch","pcm":"Nigerianisches Pidgin","pdc":"Pennsylvaniadeutsch","pdt":"Plautdietsch","peo":"Altpersisch","pfl":"Pfälzisch","phn":"Phönizisch","pi":"Pali","pl":"Polnisch","pms":"Piemontesisch","pnt":"Pontisch","pon":"Ponapeanisch","prg":"Altpreußisch","pro":"Altprovenzalisch","ps":"Paschtu","pt":"Portugiesisch","pt-BR":"Portugiesisch (Brasilien)","pt-PT":"Portugiesisch (Portugal)","qu":"Quechua","quc":"K’iche’","qug":"Chimborazo Hochland-Quechua","raj":"Rajasthani","rap":"Rapanui","rar":"Rarotonganisch","rgn":"Romagnol","rif":"Tarifit","rm":"Rätoromanisch","rn":"Rundi","ro":"Rumänisch","ro-MD":"Moldauisch","rof":"Rombo","rom":"Romani","root":"Root","rtm":"Rotumanisch","ru":"Russisch","rue":"Russinisch","rug":"Roviana","rup":"Aromunisch","rw":"Kinyarwanda","rwk":"Rwa","sa":"Sanskrit","sad":"Sandawe","sah":"Jakutisch","sam":"Samaritanisch","saq":"Samburu","sas":"Sasak","sat":"Santali","saz":"Saurashtra","sba":"Ngambay","sbp":"Sangu","sc":"Sardisch","scn":"Sizilianisch","sco":"Schottisch","sd":"Sindhi","sdc":"Sassarisch","sdh":"Südkurdisch","se":"Nordsamisch","see":"Seneca","seh":"Sena","sei":"Seri","sel":"Selkupisch","ses":"Koyra Senni","sg":"Sango","sga":"Altirisch","sgs":"Samogitisch","sh":"Serbo-Kroatisch","shi":"Taschelhit","shn":"Schan","shu":"Tschadisch-Arabisch","si":"Singhalesisch","sid":"Sidamo","sk":"Slowakisch","sl":"Slowenisch","sli":"Schlesisch (Niederschlesisch)","sly":"Selayar","sm":"Samoanisch","sma":"Südsamisch","smj":"Lule-Samisch","smn":"Inari-Samisch","sms":"Skolt-Samisch","sn":"Shona","snk":"Soninke","so":"Somali","sog":"Sogdisch","sq":"Albanisch","sr":"Serbisch","srn":"Srananisch","srr":"Serer","ss":"Swazi","ssy":"Saho","st":"Süd-Sotho","stq":"Saterfriesisch","su":"Sundanesisch","suk":"Sukuma","sus":"Susu","sux":"Sumerisch","sv":"Schwedisch","sw":"Suaheli","sw-CD":"Kongo-Swahili","swb":"Komorisch","syc":"Altsyrisch","syr":"Syrisch","szl":"Schlesisch (Wasserpolnisch)","ta":"Tamil","tcy":"Tulu","te":"Telugu","tem":"Temne","teo":"Teso","ter":"Tereno","tet":"Tetum","tg":"Tadschikisch","th":"Thailändisch","ti":"Tigrinya","tig":"Tigre","tiv":"Tiv","tk":"Turkmenisch","tkl":"Tokelauanisch","tkr":"Tsachurisch","tl":"Tagalog","tlh":"Klingonisch","tli":"Tlingit","tly":"Talisch","tmh":"Tamaseq","tn":"Tswana","to":"Tongaisch","tog":"Nyasa Tonga","tpi":"Neumelanesisch","tr":"Türkisch","tru":"Turoyo","trv":"Taroko","ts":"Tsonga","tsd":"Tsakonisch","tsi":"Tsimshian","tt":"Tatarisch","ttt":"Tatisch","tum":"Tumbuka","tvl":"Tuvaluisch","tw":"Twi","twq":"Tasawaq","ty":"Tahitisch","tyv":"Tuwinisch","tzm":"Zentralatlas-Tamazight","udm":"Udmurtisch","ug":"Uigurisch","uga":"Ugaritisch","uk":"Ukrainisch","umb":"Umbundu","und":"Unbekannte Sprache","ur":"Urdu","uz":"Usbekisch","vai":"Vai","ve":"Venda","vec":"Venetisch","vep":"Wepsisch","vi":"Vietnamesisch","vls":"Westflämisch","vmf":"Mainfränkisch","vo":"Volapük","vot":"Wotisch","vro":"Võro","vun":"Vunjo","wa":"Wallonisch","wae":"Walliserdeutsch","wal":"Walamo","war":"Waray","was":"Washo","wbp":"Warlpiri","wo":"Wolof","wuu":"Wu","xal":"Kalmückisch","xh":"Xhosa","xmf":"Mingrelisch","xog":"Soga","yao":"Yao","yap":"Yapesisch","yav":"Yangben","ybb":"Yemba","yi":"Jiddisch","yo":"Yoruba","yrl":"Nheengatu","yue":"Kantonesisch","za":"Zhuang","zap":"Zapotekisch","zbl":"Bliss-Symbole","zea":"Seeländisch","zen":"Zenaga","zgh":"Tamazight","zh":"Chinesisch","zh-Hans":"Chinesisch (vereinfacht)","zh-Hant":"Chinesisch (traditionell)","zu":"Zulu","zun":"Zuni","zxx":"Keine Sprachinhalte","zza":"Zaza"},"short":{"az":"Aserbaidschanisch","en-GB":"Englisch (GB)","en-US":"Englisch (USA)"},"narrow":{}},"region":{"long":{"142":"Asien","143":"Zentralasien","145":"Westasien","150":"Europa","151":"Osteuropa","154":"Nordeuropa","155":"Westeuropa","202":"Subsahara-Afrika","419":"Lateinamerika","001":"Welt","002":"Afrika","003":"Nordamerika","005":"Südamerika","009":"Ozeanien","011":"Westafrika","013":"Mittelamerika","014":"Ostafrika","015":"Nordafrika","017":"Zentralafrika","018":"Südliches Afrika","019":"Amerika","021":"Nördliches Amerika","029":"Karibik","030":"Ostasien","034":"Südasien","035":"Südostasien","039":"Südeuropa","053":"Australasien","054":"Melanesien","057":"Mikronesisches Inselgebiet","061":"Polynesien","AC":"Ascension","AD":"Andorra","AE":"Vereinigte Arabische Emirate","AF":"Afghanistan","AG":"Antigua und Barbuda","AI":"Anguilla","AL":"Albanien","AM":"Armenien","AO":"Angola","AQ":"Antarktis","AR":"Argentinien","AS":"Amerikanisch-Samoa","AT":"Österreich","AU":"Australien","AW":"Aruba","AX":"Ålandinseln","AZ":"Aserbaidschan","BA":"Bosnien und Herzegowina","BB":"Barbados","BD":"Bangladesch","BE":"Belgien","BF":"Burkina Faso","BG":"Bulgarien","BH":"Bahrain","BI":"Burundi","BJ":"Benin","BL":"St. Barthélemy","BM":"Bermuda","BN":"Brunei Darussalam","BO":"Bolivien","BQ":"Bonaire, Sint Eustatius und Saba","BR":"Brasilien","BS":"Bahamas","BT":"Bhutan","BV":"Bouvetinsel","BW":"Botsuana","BY":"Belarus","BZ":"Belize","CA":"Kanada","CC":"Kokosinseln","CD":"Kongo-Kinshasa","CF":"Zentralafrikanische Republik","CG":"Kongo-Brazzaville","CH":"Schweiz","CI":"Côte d’Ivoire","CK":"Cookinseln","CL":"Chile","CM":"Kamerun","CN":"China","CO":"Kolumbien","CP":"Clipperton-Insel","CR":"Costa Rica","CU":"Kuba","CV":"Cabo Verde","CW":"Curaçao","CX":"Weihnachtsinsel","CY":"Zypern","CZ":"Tschechien","DE":"Deutschland","DG":"Diego Garcia","DJ":"Dschibuti","DK":"Dänemark","DM":"Dominica","DO":"Dominikanische Republik","DZ":"Algerien","EA":"Ceuta und Melilla","EC":"Ecuador","EE":"Estland","EG":"Ägypten","EH":"Westsahara","ER":"Eritrea","ES":"Spanien","ET":"Äthiopien","EU":"Europäische Union","EZ":"Eurozone","FI":"Finnland","FJ":"Fidschi","FK":"Falklandinseln","FM":"Mikronesien","FO":"Färöer","FR":"Frankreich","GA":"Gabun","GB":"Vereinigtes Königreich","GD":"Grenada","GE":"Georgien","GF":"Französisch-Guayana","GG":"Guernsey","GH":"Ghana","GI":"Gibraltar","GL":"Grönland","GM":"Gambia","GN":"Guinea","GP":"Guadeloupe","GQ":"Äquatorialguinea","GR":"Griechenland","GS":"Südgeorgien und die Südlichen Sandwichinseln","GT":"Guatemala","GU":"Guam","GW":"Guinea-Bissau","GY":"Guyana","HK":"Sonderverwaltungsregion Hongkong","HM":"Heard und McDonaldinseln","HN":"Honduras","HR":"Kroatien","HT":"Haiti","HU":"Ungarn","IC":"Kanarische Inseln","ID":"Indonesien","IE":"Irland","IL":"Israel","IM":"Isle of Man","IN":"Indien","IO":"Britisches Territorium im Indischen Ozean","IQ":"Irak","IR":"Iran","IS":"Island","IT":"Italien","JE":"Jersey","JM":"Jamaika","JO":"Jordanien","JP":"Japan","KE":"Kenia","KG":"Kirgisistan","KH":"Kambodscha","KI":"Kiribati","KM":"Komoren","KN":"St. Kitts und Nevis","KP":"Nordkorea","KR":"Südkorea","KW":"Kuwait","KY":"Kaimaninseln","KZ":"Kasachstan","LA":"Laos","LB":"Libanon","LC":"St. Lucia","LI":"Liechtenstein","LK":"Sri Lanka","LR":"Liberia","LS":"Lesotho","LT":"Litauen","LU":"Luxemburg","LV":"Lettland","LY":"Libyen","MA":"Marokko","MC":"Monaco","MD":"Republik Moldau","ME":"Montenegro","MF":"St. Martin","MG":"Madagaskar","MH":"Marshallinseln","MK":"Nordmazedonien","ML":"Mali","MM":"Myanmar","MN":"Mongolei","MO":"Sonderverwaltungsregion Macau","MP":"Nördliche Marianen","MQ":"Martinique","MR":"Mauretanien","MS":"Montserrat","MT":"Malta","MU":"Mauritius","MV":"Malediven","MW":"Malawi","MX":"Mexiko","MY":"Malaysia","MZ":"Mosambik","NA":"Namibia","NC":"Neukaledonien","NE":"Niger","NF":"Norfolkinsel","NG":"Nigeria","NI":"Nicaragua","NL":"Niederlande","NO":"Norwegen","NP":"Nepal","NR":"Nauru","NU":"Niue","NZ":"Neuseeland","OM":"Oman","PA":"Panama","PE":"Peru","PF":"Französisch-Polynesien","PG":"Papua-Neuguinea","PH":"Philippinen","PK":"Pakistan","PL":"Polen","PM":"St. Pierre und Miquelon","PN":"Pitcairninseln","PR":"Puerto Rico","PS":"Palästinensische Autonomiegebiete","PT":"Portugal","PW":"Palau","PY":"Paraguay","QA":"Katar","QO":"Äußeres Ozeanien","RE":"Réunion","RO":"Rumänien","RS":"Serbien","RU":"Russland","RW":"Ruanda","SA":"Saudi-Arabien","SB":"Salomonen","SC":"Seychellen","SD":"Sudan","SE":"Schweden","SG":"Singapur","SH":"St. Helena","SI":"Slowenien","SJ":"Spitzbergen und Jan Mayen","SK":"Slowakei","SL":"Sierra Leone","SM":"San Marino","SN":"Senegal","SO":"Somalia","SR":"Suriname","SS":"Südsudan","ST":"São Tomé und Príncipe","SV":"El Salvador","SX":"Sint Maarten","SY":"Syrien","SZ":"Eswatini","TA":"Tristan da Cunha","TC":"Turks- und Caicosinseln","TD":"Tschad","TF":"Französische Süd- und Antarktisgebiete","TG":"Togo","TH":"Thailand","TJ":"Tadschikistan","TK":"Tokelau","TL":"Timor-Leste","TM":"Turkmenistan","TN":"Tunesien","TO":"Tonga","TR":"Türkei","TT":"Trinidad und Tobago","TV":"Tuvalu","TW":"Taiwan","TZ":"Tansania","UA":"Ukraine","UG":"Uganda","UM":"Amerikanische Überseeinseln","UN":"Vereinte Nationen","US":"Vereinigte Staaten","UY":"Uruguay","UZ":"Usbekistan","VA":"Vatikanstadt","VC":"St. Vincent und die Grenadinen","VE":"Venezuela","VG":"Britische Jungferninseln","VI":"Amerikanische Jungferninseln","VN":"Vietnam","VU":"Vanuatu","WF":"Wallis und Futuna","WS":"Samoa","XA":"Pseudo-Akzente","XB":"Pseudo-Bidi","XK":"Kosovo","YE":"Jemen","YT":"Mayotte","ZA":"Südafrika","ZM":"Sambia","ZW":"Simbabwe","ZZ":"Unbekannte Region"},"short":{"GB":"GB","HK":"Hongkong","MO":"Macau","PS":"Palästina","UN":"UN","US":"USA"},"narrow":{}},"script":{"long":{"Adlm":"Adlm","Afak":"Afaka","Aghb":"Kaukasisch-Albanisch","Ahom":"Ahom","Arab":"Arabisch","Armi":"Armi","Armn":"Armenisch","Avst":"Avestisch","Bali":"Balinesisch","Bamu":"Bamun","Bass":"Bassa","Batk":"Battakisch","Beng":"Bengalisch","Bhks":"Bhks","Blis":"Bliss-Symbole","Bopo":"Bopomofo","Brah":"Brahmi","Brai":"Braille","Bugi":"Buginesisch","Buhd":"Buhid","Cakm":"Chakma","Cans":"UCAS","Cari":"Karisch","Cham":"Cham","Cher":"Cherokee","Cirt":"Cirth","Copt":"Koptisch","Cprt":"Zypriotisch","Cyrl":"Kyrillisch","Cyrs":"Altkirchenslawisch","Deva":"Devanagari","Dogr":"Dogr","Dsrt":"Deseret","Dupl":"Duployanisch","Egyd":"Ägyptisch - Demotisch","Egyh":"Ägyptisch - Hieratisch","Egyp":"Ägyptische Hieroglyphen","Elba":"Elbasanisch","Elym":"Elym","Ethi":"Äthiopisch","Geok":"Khutsuri","Geor":"Georgisch","Glag":"Glagolitisch","Gong":"Gong","Gonm":"Gonm","Goth":"Gotisch","Gran":"Grantha","Grek":"Griechisch","Gujr":"Gujarati","Guru":"Gurmukhi","Hanb":"Hanb","Hang":"Hangul","Hani":"Chinesisch","Hano":"Hanunoo","Hans":"Vereinfacht","Hant":"Traditionell","Hatr":"Hatr","Hebr":"Hebräisch","Hira":"Hiragana","Hluw":"Hieroglyphen-Luwisch","Hmng":"Pahawh Hmong","Hmnp":"Hmnp","Hrkt":"Japanische Silbenschrift","Hung":"Altungarisch","Inds":"Indus-Schrift","Ital":"Altitalisch","Jamo":"Jamo","Java":"Javanesisch","Jpan":"Japanisch","Jurc":"Jurchen","Kali":"Kayah Li","Kana":"Katakana","Khar":"Kharoshthi","Khmr":"Khmer","Khoj":"Khojki","Knda":"Kannada","Kore":"Koreanisch","Kpel":"Kpelle","Kthi":"Kaithi","Lana":"Lanna","Laoo":"Laotisch","Latf":"Lateinisch - Fraktur-Variante","Latg":"Lateinisch - Gälische Variante","Latn":"Lateinisch","Lepc":"Lepcha","Limb":"Limbu","Lina":"Linear A","Linb":"Linear B","Lisu":"Fraser","Loma":"Loma","Lyci":"Lykisch","Lydi":"Lydisch","Mahj":"Mahajani","Maka":"Maka","Mand":"Mandäisch","Mani":"Manichäisch","Marc":"Marc","Maya":"Maya-Hieroglyphen","Medf":"Medf","Mend":"Mende","Merc":"Meroitisch kursiv","Mero":"Meroitisch","Mlym":"Malayalam","Modi":"Modi","Mong":"Mongolisch","Moon":"Moon","Mroo":"Mro","Mtei":"Meitei Mayek","Mult":"Mult","Mymr":"Birmanisch","Nand":"Nand","Narb":"Altnordarabisch","Nbat":"Nabatäisch","Newa":"Newa","Nkgb":"Geba","Nkoo":"N’Ko","Nshu":"Frauenschrift","Ogam":"Ogham","Olck":"Ol Chiki","Orkh":"Orchon-Runen","Orya":"Oriya","Osge":"Osge","Osma":"Osmanisch","Palm":"Palmyrenisch","Pauc":"Pau Cin Hau","Perm":"Altpermisch","Phag":"Phags-pa","Phli":"Buch-Pahlavi","Phlp":"Psalter-Pahlavi","Phlv":"Pahlavi","Phnx":"Phönizisch","Plrd":"Pollard Phonetisch","Prti":"Parthisch","Qaag":"Qaag","Rjng":"Rejang","Rohg":"Rohg","Roro":"Rongorongo","Runr":"Runenschrift","Samr":"Samaritanisch","Sara":"Sarati","Sarb":"Altsüdarabisch","Saur":"Saurashtra","Sgnw":"Gebärdensprache","Shaw":"Shaw-Alphabet","Shrd":"Sharada","Sidd":"Siddham","Sind":"Khudawadi","Sinh":"Singhalesisch","Sogd":"Sogd","Sogo":"Sogo","Sora":"Sora Sompeng","Soyo":"Soyo","Sund":"Sundanesisch","Sylo":"Syloti Nagri","Syrc":"Syrisch","Syre":"Syrisch - Estrangelo-Variante","Syrj":"Westsyrisch","Syrn":"Ostsyrisch","Tagb":"Tagbanwa","Takr":"Takri","Tale":"Tai Le","Talu":"Tai Lue","Taml":"Tamilisch","Tang":"Xixia","Tavt":"Tai-Viet","Telu":"Telugu","Teng":"Tengwar","Tfng":"Tifinagh","Tglg":"Tagalog","Thaa":"Thaana","Thai":"Thai","Tibt":"Tibetisch","Tirh":"Tirhuta","Ugar":"Ugaritisch","Vaii":"Vai","Visp":"Sichtbare Sprache","Wara":"Varang Kshiti","Wcho":"Wcho","Wole":"Woleaianisch","Xpeo":"Altpersisch","Xsux":"Sumerisch-akkadische Keilschrift","Yiii":"Yi","Zanb":"Zanb","Zinh":"Geerbter Schriftwert","Zmth":"Mathematische Notation","Zsye":"Emoji","Zsym":"Symbole","Zxxx":"Schriftlos","Zyyy":"Verbreitet","Zzzz":"Unbekannte Schrift"},"short":{},"narrow":{}},"currency":{"long":{"ADP":"Andorranische Pesete","AED":"VAE-Dirham","AFA":"Afghanische Afghani (1927–2002)","AFN":"Afghanischer Afghani","ALK":"Albanischer Lek (1946–1965)","ALL":"Albanischer Lek","AMD":"Armenischer Dram","ANG":"Niederländische-Antillen-Gulden","AOA":"Angolanischer Kwanza","AOK":"Angolanischer Kwanza (1977–1990)","AON":"Angolanischer Neuer Kwanza (1990–2000)","AOR":"Angolanischer Kwanza Reajustado (1995–1999)","ARA":"Argentinischer Austral","ARL":"Argentinischer Peso Ley (1970–1983)","ARM":"Argentinischer Peso (1881–1970)","ARP":"Argentinischer Peso (1983–1985)","ARS":"Argentinischer Peso","ATS":"Österreichischer Schilling","AUD":"Australischer Dollar","AWG":"Aruba-Florin","AZM":"Aserbaidschan-Manat (1993–2006)","AZN":"Aserbaidschan-Manat","BAD":"Bosnien und Herzegowina Dinar (1992–1994)","BAM":"Bosnien und Herzegowina Konvertierbare Mark","BAN":"Bosnien und Herzegowina Neuer Dinar (1994–1997)","BBD":"Barbados-Dollar","BDT":"Bangladesch-Taka","BEC":"Belgischer Franc (konvertibel)","BEF":"Belgischer Franc","BEL":"Belgischer Finanz-Franc","BGL":"Bulgarische Lew (1962–1999)","BGM":"Bulgarischer Lew (1952–1962)","BGN":"Bulgarischer Lew","BGO":"Bulgarischer Lew (1879–1952)","BHD":"Bahrain-Dinar","BIF":"Burundi-Franc","BMD":"Bermuda-Dollar","BND":"Brunei-Dollar","BOB":"Bolivianischer Boliviano","BOL":"Bolivianischer Boliviano (1863–1963)","BOP":"Bolivianischer Peso","BOV":"Boliviansiche Mvdol","BRB":"Brasilianischer Cruzeiro Novo (1967–1986)","BRC":"Brasilianischer Cruzado (1986–1989)","BRE":"Brasilianischer Cruzeiro (1990–1993)","BRL":"Brasilianischer Real","BRN":"Brasilianischer Cruzado Novo (1989–1990)","BRR":"Brasilianischer Cruzeiro (1993–1994)","BRZ":"Brasilianischer Cruzeiro (1942–1967)","BSD":"Bahamas-Dollar","BTN":"Bhutan-Ngultrum","BUK":"Birmanischer Kyat","BWP":"Botswanischer Pula","BYB":"Belarus-Rubel (1994–1999)","BYN":"Weißrussischer Rubel","BYR":"Weißrussischer Rubel (2000–2016)","BZD":"Belize-Dollar","CAD":"Kanadischer Dollar","CDF":"Kongo-Franc","CHE":"WIR-Euro","CHF":"Schweizer Franken","CHW":"WIR Franken","CLE":"Chilenischer Escudo","CLF":"Chilenische Unidades de Fomento","CLP":"Chilenischer Peso","CNH":"Renminbi Yuan (Off–Shore)","CNX":"Dollar der Chinesischen Volksbank","CNY":"Renminbi Yuan","COP":"Kolumbianischer Peso","COU":"Kolumbianische Unidades de valor real","CRC":"Costa-Rica-Colón","CSD":"Serbischer Dinar (2002–2006)","CSK":"Tschechoslowakische Krone","CUC":"Kubanischer Peso (konvertibel)","CUP":"Kubanischer Peso","CVE":"Cabo-Verde-Escudo","CYP":"Zypern-Pfund","CZK":"Tschechische Krone","DDM":"Mark der DDR","DEM":"Deutsche Mark","DJF":"Dschibuti-Franc","DKK":"Dänische Krone","DOP":"Dominikanischer Peso","DZD":"Algerischer Dinar","ECS":"Ecuadorianischer Sucre","ECV":"Verrechnungseinheit für Ecuador","EEK":"Estnische Krone","EGP":"Ägyptisches Pfund","ERN":"Eritreischer Nakfa","ESA":"Spanische Peseta (A–Konten)","ESB":"Spanische Peseta (konvertibel)","ESP":"Spanische Peseta","ETB":"Äthiopischer Birr","EUR":"Euro","FIM":"Finnische Mark","FJD":"Fidschi-Dollar","FKP":"Falkland-Pfund","FRF":"Französischer Franc","GBP":"Britisches Pfund","GEK":"Georgischer Kupon Larit","GEL":"Georgischer Lari","GHC":"Ghanaischer Cedi (1979–2007)","GHS":"Ghanaischer Cedi","GIP":"Gibraltar-Pfund","GMD":"Gambia-Dalasi","GNF":"Guinea-Franc","GNS":"Guineischer Syli","GQE":"Äquatorialguinea-Ekwele","GRD":"Griechische Drachme","GTQ":"Guatemaltekischer Quetzal","GWE":"Portugiesisch Guinea Escudo","GWP":"Guinea-Bissau Peso","GYD":"Guyana-Dollar","HKD":"Hongkong-Dollar","HNL":"Honduras-Lempira","HRD":"Kroatischer Dinar","HRK":"Kroatischer Kuna","HTG":"Haitianische Gourde","HUF":"Ungarischer Forint","IDR":"Indonesische Rupiah","IEP":"Irisches Pfund","ILP":"Israelisches Pfund","ILR":"Israelischer Schekel (1980–1985)","ILS":"Israelischer Neuer Schekel","INR":"Indische Rupie","IQD":"Irakischer Dinar","IRR":"Iranischer Rial","ISJ":"Isländische Krone (1918–1981)","ISK":"Isländische Krone","ITL":"Italienische Lira","JMD":"Jamaika-Dollar","JOD":"Jordanischer Dinar","JPY":"Japanischer Yen","KES":"Kenia-Schilling","KGS":"Kirgisischer Som","KHR":"Kambodschanischer Riel","KMF":"Komoren-Franc","KPW":"Nordkoreanischer Won","KRH":"Südkoreanischer Hwan (1953–1962)","KRO":"Südkoreanischer Won (1945–1953)","KRW":"Südkoreanischer Won","KWD":"Kuwait-Dinar","KYD":"Kaiman-Dollar","KZT":"Kasachischer Tenge","LAK":"Laotischer Kip","LBP":"Libanesisches Pfund","LKR":"Sri-Lanka-Rupie","LRD":"Liberianischer Dollar","LSL":"Loti","LTL":"Litauischer Litas","LTT":"Litauischer Talonas","LUC":"Luxemburgischer Franc (konvertibel)","LUF":"Luxemburgischer Franc","LUL":"Luxemburgischer Finanz-Franc","LVL":"Lettischer Lats","LVR":"Lettischer Rubel","LYD":"Libyscher Dinar","MAD":"Marokkanischer Dirham","MAF":"Marokkanischer Franc","MCF":"Monegassischer Franc","MDC":"Moldau-Cupon","MDL":"Moldau-Leu","MGA":"Madagaskar-Ariary","MGF":"Madagaskar-Franc","MKD":"Mazedonischer Denar","MKN":"Mazedonischer Denar (1992–1993)","MLF":"Malischer Franc","MMK":"Myanmarischer Kyat","MNT":"Mongolischer Tögrög","MOP":"Macao-Pataca","MRO":"Mauretanischer Ouguiya (1973–2017)","MRU":"Mauretanischer Ouguiya","MTL":"Maltesische Lira","MTP":"Maltesisches Pfund","MUR":"Mauritius-Rupie","MVP":"Malediven-Rupie (alt)","MVR":"Malediven-Rufiyaa","MWK":"Malawi-Kwacha","MXN":"Mexikanischer Peso","MXP":"Mexikanischer Silber-Peso (1861–1992)","MXV":"Mexicanischer Unidad de Inversion (UDI)","MYR":"Malaysischer Ringgit","MZE":"Mosambikanischer Escudo","MZM":"Mosambikanischer Metical (1980–2006)","MZN":"Mosambikanischer Metical","NAD":"Namibia-Dollar","NGN":"Nigerianischer Naira","NIC":"Nicaraguanischer Córdoba (1988–1991)","NIO":"Nicaragua-Córdoba","NLG":"Niederländischer Gulden","NOK":"Norwegische Krone","NPR":"Nepalesische Rupie","NZD":"Neuseeland-Dollar","OMR":"Omanischer Rial","PAB":"Panamaischer Balboa","PEI":"Peruanischer Inti","PEN":"Peruanischer Sol","PES":"Peruanischer Sol (1863–1965)","PGK":"Papua-Neuguineischer Kina","PHP":"Philippinischer Peso","PKR":"Pakistanische Rupie","PLN":"Polnischer Złoty","PLZ":"Polnischer Zloty (1950–1995)","PTE":"Portugiesischer Escudo","PYG":"Paraguayischer Guaraní","QAR":"Katar-Riyal","RHD":"Rhodesischer Dollar","ROL":"Rumänischer Leu (1952–2006)","RON":"Rumänischer Leu","RSD":"Serbischer Dinar","RUB":"Russischer Rubel","RUR":"Russischer Rubel (1991–1998)","RWF":"Ruanda-Franc","SAR":"Saudi-Rial","SBD":"Salomonen-Dollar","SCR":"Seychellen-Rupie","SDD":"Sudanesischer Dinar (1992–2007)","SDG":"Sudanesisches Pfund","SDP":"Sudanesisches Pfund (1957–1998)","SEK":"Schwedische Krone","SGD":"Singapur-Dollar","SHP":"St. Helena-Pfund","SIT":"Slowenischer Tolar","SKK":"Slowakische Krone","SLL":"Sierra-leonischer Leone","SOS":"Somalia-Schilling","SRD":"Suriname-Dollar","SRG":"Suriname Gulden","SSP":"Südsudanesisches Pfund","STD":"São-toméischer Dobra (1977–2017)","STN":"São-toméischer Dobra","SUR":"Sowjetischer Rubel","SVC":"El Salvador Colon","SYP":"Syrisches Pfund","SZL":"Swasiländischer Lilangeni","THB":"Thailändischer Baht","TJR":"Tadschikistan Rubel","TJS":"Tadschikistan-Somoni","TMM":"Turkmenistan-Manat (1993–2009)","TMT":"Turkmenistan-Manat","TND":"Tunesischer Dinar","TOP":"Tongaischer Paʻanga","TPE":"Timor-Escudo","TRL":"Türkische Lira (1922–2005)","TRY":"Türkische Lira","TTD":"Trinidad und Tobago-Dollar","TWD":"Neuer Taiwan-Dollar","TZS":"Tansania-Schilling","UAH":"Ukrainische Hrywnja","UAK":"Ukrainischer Karbovanetz","UGS":"Uganda-Schilling (1966–1987)","UGX":"Uganda-Schilling","USD":"US-Dollar","USN":"US Dollar (Nächster Tag)","USS":"US Dollar (Gleicher Tag)","UYI":"Uruguayischer Peso (Indexierte Rechnungseinheiten)","UYP":"Uruguayischer Peso (1975–1993)","UYU":"Uruguayischer Peso","UYW":"UYW","UZS":"Usbekistan-Sum","VEB":"Venezolanischer Bolívar (1871–2008)","VEF":"Venezolanischer Bolívar (2008–2018)","VES":"Venezolanischer Bolívar","VND":"Vietnamesischer Dong","VNN":"Vietnamesischer Dong(1978–1985)","VUV":"Vanuatu-Vatu","WST":"Samoanischer Tala","XAF":"CFA-Franc (BEAC)","XAG":"Unze Silber","XAU":"Unze Gold","XBA":"Europäische Rechnungseinheit","XBB":"Europäische Währungseinheit (XBB)","XBC":"Europäische Rechnungseinheit (XBC)","XBD":"Europäische Rechnungseinheit (XBD)","XCD":"Ostkaribischer Dollar","XDR":"Sonderziehungsrechte","XEU":"Europäische Währungseinheit (XEU)","XFO":"Französischer Gold-Franc","XFU":"Französischer UIC-Franc","XOF":"CFA-Franc (BCEAO)","XPD":"Unze Palladium","XPF":"CFP-Franc","XPT":"Unze Platin","XRE":"RINET Funds","XSU":"SUCRE","XTS":"Testwährung","XUA":"Rechnungseinheit der AfEB","XXX":"Unbekannte Währung","YDD":"Jemen-Dinar","YER":"Jemen-Rial","YUD":"Jugoslawischer Dinar (1966–1990)","YUM":"Jugoslawischer Neuer Dinar (1994–2002)","YUN":"Jugoslawischer Dinar (konvertibel)","YUR":"Jugoslawischer reformierter Dinar (1992–1993)","ZAL":"Südafrikanischer Rand (Finanz)","ZAR":"Südafrikanischer Rand","ZMK":"Kwacha (1968–2012)","ZMW":"Kwacha","ZRN":"Zaire-Neuer Zaïre (1993–1998)","ZRZ":"Zaire-Zaïre (1971–1993)","ZWD":"Simbabwe-Dollar (1980–2008)","ZWL":"Simbabwe-Dollar (2009)","ZWR":"Simbabwe-Dollar (2008)"},"short":{},"narrow":{}}},"patterns":{"locale":"{0} ({1})"}}},"availableLocales":["de"],"aliases":{},"parentLocales":{}},
    {"data":{"en":{"types":{"language":{"long":{"aa":"Afar","ab":"Abkhazian","ace":"Achinese","ach":"Acoli","ada":"Adangme","ady":"Adyghe","ae":"Avestan","aeb":"Tunisian Arabic","af":"Afrikaans","afh":"Afrihili","agq":"Aghem","ain":"Ainu","ak":"Akan","akk":"Akkadian","akz":"Alabama","ale":"Aleut","aln":"Gheg Albanian","alt":"Southern Altai","am":"Amharic","an":"Aragonese","ang":"Old English","anp":"Angika","ar":"Arabic","ar-001":"Modern Standard Arabic","arc":"Aramaic","arn":"Mapuche","aro":"Araona","arp":"Arapaho","arq":"Algerian Arabic","ars":"Najdi Arabic","arw":"Arawak","ary":"Moroccan Arabic","arz":"Egyptian Arabic","as":"Assamese","asa":"Asu","ase":"American Sign Language","ast":"Asturian","av":"Avaric","avk":"Kotava","awa":"Awadhi","ay":"Aymara","az":"Azerbaijani","ba":"Bashkir","bal":"Baluchi","ban":"Balinese","bar":"Bavarian","bas":"Basaa","bax":"Bamun","bbc":"Batak Toba","bbj":"Ghomala","be":"Belarusian","bej":"Beja","bem":"Bemba","bew":"Betawi","bez":"Bena","bfd":"Bafut","bfq":"Badaga","bg":"Bulgarian","bgn":"Western Balochi","bho":"Bhojpuri","bi":"Bislama","bik":"Bikol","bin":"Bini","bjn":"Banjar","bkm":"Kom","bla":"Siksika","bm":"Bambara","bn":"Bangla","bo":"Tibetan","bpy":"Bishnupriya","bqi":"Bakhtiari","br":"Breton","bra":"Braj","brh":"Brahui","brx":"Bodo","bs":"Bosnian","bss":"Akoose","bua":"Buriat","bug":"Buginese","bum":"Bulu","byn":"Blin","byv":"Medumba","ca":"Catalan","cad":"Caddo","car":"Carib","cay":"Cayuga","cch":"Atsam","ccp":"Chakma","ce":"Chechen","ceb":"Cebuano","cgg":"Chiga","ch":"Chamorro","chb":"Chibcha","chg":"Chagatai","chk":"Chuukese","chm":"Mari","chn":"Chinook Jargon","cho":"Choctaw","chp":"Chipewyan","chr":"Cherokee","chy":"Cheyenne","cic":"Chickasaw","ckb":"Central Kurdish","co":"Corsican","cop":"Coptic","cps":"Capiznon","cr":"Cree","crh":"Crimean Turkish","crs":"Seselwa Creole French","cs":"Czech","csb":"Kashubian","cu":"Church Slavic","cv":"Chuvash","cy":"Welsh","da":"Danish","dak":"Dakota","dar":"Dargwa","dav":"Taita","de":"German","de-AT":"Austrian German","de-CH":"Swiss High German","del":"Delaware","den":"Slave","dgr":"Dogrib","din":"Dinka","dje":"Zarma","doi":"Dogri","dsb":"Lower Sorbian","dtp":"Central Dusun","dua":"Duala","dum":"Middle Dutch","dv":"Divehi","dyo":"Jola-Fonyi","dyu":"Dyula","dz":"Dzongkha","dzg":"Dazaga","ebu":"Embu","ee":"Ewe","efi":"Efik","egl":"Emilian","egy":"Ancient Egyptian","eka":"Ekajuk","el":"Greek","elx":"Elamite","en":"English","en-AU":"Australian English","en-CA":"Canadian English","en-GB":"British English","en-US":"American English","enm":"Middle English","eo":"Esperanto","es":"Spanish","es-419":"Latin American Spanish","es-ES":"European Spanish","es-MX":"Mexican Spanish","esu":"Central Yupik","et":"Estonian","eu":"Basque","ewo":"Ewondo","ext":"Extremaduran","fa":"Persian","fa-AF":"Dari","fan":"Fang","fat":"Fanti","ff":"Fulah","fi":"Finnish","fil":"Filipino","fit":"Tornedalen Finnish","fj":"Fijian","fo":"Faroese","fon":"Fon","fr":"French","fr-CA":"Canadian French","fr-CH":"Swiss French","frc":"Cajun French","frm":"Middle French","fro":"Old French","frp":"Arpitan","frr":"Northern Frisian","frs":"Eastern Frisian","fur":"Friulian","fy":"Western Frisian","ga":"Irish","gaa":"Ga","gag":"Gagauz","gan":"Gan Chinese","gay":"Gayo","gba":"Gbaya","gbz":"Zoroastrian Dari","gd":"Scottish Gaelic","gez":"Geez","gil":"Gilbertese","gl":"Galician","glk":"Gilaki","gmh":"Middle High German","gn":"Guarani","goh":"Old High German","gom":"Goan Konkani","gon":"Gondi","gor":"Gorontalo","got":"Gothic","grb":"Grebo","grc":"Ancient Greek","gsw":"Swiss German","gu":"Gujarati","guc":"Wayuu","gur":"Frafra","guz":"Gusii","gv":"Manx","gwi":"Gwichʼin","ha":"Hausa","hai":"Haida","hak":"Hakka Chinese","haw":"Hawaiian","he":"Hebrew","hi":"Hindi","hif":"Fiji Hindi","hil":"Hiligaynon","hit":"Hittite","hmn":"Hmong","ho":"Hiri Motu","hr":"Croatian","hsb":"Upper Sorbian","hsn":"Xiang Chinese","ht":"Haitian Creole","hu":"Hungarian","hup":"Hupa","hy":"Armenian","hz":"Herero","ia":"Interlingua","iba":"Iban","ibb":"Ibibio","id":"Indonesian","ie":"Interlingue","ig":"Igbo","ii":"Sichuan Yi","ik":"Inupiaq","ilo":"Iloko","inh":"Ingush","io":"Ido","is":"Icelandic","it":"Italian","iu":"Inuktitut","izh":"Ingrian","ja":"Japanese","jam":"Jamaican Creole English","jbo":"Lojban","jgo":"Ngomba","jmc":"Machame","jpr":"Judeo-Persian","jrb":"Judeo-Arabic","jut":"Jutish","jv":"Javanese","ka":"Georgian","kaa":"Kara-Kalpak","kab":"Kabyle","kac":"Kachin","kaj":"Jju","kam":"Kamba","kaw":"Kawi","kbd":"Kabardian","kbl":"Kanembu","kcg":"Tyap","kde":"Makonde","kea":"Kabuverdianu","ken":"Kenyang","kfo":"Koro","kg":"Kongo","kgp":"Kaingang","kha":"Khasi","kho":"Khotanese","khq":"Koyra Chiini","khw":"Khowar","ki":"Kikuyu","kiu":"Kirmanjki","kj":"Kuanyama","kk":"Kazakh","kkj":"Kako","kl":"Kalaallisut","kln":"Kalenjin","km":"Khmer","kmb":"Kimbundu","kn":"Kannada","ko":"Korean","koi":"Komi-Permyak","kok":"Konkani","kos":"Kosraean","kpe":"Kpelle","kr":"Kanuri","krc":"Karachay-Balkar","kri":"Krio","krj":"Kinaray-a","krl":"Karelian","kru":"Kurukh","ks":"Kashmiri","ksb":"Shambala","ksf":"Bafia","ksh":"Colognian","ku":"Kurdish","kum":"Kumyk","kut":"Kutenai","kv":"Komi","kw":"Cornish","ky":"Kyrgyz","la":"Latin","lad":"Ladino","lag":"Langi","lah":"Lahnda","lam":"Lamba","lb":"Luxembourgish","lez":"Lezghian","lfn":"Lingua Franca Nova","lg":"Ganda","li":"Limburgish","lij":"Ligurian","liv":"Livonian","lkt":"Lakota","lmo":"Lombard","ln":"Lingala","lo":"Lao","lol":"Mongo","lou":"Louisiana Creole","loz":"Lozi","lrc":"Northern Luri","lt":"Lithuanian","ltg":"Latgalian","lu":"Luba-Katanga","lua":"Luba-Lulua","lui":"Luiseno","lun":"Lunda","luo":"Luo","lus":"Mizo","luy":"Luyia","lv":"Latvian","lzh":"Literary Chinese","lzz":"Laz","mad":"Madurese","maf":"Mafa","mag":"Magahi","mai":"Maithili","mak":"Makasar","man":"Mandingo","mas":"Masai","mde":"Maba","mdf":"Moksha","mdr":"Mandar","men":"Mende","mer":"Meru","mfe":"Morisyen","mg":"Malagasy","mga":"Middle Irish","mgh":"Makhuwa-Meetto","mgo":"Metaʼ","mh":"Marshallese","mi":"Maori","mic":"Mi'kmaq","min":"Minangkabau","mk":"Macedonian","ml":"Malayalam","mn":"Mongolian","mnc":"Manchu","mni":"Manipuri","moh":"Mohawk","mos":"Mossi","mr":"Marathi","mrj":"Western Mari","ms":"Malay","mt":"Maltese","mua":"Mundang","mul":"Multiple languages","mus":"Muscogee","mwl":"Mirandese","mwr":"Marwari","mwv":"Mentawai","my":"Burmese","mye":"Myene","myv":"Erzya","mzn":"Mazanderani","na":"Nauru","nan":"Min Nan Chinese","nap":"Neapolitan","naq":"Nama","nb":"Norwegian Bokmål","nd":"North Ndebele","nds":"Low German","nds-NL":"Low Saxon","ne":"Nepali","new":"Newari","ng":"Ndonga","nia":"Nias","niu":"Niuean","njo":"Ao Naga","nl":"Dutch","nl-BE":"Flemish","nmg":"Kwasio","nn":"Norwegian Nynorsk","nnh":"Ngiemboon","no":"Norwegian","nog":"Nogai","non":"Old Norse","nov":"Novial","nqo":"N’Ko","nr":"South Ndebele","nso":"Northern Sotho","nus":"Nuer","nv":"Navajo","nwc":"Classical Newari","ny":"Nyanja","nym":"Nyamwezi","nyn":"Nyankole","nyo":"Nyoro","nzi":"Nzima","oc":"Occitan","oj":"Ojibwa","om":"Oromo","or":"Odia","os":"Ossetic","osa":"Osage","ota":"Ottoman Turkish","pa":"Punjabi","pag":"Pangasinan","pal":"Pahlavi","pam":"Pampanga","pap":"Papiamento","pau":"Palauan","pcd":"Picard","pcm":"Nigerian Pidgin","pdc":"Pennsylvania German","pdt":"Plautdietsch","peo":"Old Persian","pfl":"Palatine German","phn":"Phoenician","pi":"Pali","pl":"Polish","pms":"Piedmontese","pnt":"Pontic","pon":"Pohnpeian","prg":"Prussian","pro":"Old Provençal","ps":"Pashto","pt":"Portuguese","pt-BR":"Brazilian Portuguese","pt-PT":"European Portuguese","qu":"Quechua","quc":"Kʼicheʼ","qug":"Chimborazo Highland Quichua","raj":"Rajasthani","rap":"Rapanui","rar":"Rarotongan","rgn":"Romagnol","rif":"Riffian","rm":"Romansh","rn":"Rundi","ro":"Romanian","ro-MD":"Moldavian","rof":"Rombo","rom":"Romany","root":"Root","rtm":"Rotuman","ru":"Russian","rue":"Rusyn","rug":"Roviana","rup":"Aromanian","rw":"Kinyarwanda","rwk":"Rwa","sa":"Sanskrit","sad":"Sandawe","sah":"Sakha","sam":"Samaritan Aramaic","saq":"Samburu","sas":"Sasak","sat":"Santali","saz":"Saurashtra","sba":"Ngambay","sbp":"Sangu","sc":"Sardinian","scn":"Sicilian","sco":"Scots","sd":"Sindhi","sdc":"Sassarese Sardinian","sdh":"Southern Kurdish","se":"Northern Sami","see":"Seneca","seh":"Sena","sei":"Seri","sel":"Selkup","ses":"Koyraboro Senni","sg":"Sango","sga":"Old Irish","sgs":"Samogitian","sh":"Serbo-Croatian","shi":"Tachelhit","shn":"Shan","shu":"Chadian Arabic","si":"Sinhala","sid":"Sidamo","sk":"Slovak","sl":"Slovenian","sli":"Lower Silesian","sly":"Selayar","sm":"Samoan","sma":"Southern Sami","smj":"Lule Sami","smn":"Inari Sami","sms":"Skolt Sami","sn":"Shona","snk":"Soninke","so":"Somali","sog":"Sogdien","sq":"Albanian","sr":"Serbian","sr-ME":"Montenegrin","srn":"Sranan Tongo","srr":"Serer","ss":"Swati","ssy":"Saho","st":"Southern Sotho","stq":"Saterland Frisian","su":"Sundanese","suk":"Sukuma","sus":"Susu","sux":"Sumerian","sv":"Swedish","sw":"Swahili","sw-CD":"Congo Swahili","swb":"Comorian","syc":"Classical Syriac","syr":"Syriac","szl":"Silesian","ta":"Tamil","tcy":"Tulu","te":"Telugu","tem":"Timne","teo":"Teso","ter":"Tereno","tet":"Tetum","tg":"Tajik","th":"Thai","ti":"Tigrinya","tig":"Tigre","tiv":"Tiv","tk":"Turkmen","tkl":"Tokelau","tkr":"Tsakhur","tl":"Tagalog","tlh":"Klingon","tli":"Tlingit","tly":"Talysh","tmh":"Tamashek","tn":"Tswana","to":"Tongan","tog":"Nyasa Tonga","tpi":"Tok Pisin","tr":"Turkish","tru":"Turoyo","trv":"Taroko","ts":"Tsonga","tsd":"Tsakonian","tsi":"Tsimshian","tt":"Tatar","ttt":"Muslim Tat","tum":"Tumbuka","tvl":"Tuvalu","tw":"Twi","twq":"Tasawaq","ty":"Tahitian","tyv":"Tuvinian","tzm":"Central Atlas Tamazight","udm":"Udmurt","ug":"Uyghur","uga":"Ugaritic","uk":"Ukrainian","umb":"Umbundu","und":"Unknown language","ur":"Urdu","uz":"Uzbek","vai":"Vai","ve":"Venda","vec":"Venetian","vep":"Veps","vi":"Vietnamese","vls":"West Flemish","vmf":"Main-Franconian","vo":"Volapük","vot":"Votic","vro":"Võro","vun":"Vunjo","wa":"Walloon","wae":"Walser","wal":"Wolaytta","war":"Waray","was":"Washo","wbp":"Warlpiri","wo":"Wolof","wuu":"Wu Chinese","xal":"Kalmyk","xh":"Xhosa","xmf":"Mingrelian","xog":"Soga","yao":"Yao","yap":"Yapese","yav":"Yangben","ybb":"Yemba","yi":"Yiddish","yo":"Yoruba","yrl":"Nheengatu","yue":"Cantonese","za":"Zhuang","zap":"Zapotec","zbl":"Blissymbols","zea":"Zeelandic","zen":"Zenaga","zgh":"Standard Moroccan Tamazight","zh":"Chinese","zh-Hans":"Simplified Chinese","zh-Hant":"Traditional Chinese","zu":"Zulu","zun":"Zuni","zxx":"No linguistic content","zza":"Zaza"},"short":{"az":"Azeri","en-GB":"UK English","en-US":"US English"},"narrow":{}},"region":{"long":{"142":"Asia","143":"Central Asia","145":"Western Asia","150":"Europe","151":"Eastern Europe","154":"Northern Europe","155":"Western Europe","202":"Sub-Saharan Africa","419":"Latin America","001":"World","002":"Africa","003":"North America","005":"South America","009":"Oceania","011":"Western Africa","013":"Central America","014":"Eastern Africa","015":"Northern Africa","017":"Middle Africa","018":"Southern Africa","019":"Americas","021":"Northern America","029":"Caribbean","030":"Eastern Asia","034":"Southern Asia","035":"Southeast Asia","039":"Southern Europe","053":"Australasia","054":"Melanesia","057":"Micronesian Region","061":"Polynesia","AC":"Ascension Island","AD":"Andorra","AE":"United Arab Emirates","AF":"Afghanistan","AG":"Antigua & Barbuda","AI":"Anguilla","AL":"Albania","AM":"Armenia","AO":"Angola","AQ":"Antarctica","AR":"Argentina","AS":"American Samoa","AT":"Austria","AU":"Australia","AW":"Aruba","AX":"Åland Islands","AZ":"Azerbaijan","BA":"Bosnia & Herzegovina","BB":"Barbados","BD":"Bangladesh","BE":"Belgium","BF":"Burkina Faso","BG":"Bulgaria","BH":"Bahrain","BI":"Burundi","BJ":"Benin","BL":"St. Barthélemy","BM":"Bermuda","BN":"Brunei","BO":"Bolivia","BQ":"Caribbean Netherlands","BR":"Brazil","BS":"Bahamas","BT":"Bhutan","BV":"Bouvet Island","BW":"Botswana","BY":"Belarus","BZ":"Belize","CA":"Canada","CC":"Cocos (Keeling) Islands","CD":"Congo - Kinshasa","CF":"Central African Republic","CG":"Congo - Brazzaville","CH":"Switzerland","CI":"Côte d’Ivoire","CK":"Cook Islands","CL":"Chile","CM":"Cameroon","CN":"China","CO":"Colombia","CP":"Clipperton Island","CR":"Costa Rica","CU":"Cuba","CV":"Cape Verde","CW":"Curaçao","CX":"Christmas Island","CY":"Cyprus","CZ":"Czechia","DE":"Germany","DG":"Diego Garcia","DJ":"Djibouti","DK":"Denmark","DM":"Dominica","DO":"Dominican Republic","DZ":"Algeria","EA":"Ceuta & Melilla","EC":"Ecuador","EE":"Estonia","EG":"Egypt","EH":"Western Sahara","ER":"Eritrea","ES":"Spain","ET":"Ethiopia","EU":"European Union","EZ":"Eurozone","FI":"Finland","FJ":"Fiji","FK":"Falkland Islands","FM":"Micronesia","FO":"Faroe Islands","FR":"France","GA":"Gabon","GB":"United Kingdom","GD":"Grenada","GE":"Georgia","GF":"French Guiana","GG":"Guernsey","GH":"Ghana","GI":"Gibraltar","GL":"Greenland","GM":"Gambia","GN":"Guinea","GP":"Guadeloupe","GQ":"Equatorial Guinea","GR":"Greece","GS":"South Georgia & South Sandwich Islands","GT":"Guatemala","GU":"Guam","GW":"Guinea-Bissau","GY":"Guyana","HK":"Hong Kong SAR China","HM":"Heard & McDonald Islands","HN":"Honduras","HR":"Croatia","HT":"Haiti","HU":"Hungary","IC":"Canary Islands","ID":"Indonesia","IE":"Ireland","IL":"Israel","IM":"Isle of Man","IN":"India","IO":"British Indian Ocean Territory","IQ":"Iraq","IR":"Iran","IS":"Iceland","IT":"Italy","JE":"Jersey","JM":"Jamaica","JO":"Jordan","JP":"Japan","KE":"Kenya","KG":"Kyrgyzstan","KH":"Cambodia","KI":"Kiribati","KM":"Comoros","KN":"St. Kitts & Nevis","KP":"North Korea","KR":"South Korea","KW":"Kuwait","KY":"Cayman Islands","KZ":"Kazakhstan","LA":"Laos","LB":"Lebanon","LC":"St. Lucia","LI":"Liechtenstein","LK":"Sri Lanka","LR":"Liberia","LS":"Lesotho","LT":"Lithuania","LU":"Luxembourg","LV":"Latvia","LY":"Libya","MA":"Morocco","MC":"Monaco","MD":"Moldova","ME":"Montenegro","MF":"St. Martin","MG":"Madagascar","MH":"Marshall Islands","MK":"North Macedonia","ML":"Mali","MM":"Myanmar (Burma)","MN":"Mongolia","MO":"Macao SAR China","MP":"Northern Mariana Islands","MQ":"Martinique","MR":"Mauritania","MS":"Montserrat","MT":"Malta","MU":"Mauritius","MV":"Maldives","MW":"Malawi","MX":"Mexico","MY":"Malaysia","MZ":"Mozambique","NA":"Namibia","NC":"New Caledonia","NE":"Niger","NF":"Norfolk Island","NG":"Nigeria","NI":"Nicaragua","NL":"Netherlands","NO":"Norway","NP":"Nepal","NR":"Nauru","NU":"Niue","NZ":"New Zealand","OM":"Oman","PA":"Panama","PE":"Peru","PF":"French Polynesia","PG":"Papua New Guinea","PH":"Philippines","PK":"Pakistan","PL":"Poland","PM":"St. Pierre & Miquelon","PN":"Pitcairn Islands","PR":"Puerto Rico","PS":"Palestinian Territories","PT":"Portugal","PW":"Palau","PY":"Paraguay","QA":"Qatar","QO":"Outlying Oceania","RE":"Réunion","RO":"Romania","RS":"Serbia","RU":"Russia","RW":"Rwanda","SA":"Saudi Arabia","SB":"Solomon Islands","SC":"Seychelles","SD":"Sudan","SE":"Sweden","SG":"Singapore","SH":"St. Helena","SI":"Slovenia","SJ":"Svalbard & Jan Mayen","SK":"Slovakia","SL":"Sierra Leone","SM":"San Marino","SN":"Senegal","SO":"Somalia","SR":"Suriname","SS":"South Sudan","ST":"São Tomé & Príncipe","SV":"El Salvador","SX":"Sint Maarten","SY":"Syria","SZ":"Eswatini","TA":"Tristan da Cunha","TC":"Turks & Caicos Islands","TD":"Chad","TF":"French Southern Territories","TG":"Togo","TH":"Thailand","TJ":"Tajikistan","TK":"Tokelau","TL":"Timor-Leste","TM":"Turkmenistan","TN":"Tunisia","TO":"Tonga","TR":"Turkey","TT":"Trinidad & Tobago","TV":"Tuvalu","TW":"Taiwan","TZ":"Tanzania","UA":"Ukraine","UG":"Uganda","UM":"U.S. Outlying Islands","UN":"United Nations","US":"United States","UY":"Uruguay","UZ":"Uzbekistan","VA":"Vatican City","VC":"St. Vincent & Grenadines","VE":"Venezuela","VG":"British Virgin Islands","VI":"U.S. Virgin Islands","VN":"Vietnam","VU":"Vanuatu","WF":"Wallis & Futuna","WS":"Samoa","XA":"Pseudo-Accents","XB":"Pseudo-Bidi","XK":"Kosovo","YE":"Yemen","YT":"Mayotte","ZA":"South Africa","ZM":"Zambia","ZW":"Zimbabwe","ZZ":"Unknown Region"},"short":{"BA":"Bosnia","GB":"UK","HK":"Hong Kong","MM":"Myanmar","MO":"Macao","PS":"Palestine","UN":"UN","US":"US"},"narrow":{}},"script":{"long":{"Adlm":"Adlam","Afak":"Afaka","Aghb":"Caucasian Albanian","Ahom":"Ahom","Arab":"Arabic","Armi":"Imperial Aramaic","Armn":"Armenian","Avst":"Avestan","Bali":"Balinese","Bamu":"Bamum","Bass":"Bassa Vah","Batk":"Batak","Beng":"Bangla","Bhks":"Bhaiksuki","Blis":"Blissymbols","Bopo":"Bopomofo","Brah":"Brahmi","Brai":"Braille","Bugi":"Buginese","Buhd":"Buhid","Cakm":"Chakma","Cans":"Unified Canadian Aboriginal Syllabics","Cari":"Carian","Cham":"Cham","Cher":"Cherokee","Cirt":"Cirth","Copt":"Coptic","Cprt":"Cypriot","Cyrl":"Cyrillic","Cyrs":"Old Church Slavonic Cyrillic","Deva":"Devanagari","Dogr":"Dogra","Dsrt":"Deseret","Dupl":"Duployan shorthand","Egyd":"Egyptian demotic","Egyh":"Egyptian hieratic","Egyp":"Egyptian hieroglyphs","Elba":"Elbasan","Elym":"Elymaic","Ethi":"Ethiopic","Geok":"Georgian Khutsuri","Geor":"Georgian","Glag":"Glagolitic","Gong":"Gunjala Gondi","Gonm":"Masaram Gondi","Goth":"Gothic","Gran":"Grantha","Grek":"Greek","Gujr":"Gujarati","Guru":"Gurmukhi","Hanb":"Han with Bopomofo","Hang":"Hangul","Hani":"Han","Hano":"Hanunoo","Hans":"Simplified","Hant":"Traditional","Hatr":"Hatran","Hebr":"Hebrew","Hira":"Hiragana","Hluw":"Anatolian Hieroglyphs","Hmng":"Pahawh Hmong","Hmnp":"Nyiakeng Puachue Hmong","Hrkt":"Japanese syllabaries","Hung":"Old Hungarian","Inds":"Indus","Ital":"Old Italic","Jamo":"Jamo","Java":"Javanese","Jpan":"Japanese","Jurc":"Jurchen","Kali":"Kayah Li","Kana":"Katakana","Khar":"Kharoshthi","Khmr":"Khmer","Khoj":"Khojki","Knda":"Kannada","Kore":"Korean","Kpel":"Kpelle","Kthi":"Kaithi","Lana":"Lanna","Laoo":"Lao","Latf":"Fraktur Latin","Latg":"Gaelic Latin","Latn":"Latin","Lepc":"Lepcha","Limb":"Limbu","Lina":"Linear A","Linb":"Linear B","Lisu":"Fraser","Loma":"Loma","Lyci":"Lycian","Lydi":"Lydian","Mahj":"Mahajani","Maka":"Makasar","Mand":"Mandaean","Mani":"Manichaean","Marc":"Marchen","Maya":"Mayan hieroglyphs","Medf":"Medefaidrin","Mend":"Mende","Merc":"Meroitic Cursive","Mero":"Meroitic","Mlym":"Malayalam","Modi":"Modi","Mong":"Mongolian","Moon":"Moon","Mroo":"Mro","Mtei":"Meitei Mayek","Mult":"Multani","Mymr":"Myanmar","Nand":"Nandinagari","Narb":"Old North Arabian","Nbat":"Nabataean","Newa":"Newa","Nkgb":"Naxi Geba","Nkoo":"N’Ko","Nshu":"Nüshu","Ogam":"Ogham","Olck":"Ol Chiki","Orkh":"Orkhon","Orya":"Odia","Osge":"Osage","Osma":"Osmanya","Palm":"Palmyrene","Pauc":"Pau Cin Hau","Perm":"Old Permic","Phag":"Phags-pa","Phli":"Inscriptional Pahlavi","Phlp":"Psalter Pahlavi","Phlv":"Book Pahlavi","Phnx":"Phoenician","Plrd":"Pollard Phonetic","Prti":"Inscriptional Parthian","Qaag":"Zawgyi","Rjng":"Rejang","Rohg":"Hanifi Rohingya","Roro":"Rongorongo","Runr":"Runic","Samr":"Samaritan","Sara":"Sarati","Sarb":"Old South Arabian","Saur":"Saurashtra","Sgnw":"SignWriting","Shaw":"Shavian","Shrd":"Sharada","Sidd":"Siddham","Sind":"Khudawadi","Sinh":"Sinhala","Sogd":"Sogdian","Sogo":"Old Sogdian","Sora":"Sora Sompeng","Soyo":"Soyombo","Sund":"Sundanese","Sylo":"Syloti Nagri","Syrc":"Syriac","Syre":"Estrangelo Syriac","Syrj":"Western Syriac","Syrn":"Eastern Syriac","Tagb":"Tagbanwa","Takr":"Takri","Tale":"Tai Le","Talu":"New Tai Lue","Taml":"Tamil","Tang":"Tangut","Tavt":"Tai Viet","Telu":"Telugu","Teng":"Tengwar","Tfng":"Tifinagh","Tglg":"Tagalog","Thaa":"Thaana","Thai":"Thai","Tibt":"Tibetan","Tirh":"Tirhuta","Ugar":"Ugaritic","Vaii":"Vai","Visp":"Visible Speech","Wara":"Varang Kshiti","Wcho":"Wancho","Wole":"Woleai","Xpeo":"Old Persian","Xsux":"Sumero-Akkadian Cuneiform","Yiii":"Yi","Zanb":"Zanabazar Square","Zinh":"Inherited","Zmth":"Mathematical Notation","Zsye":"Emoji","Zsym":"Symbols","Zxxx":"Unwritten","Zyyy":"Common","Zzzz":"Unknown Script"},"short":{"Cans":"UCAS","Xsux":"S-A Cuneiform"},"narrow":{}},"currency":{"long":{"ADP":"Andorran Peseta","AED":"United Arab Emirates Dirham","AFA":"Afghan Afghani (1927–2002)","AFN":"Afghan Afghani","ALK":"Albanian Lek (1946–1965)","ALL":"Albanian Lek","AMD":"Armenian Dram","ANG":"Netherlands Antillean Guilder","AOA":"Angolan Kwanza","AOK":"Angolan Kwanza (1977–1991)","AON":"Angolan New Kwanza (1990–2000)","AOR":"Angolan Readjusted Kwanza (1995–1999)","ARA":"Argentine Austral","ARL":"Argentine Peso Ley (1970–1983)","ARM":"Argentine Peso (1881–1970)","ARP":"Argentine Peso (1983–1985)","ARS":"Argentine Peso","ATS":"Austrian Schilling","AUD":"Australian Dollar","AWG":"Aruban Florin","AZM":"Azerbaijani Manat (1993–2006)","AZN":"Azerbaijani Manat","BAD":"Bosnia-Herzegovina Dinar (1992–1994)","BAM":"Bosnia-Herzegovina Convertible Mark","BAN":"Bosnia-Herzegovina New Dinar (1994–1997)","BBD":"Barbadian Dollar","BDT":"Bangladeshi Taka","BEC":"Belgian Franc (convertible)","BEF":"Belgian Franc","BEL":"Belgian Franc (financial)","BGL":"Bulgarian Hard Lev","BGM":"Bulgarian Socialist Lev","BGN":"Bulgarian Lev","BGO":"Bulgarian Lev (1879–1952)","BHD":"Bahraini Dinar","BIF":"Burundian Franc","BMD":"Bermudan Dollar","BND":"Brunei Dollar","BOB":"Bolivian Boliviano","BOL":"Bolivian Boliviano (1863–1963)","BOP":"Bolivian Peso","BOV":"Bolivian Mvdol","BRB":"Brazilian New Cruzeiro (1967–1986)","BRC":"Brazilian Cruzado (1986–1989)","BRE":"Brazilian Cruzeiro (1990–1993)","BRL":"Brazilian Real","BRN":"Brazilian New Cruzado (1989–1990)","BRR":"Brazilian Cruzeiro (1993–1994)","BRZ":"Brazilian Cruzeiro (1942–1967)","BSD":"Bahamian Dollar","BTN":"Bhutanese Ngultrum","BUK":"Burmese Kyat","BWP":"Botswanan Pula","BYB":"Belarusian Ruble (1994–1999)","BYN":"Belarusian Ruble","BYR":"Belarusian Ruble (2000–2016)","BZD":"Belize Dollar","CAD":"Canadian Dollar","CDF":"Congolese Franc","CHE":"WIR Euro","CHF":"Swiss Franc","CHW":"WIR Franc","CLE":"Chilean Escudo","CLF":"Chilean Unit of Account (UF)","CLP":"Chilean Peso","CNH":"Chinese Yuan (offshore)","CNX":"Chinese People’s Bank Dollar","CNY":"Chinese Yuan","COP":"Colombian Peso","COU":"Colombian Real Value Unit","CRC":"Costa Rican Colón","CSD":"Serbian Dinar (2002–2006)","CSK":"Czechoslovak Hard Koruna","CUC":"Cuban Convertible Peso","CUP":"Cuban Peso","CVE":"Cape Verdean Escudo","CYP":"Cypriot Pound","CZK":"Czech Koruna","DDM":"East German Mark","DEM":"German Mark","DJF":"Djiboutian Franc","DKK":"Danish Krone","DOP":"Dominican Peso","DZD":"Algerian Dinar","ECS":"Ecuadorian Sucre","ECV":"Ecuadorian Unit of Constant Value","EEK":"Estonian Kroon","EGP":"Egyptian Pound","ERN":"Eritrean Nakfa","ESA":"Spanish Peseta (A account)","ESB":"Spanish Peseta (convertible account)","ESP":"Spanish Peseta","ETB":"Ethiopian Birr","EUR":"Euro","FIM":"Finnish Markka","FJD":"Fijian Dollar","FKP":"Falkland Islands Pound","FRF":"French Franc","GBP":"British Pound","GEK":"Georgian Kupon Larit","GEL":"Georgian Lari","GHC":"Ghanaian Cedi (1979–2007)","GHS":"Ghanaian Cedi","GIP":"Gibraltar Pound","GMD":"Gambian Dalasi","GNF":"Guinean Franc","GNS":"Guinean Syli","GQE":"Equatorial Guinean Ekwele","GRD":"Greek Drachma","GTQ":"Guatemalan Quetzal","GWE":"Portuguese Guinea Escudo","GWP":"Guinea-Bissau Peso","GYD":"Guyanaese Dollar","HKD":"Hong Kong Dollar","HNL":"Honduran Lempira","HRD":"Croatian Dinar","HRK":"Croatian Kuna","HTG":"Haitian Gourde","HUF":"Hungarian Forint","IDR":"Indonesian Rupiah","IEP":"Irish Pound","ILP":"Israeli Pound","ILR":"Israeli Shekel (1980–1985)","ILS":"Israeli New Shekel","INR":"Indian Rupee","IQD":"Iraqi Dinar","IRR":"Iranian Rial","ISJ":"Icelandic Króna (1918–1981)","ISK":"Icelandic Króna","ITL":"Italian Lira","JMD":"Jamaican Dollar","JOD":"Jordanian Dinar","JPY":"Japanese Yen","KES":"Kenyan Shilling","KGS":"Kyrgystani Som","KHR":"Cambodian Riel","KMF":"Comorian Franc","KPW":"North Korean Won","KRH":"South Korean Hwan (1953–1962)","KRO":"South Korean Won (1945–1953)","KRW":"South Korean Won","KWD":"Kuwaiti Dinar","KYD":"Cayman Islands Dollar","KZT":"Kazakhstani Tenge","LAK":"Laotian Kip","LBP":"Lebanese Pound","LKR":"Sri Lankan Rupee","LRD":"Liberian Dollar","LSL":"Lesotho Loti","LTL":"Lithuanian Litas","LTT":"Lithuanian Talonas","LUC":"Luxembourgian Convertible Franc","LUF":"Luxembourgian Franc","LUL":"Luxembourg Financial Franc","LVL":"Latvian Lats","LVR":"Latvian Ruble","LYD":"Libyan Dinar","MAD":"Moroccan Dirham","MAF":"Moroccan Franc","MCF":"Monegasque Franc","MDC":"Moldovan Cupon","MDL":"Moldovan Leu","MGA":"Malagasy Ariary","MGF":"Malagasy Franc","MKD":"Macedonian Denar","MKN":"Macedonian Denar (1992–1993)","MLF":"Malian Franc","MMK":"Myanmar Kyat","MNT":"Mongolian Tugrik","MOP":"Macanese Pataca","MRO":"Mauritanian Ouguiya (1973–2017)","MRU":"Mauritanian Ouguiya","MTL":"Maltese Lira","MTP":"Maltese Pound","MUR":"Mauritian Rupee","MVP":"Maldivian Rupee (1947–1981)","MVR":"Maldivian Rufiyaa","MWK":"Malawian Kwacha","MXN":"Mexican Peso","MXP":"Mexican Silver Peso (1861–1992)","MXV":"Mexican Investment Unit","MYR":"Malaysian Ringgit","MZE":"Mozambican Escudo","MZM":"Mozambican Metical (1980–2006)","MZN":"Mozambican Metical","NAD":"Namibian Dollar","NGN":"Nigerian Naira","NIC":"Nicaraguan Córdoba (1988–1991)","NIO":"Nicaraguan Córdoba","NLG":"Dutch Guilder","NOK":"Norwegian Krone","NPR":"Nepalese Rupee","NZD":"New Zealand Dollar","OMR":"Omani Rial","PAB":"Panamanian Balboa","PEI":"Peruvian Inti","PEN":"Peruvian Sol","PES":"Peruvian Sol (1863–1965)","PGK":"Papua New Guinean Kina","PHP":"Philippine Piso","PKR":"Pakistani Rupee","PLN":"Polish Zloty","PLZ":"Polish Zloty (1950–1995)","PTE":"Portuguese Escudo","PYG":"Paraguayan Guarani","QAR":"Qatari Rial","RHD":"Rhodesian Dollar","ROL":"Romanian Leu (1952–2006)","RON":"Romanian Leu","RSD":"Serbian Dinar","RUB":"Russian Ruble","RUR":"Russian Ruble (1991–1998)","RWF":"Rwandan Franc","SAR":"Saudi Riyal","SBD":"Solomon Islands Dollar","SCR":"Seychellois Rupee","SDD":"Sudanese Dinar (1992–2007)","SDG":"Sudanese Pound","SDP":"Sudanese Pound (1957–1998)","SEK":"Swedish Krona","SGD":"Singapore Dollar","SHP":"St. Helena Pound","SIT":"Slovenian Tolar","SKK":"Slovak Koruna","SLL":"Sierra Leonean Leone","SOS":"Somali Shilling","SRD":"Surinamese Dollar","SRG":"Surinamese Guilder","SSP":"South Sudanese Pound","STD":"São Tomé & Príncipe Dobra (1977–2017)","STN":"São Tomé & Príncipe Dobra","SUR":"Soviet Rouble","SVC":"Salvadoran Colón","SYP":"Syrian Pound","SZL":"Swazi Lilangeni","THB":"Thai Baht","TJR":"Tajikistani Ruble","TJS":"Tajikistani Somoni","TMM":"Turkmenistani Manat (1993–2009)","TMT":"Turkmenistani Manat","TND":"Tunisian Dinar","TOP":"Tongan Paʻanga","TPE":"Timorese Escudo","TRL":"Turkish Lira (1922–2005)","TRY":"Turkish Lira","TTD":"Trinidad & Tobago Dollar","TWD":"New Taiwan Dollar","TZS":"Tanzanian Shilling","UAH":"Ukrainian Hryvnia","UAK":"Ukrainian Karbovanets","UGS":"Ugandan Shilling (1966–1987)","UGX":"Ugandan Shilling","USD":"US Dollar","USN":"US Dollar (Next day)","USS":"US Dollar (Same day)","UYI":"Uruguayan Peso (Indexed Units)","UYP":"Uruguayan Peso (1975–1993)","UYU":"Uruguayan Peso","UYW":"Uruguayan Nominal Wage Index Unit","UZS":"Uzbekistani Som","VEB":"Venezuelan Bolívar (1871–2008)","VEF":"Venezuelan Bolívar (2008–2018)","VES":"Venezuelan Bolívar","VND":"Vietnamese Dong","VNN":"Vietnamese Dong (1978–1985)","VUV":"Vanuatu Vatu","WST":"Samoan Tala","XAF":"Central African CFA Franc","XAG":"Silver","XAU":"Gold","XBA":"European Composite Unit","XBB":"European Monetary Unit","XBC":"European Unit of Account (XBC)","XBD":"European Unit of Account (XBD)","XCD":"East Caribbean Dollar","XDR":"Special Drawing Rights","XEU":"European Currency Unit","XFO":"French Gold Franc","XFU":"French UIC-Franc","XOF":"West African CFA Franc","XPD":"Palladium","XPF":"CFP Franc","XPT":"Platinum","XRE":"RINET Funds","XSU":"Sucre","XTS":"Testing Currency Code","XUA":"ADB Unit of Account","XXX":"Unknown Currency","YDD":"Yemeni Dinar","YER":"Yemeni Rial","YUD":"Yugoslavian Hard Dinar (1966–1990)","YUM":"Yugoslavian New Dinar (1994–2002)","YUN":"Yugoslavian Convertible Dinar (1990–1992)","YUR":"Yugoslavian Reformed Dinar (1992–1993)","ZAL":"South African Rand (financial)","ZAR":"South African Rand","ZMK":"Zambian Kwacha (1968–2012)","ZMW":"Zambian Kwacha","ZRN":"Zairean New Zaire (1993–1998)","ZRZ":"Zairean Zaire (1971–1993)","ZWD":"Zimbabwean Dollar (1980–2008)","ZWL":"Zimbabwean Dollar (2009)","ZWR":"Zimbabwean Dollar (2008)"},"short":{},"narrow":{}}},"patterns":{"locale":"{0} ({1})"}}},"availableLocales":["en"],"aliases":{},"parentLocales":{"en-150":"en-001","en-AG":"en-001","en-AI":"en-001","en-AU":"en-001","en-BB":"en-001","en-BM":"en-001","en-BS":"en-001","en-BW":"en-001","en-BZ":"en-001","en-CA":"en-001","en-CC":"en-001","en-CK":"en-001","en-CM":"en-001","en-CX":"en-001","en-CY":"en-001","en-DG":"en-001","en-DM":"en-001","en-ER":"en-001","en-FJ":"en-001","en-FK":"en-001","en-FM":"en-001","en-GB":"en-001","en-GD":"en-001","en-GG":"en-001","en-GH":"en-001","en-GI":"en-001","en-GM":"en-001","en-GY":"en-001","en-HK":"en-001","en-IE":"en-001","en-IL":"en-001","en-IM":"en-001","en-IN":"en-001","en-IO":"en-001","en-JE":"en-001","en-JM":"en-001","en-KE":"en-001","en-KI":"en-001","en-KN":"en-001","en-KY":"en-001","en-LC":"en-001","en-LR":"en-001","en-LS":"en-001","en-MG":"en-001","en-MO":"en-001","en-MS":"en-001","en-MT":"en-001","en-MU":"en-001","en-MW":"en-001","en-MY":"en-001","en-NA":"en-001","en-NF":"en-001","en-NG":"en-001","en-NR":"en-001","en-NU":"en-001","en-NZ":"en-001","en-PG":"en-001","en-PH":"en-001","en-PK":"en-001","en-PN":"en-001","en-PW":"en-001","en-RW":"en-001","en-SB":"en-001","en-SC":"en-001","en-SD":"en-001","en-SG":"en-001","en-SH":"en-001","en-SL":"en-001","en-SS":"en-001","en-SX":"en-001","en-SZ":"en-001","en-TC":"en-001","en-TK":"en-001","en-TO":"en-001","en-TT":"en-001","en-TV":"en-001","en-TZ":"en-001","en-UG":"en-001","en-VC":"en-001","en-VG":"en-001","en-VU":"en-001","en-WS":"en-001","en-ZA":"en-001","en-ZM":"en-001","en-ZW":"en-001","en-AT":"en-150","en-BE":"en-150","en-CH":"en-150","en-DE":"en-150","en-DK":"en-150","en-FI":"en-150","en-NL":"en-150","en-SE":"en-150","en-SI":"en-150"}},
    {"data":{},"availableLocales":["en-US-POSIX"],"aliases":{},"parentLocales":{"en-150":"en-001","en-AG":"en-001","en-AI":"en-001","en-AU":"en-001","en-BB":"en-001","en-BM":"en-001","en-BS":"en-001","en-BW":"en-001","en-BZ":"en-001","en-CA":"en-001","en-CC":"en-001","en-CK":"en-001","en-CM":"en-001","en-CX":"en-001","en-CY":"en-001","en-DG":"en-001","en-DM":"en-001","en-ER":"en-001","en-FJ":"en-001","en-FK":"en-001","en-FM":"en-001","en-GB":"en-001","en-GD":"en-001","en-GG":"en-001","en-GH":"en-001","en-GI":"en-001","en-GM":"en-001","en-GY":"en-001","en-HK":"en-001","en-IE":"en-001","en-IL":"en-001","en-IM":"en-001","en-IN":"en-001","en-IO":"en-001","en-JE":"en-001","en-JM":"en-001","en-KE":"en-001","en-KI":"en-001","en-KN":"en-001","en-KY":"en-001","en-LC":"en-001","en-LR":"en-001","en-LS":"en-001","en-MG":"en-001","en-MO":"en-001","en-MS":"en-001","en-MT":"en-001","en-MU":"en-001","en-MW":"en-001","en-MY":"en-001","en-NA":"en-001","en-NF":"en-001","en-NG":"en-001","en-NR":"en-001","en-NU":"en-001","en-NZ":"en-001","en-PG":"en-001","en-PH":"en-001","en-PK":"en-001","en-PN":"en-001","en-PW":"en-001","en-RW":"en-001","en-SB":"en-001","en-SC":"en-001","en-SD":"en-001","en-SG":"en-001","en-SH":"en-001","en-SL":"en-001","en-SS":"en-001","en-SX":"en-001","en-SZ":"en-001","en-TC":"en-001","en-TK":"en-001","en-TO":"en-001","en-TT":"en-001","en-TV":"en-001","en-TZ":"en-001","en-UG":"en-001","en-VC":"en-001","en-VG":"en-001","en-VU":"en-001","en-WS":"en-001","en-ZA":"en-001","en-ZM":"en-001","en-ZW":"en-001","en-AT":"en-150","en-BE":"en-150","en-CH":"en-150","en-DE":"en-150","en-DK":"en-150","en-FI":"en-150","en-NL":"en-150","en-SE":"en-150","en-SI":"en-150"}},
    {"data":{"ja":{"types":{"language":{"long":{"aa":"アファル語","ab":"アブハズ語","ace":"アチェ語","ach":"アチョリ語","ada":"アダングメ語","ady":"アディゲ語","ae":"アヴェスタ語","aeb":"チュニジア・アラビア語","af":"アフリカーンス語","afh":"アフリヒリ語","agq":"アゲム語","ain":"アイヌ語","ak":"アカン語","akk":"アッカド語","akz":"アラバマ語","ale":"アレウト語","aln":"ゲグ・アルバニア語","alt":"南アルタイ語","am":"アムハラ語","an":"アラゴン語","ang":"古英語","anp":"アンギカ語","ar":"アラビア語","ar-001":"現代標準アラビア語","arc":"アラム語","arn":"マプチェ語","aro":"アラオナ語","arp":"アラパホー語","arq":"アルジェリア・アラビア語","ars":"ナジュド地方・アラビア語","arw":"アラワク語","ary":"モロッコ・アラビア語","arz":"エジプト・アラビア語","as":"アッサム語","asa":"アス語","ase":"アメリカ手話","ast":"アストゥリアス語","av":"アヴァル語","avk":"コタヴァ","awa":"アワディー語","ay":"アイマラ語","az":"アゼルバイジャン語","ba":"バシキール語","bal":"バルーチー語","ban":"バリ語","bar":"バイエルン・オーストリア語","bas":"バサ語","bax":"バムン語","bbc":"トバ・バタク語","bbj":"ゴーマラ語","be":"ベラルーシ語","bej":"ベジャ語","bem":"ベンバ語","bew":"ベタウィ語","bez":"ベナ語","bfd":"バフット語","bfq":"バダガ語","bg":"ブルガリア語","bgn":"西バローチー語","bho":"ボージュプリー語","bi":"ビスラマ語","bik":"ビコル語","bin":"ビニ語","bjn":"バンジャル語","bkm":"コム語","bla":"シクシカ語","bm":"バンバラ語","bn":"ベンガル語","bo":"チベット語","bpy":"ビシュヌプリヤ・マニプリ語","bqi":"バフティヤーリー語","br":"ブルトン語","bra":"ブラジ語","brh":"ブラフイ語","brx":"ボド語","bs":"ボスニア語","bss":"アコース語","bua":"ブリヤート語","bug":"ブギ語","bum":"ブル語","byn":"ビリン語","byv":"メドゥンバ語","ca":"カタロニア語","cad":"カドー語","car":"カリブ語","cay":"カユーガ語","cch":"チャワイ語","ccp":"チャクマ語","ce":"チェチェン語","ceb":"セブアノ語","cgg":"チガ語","ch":"チャモロ語","chb":"チブチャ語","chg":"チャガタイ語","chk":"チューク語","chm":"マリ語","chn":"チヌーク混成語","cho":"チョクトー語","chp":"チペワイアン語","chr":"チェロキー語","chy":"シャイアン語","ckb":"中央クルド語","co":"コルシカ語","cop":"コプト語","cps":"カピス語","cr":"クリー語","crh":"クリミア・タタール語","crs":"セーシェル・クレオール語","cs":"チェコ語","csb":"カシューブ語","cu":"教会スラブ語","cv":"チュヴァシ語","cy":"ウェールズ語","da":"デンマーク語","dak":"ダコタ語","dar":"ダルグワ語","dav":"タイタ語","de":"ドイツ語","de-AT":"ドイツ語 (オーストリア)","de-CH":"標準ドイツ語 (スイス)","del":"デラウェア語","den":"スレイビー語","dgr":"ドグリブ語","din":"ディンカ語","dje":"ザルマ語","doi":"ドーグリー語","dsb":"低地ソルブ語","dtp":"中央ドゥスン語","dua":"ドゥアラ語","dum":"中世オランダ語","dv":"ディベヒ語","dyo":"ジョラ＝フォニィ語","dyu":"ジュラ語","dz":"ゾンカ語","dzg":"ダザガ語","ebu":"エンブ語","ee":"エウェ語","efi":"エフィク語","egl":"エミリア語","egy":"古代エジプト語","eka":"エカジュク語","el":"ギリシャ語","elx":"エラム語","en":"英語","en-AU":"オーストラリア英語","en-CA":"カナダ英語","en-GB":"イギリス英語","en-US":"アメリカ英語","enm":"中英語","eo":"エスペラント語","es":"スペイン語","es-419":"スペイン語 (ラテンアメリカ)","es-ES":"スペイン語 (イベリア半島)","es-MX":"スペイン語 (メキシコ)","esu":"中央アラスカ・ユピック語","et":"エストニア語","eu":"バスク語","ewo":"エウォンド語","ext":"エストレマドゥーラ語","fa":"ペルシア語","fan":"ファング語","fat":"ファンティー語","ff":"フラ語","fi":"フィンランド語","fil":"フィリピノ語","fit":"トルネダール・フィンランド語","fj":"フィジー語","fo":"フェロー語","fon":"フォン語","fr":"フランス語","fr-CA":"フランス語 (カナダ)","fr-CH":"フランス語 (スイス)","frc":"ケイジャン・フランス語","frm":"中期フランス語","fro":"古フランス語","frp":"アルピタン語","frr":"北フリジア語","frs":"東フリジア語","fur":"フリウリ語","fy":"西フリジア語","ga":"アイルランド語","gaa":"ガ語","gag":"ガガウズ語","gan":"贛語","gay":"ガヨ語","gba":"バヤ語","gbz":"ダリー語(ゾロアスター教)","gd":"スコットランド・ゲール語","gez":"ゲエズ語","gil":"キリバス語","gl":"ガリシア語","glk":"ギラキ語","gmh":"中高ドイツ語","gn":"グアラニー語","goh":"古高ドイツ語","gom":"ゴア・コンカニ語","gon":"ゴーンディー語","gor":"ゴロンタロ語","got":"ゴート語","grb":"グレボ語","grc":"古代ギリシャ語","gsw":"スイスドイツ語","gu":"グジャラート語","guc":"ワユ語","gur":"フラフラ語","guz":"グシイ語","gv":"マン島語","gwi":"グウィッチン語","ha":"ハウサ語","hai":"ハイダ語","hak":"客家語","haw":"ハワイ語","he":"ヘブライ語","hi":"ヒンディー語","hif":"フィジー・ヒンディー語","hil":"ヒリガイノン語","hit":"ヒッタイト語","hmn":"フモン語","ho":"ヒリモツ語","hr":"クロアチア語","hsb":"高地ソルブ語","hsn":"湘語","ht":"ハイチ・クレオール語","hu":"ハンガリー語","hup":"フパ語","hy":"アルメニア語","hz":"ヘレロ語","ia":"インターリングア","iba":"イバン語","ibb":"イビビオ語","id":"インドネシア語","ie":"インターリング","ig":"イボ語","ii":"四川イ語","ik":"イヌピアック語","ilo":"イロカノ語","inh":"イングーシ語","io":"イド語","is":"アイスランド語","it":"イタリア語","iu":"イヌクティトット語","izh":"イングリア語","ja":"日本語","jam":"ジャマイカ・クレオール語","jbo":"ロジバン語","jgo":"ンゴンバ語","jmc":"マチャメ語","jpr":"ユダヤ・ペルシア語","jrb":"ユダヤ・アラビア語","jut":"ユトランド語","jv":"ジャワ語","ka":"ジョージア語","kaa":"カラカルパク語","kab":"カビル語","kac":"カチン語","kaj":"カジェ語","kam":"カンバ語","kaw":"カウィ語","kbd":"カバルド語","kbl":"カネンブ語","kcg":"カタブ語","kde":"マコンデ語","kea":"カーボベルデ・クレオール語","ken":"ニャン語","kfo":"コロ語","kg":"コンゴ語","kgp":"カインガング語","kha":"カシ語","kho":"コータン語","khq":"コイラ・チーニ語","khw":"コワール語","ki":"キクユ語","kiu":"キルマンジュキ語","kj":"クワニャマ語","kk":"カザフ語","kkj":"カコ語","kl":"グリーンランド語","kln":"カレンジン語","km":"クメール語","kmb":"キンブンド語","kn":"カンナダ語","ko":"韓国語","koi":"コミ・ペルミャク語","kok":"コンカニ語","kos":"コスラエ語","kpe":"クペレ語","kr":"カヌリ語","krc":"カラチャイ・バルカル語","kri":"クリオ語","krj":"キナライア語","krl":"カレリア語","kru":"クルク語","ks":"カシミール語","ksb":"サンバー語","ksf":"バフィア語","ksh":"ケルン語","ku":"クルド語","kum":"クムク語","kut":"クテナイ語","kv":"コミ語","kw":"コーンウォール語","ky":"キルギス語","la":"ラテン語","lad":"ラディノ語","lag":"ランギ語","lah":"ラフンダー語","lam":"ランバ語","lb":"ルクセンブルク語","lez":"レズギ語","lfn":"リングア・フランカ・ノバ","lg":"ガンダ語","li":"リンブルフ語","lij":"リグリア語","liv":"リヴォニア語","lkt":"ラコタ語","lmo":"ロンバルド語","ln":"リンガラ語","lo":"ラオ語","lol":"モンゴ語","lou":"ルイジアナ・クレオール語","loz":"ロジ語","lrc":"北ロル語","lt":"リトアニア語","ltg":"ラトガリア語","lu":"ルバ・カタンガ語","lua":"ルバ・ルルア語","lui":"ルイセーニョ語","lun":"ルンダ語","luo":"ルオ語","lus":"ミゾ語","luy":"ルヒヤ語","lv":"ラトビア語","lzh":"漢文","lzz":"ラズ語","mad":"マドゥラ語","maf":"マファ語","mag":"マガヒー語","mai":"マイティリー語","mak":"マカッサル語","man":"マンディンゴ語","mas":"マサイ語","mde":"マバ語","mdf":"モクシャ語","mdr":"マンダル語","men":"メンデ語","mer":"メル語","mfe":"モーリシャス・クレオール語","mg":"マダガスカル語","mga":"中期アイルランド語","mgh":"マクア・ミート語","mgo":"メタ語","mh":"マーシャル語","mi":"マオリ語","mic":"ミクマク語","min":"ミナンカバウ語","mk":"マケドニア語","ml":"マラヤーラム語","mn":"モンゴル語","mnc":"満州語","mni":"マニプリ語","moh":"モーホーク語","mos":"モシ語","mr":"マラーティー語","mrj":"山地マリ語","ms":"マレー語","mt":"マルタ語","mua":"ムンダン語","mul":"複数言語","mus":"クリーク語","mwl":"ミランダ語","mwr":"マールワーリー語","mwv":"メンタワイ語","my":"ミャンマー語","mye":"ミエネ語","myv":"エルジャ語","mzn":"マーザンダラーン語","na":"ナウル語","nan":"閩南語","nap":"ナポリ語","naq":"ナマ語","nb":"ノルウェー語(ブークモール)","nd":"北ンデベレ語","nds":"低地ドイツ語","nds-NL":"低地ドイツ語 (オランダ)","ne":"ネパール語","new":"ネワール語","ng":"ンドンガ語","nia":"ニアス語","niu":"ニウーエイ語","njo":"アオ・ナガ語","nl":"オランダ語","nl-BE":"フレミッシュ語","nmg":"クワシオ語","nn":"ノルウェー語(ニーノシュク)","nnh":"ンジエムブーン語","no":"ノルウェー語","nog":"ノガイ語","non":"古ノルド語","nov":"ノヴィアル","nqo":"ンコ語","nr":"南ンデベレ語","nso":"北部ソト語","nus":"ヌエル語","nv":"ナバホ語","nwc":"古典ネワール語","ny":"ニャンジャ語","nym":"ニャムウェジ語","nyn":"ニャンコレ語","nyo":"ニョロ語","nzi":"ンゼマ語","oc":"オック語","oj":"オジブウェー語","om":"オロモ語","or":"オディア語","os":"オセット語","osa":"オセージ語","ota":"オスマントルコ語","pa":"パンジャブ語","pag":"パンガシナン語","pal":"パフラヴィー語","pam":"パンパンガ語","pap":"パピアメント語","pau":"パラオ語","pcd":"ピカルディ語","pcm":"ナイジェリア・ピジン語","pdc":"ペンシルベニア・ドイツ語","pdt":"メノナイト低地ドイツ語","peo":"古代ペルシア語","pfl":"プファルツ語","phn":"フェニキア語","pi":"パーリ語","pl":"ポーランド語","pms":"ピエモンテ語","pnt":"ポントス・ギリシャ語","pon":"ポンペイ語","prg":"プロシア語","pro":"古期プロバンス語","ps":"パシュトゥー語","pt":"ポルトガル語","pt-BR":"ポルトガル語 (ブラジル)","pt-PT":"ポルトガル語 (イベリア半島)","qu":"ケチュア語","quc":"キチェ語","qug":"チンボラソ高地ケチュア語","raj":"ラージャスターン語","rap":"ラパヌイ語","rar":"ラロトンガ語","rgn":"ロマーニャ語","rif":"リーフ語","rm":"ロマンシュ語","rn":"ルンディ語","ro":"ルーマニア語","ro-MD":"モルダビア語","rof":"ロンボ語","rom":"ロマーニー語","root":"ルート","rtm":"ロツマ語","ru":"ロシア語","rue":"ルシン語","rug":"ロヴィアナ語","rup":"アルーマニア語","rw":"キニアルワンダ語","rwk":"ルワ語","sa":"サンスクリット語","sad":"サンダウェ語","sah":"サハ語","sam":"サマリア・アラム語","saq":"サンブル語","sas":"ササク語","sat":"サンターリー語","saz":"サウラーシュトラ語","sba":"ンガムバイ語","sbp":"サング語","sc":"サルデーニャ語","scn":"シチリア語","sco":"スコットランド語","sd":"シンド語","sdc":"サッサリ・サルデーニャ語","sdh":"南部クルド語","se":"北サーミ語","see":"セネカ語","seh":"セナ語","sei":"セリ語","sel":"セリクプ語","ses":"コイラボロ・センニ語","sg":"サンゴ語","sga":"古アイルランド語","sgs":"サモギティア語","sh":"セルボ・クロアチア語","shi":"タシルハイト語","shn":"シャン語","shu":"チャド・アラビア語","si":"シンハラ語","sid":"シダモ語","sk":"スロバキア語","sl":"スロベニア語","sli":"低シレジア語","sly":"スラヤール語","sm":"サモア語","sma":"南サーミ語","smj":"ルレ・サーミ語","smn":"イナリ・サーミ語","sms":"スコルト・サーミ語","sn":"ショナ語","snk":"ソニンケ語","so":"ソマリ語","sog":"ソグド語","sq":"アルバニア語","sr":"セルビア語","srn":"スリナム語","srr":"セレル語","ss":"スワジ語","ssy":"サホ語","st":"南部ソト語","stq":"ザーターフリジア語","su":"スンダ語","suk":"スクマ語","sus":"スス語","sux":"シュメール語","sv":"スウェーデン語","sw":"スワヒリ語","sw-CD":"コンゴ・スワヒリ語","swb":"コモロ語","syc":"古典シリア語","syr":"シリア語","szl":"シレジア語","ta":"タミル語","tcy":"トゥル語","te":"テルグ語","tem":"テムネ語","teo":"テソ語","ter":"テレーノ語","tet":"テトゥン語","tg":"タジク語","th":"タイ語","ti":"ティグリニア語","tig":"ティグレ語","tiv":"ティブ語","tk":"トルクメン語","tkl":"トケラウ語","tkr":"ツァフル語","tl":"タガログ語","tlh":"クリンゴン語","tli":"トリンギット語","tly":"タリシュ語","tmh":"タマシェク語","tn":"ツワナ語","to":"トンガ語","tog":"トンガ語(ニアサ)","tpi":"トク・ピシン語","tr":"トルコ語","tru":"トゥロヨ語","trv":"タロコ語","ts":"ツォンガ語","tsd":"ツァコン語","tsi":"チムシュ語","tt":"タタール語","ttt":"ムスリム・タタール語","tum":"トゥンブカ語","tvl":"ツバル語","tw":"トウィ語","twq":"タサワク語","ty":"タヒチ語","tyv":"トゥヴァ語","tzm":"中央アトラス・タマジクト語","udm":"ウドムルト語","ug":"ウイグル語","uga":"ウガリト語","uk":"ウクライナ語","umb":"ムブンドゥ語","und":"言語不明","ur":"ウルドゥー語","uz":"ウズベク語","vai":"ヴァイ語","ve":"ベンダ語","vec":"ヴェネト語","vep":"ヴェプス語","vi":"ベトナム語","vls":"西フラマン語","vmf":"マインフランク語","vo":"ヴォラピュク語","vot":"ヴォート語","vro":"ヴォロ語","vun":"ヴンジョ語","wa":"ワロン語","wae":"ヴァリス語","wal":"ウォライタ語","war":"ワライ語","was":"ワショ語","wbp":"ワルピリ語","wo":"ウォロフ語","wuu":"呉語","xal":"カルムイク語","xh":"コサ語","xmf":"メグレル語","xog":"ソガ語","yao":"ヤオ語","yap":"ヤップ語","yav":"ヤンベン語","ybb":"イエンバ語","yi":"イディッシュ語","yo":"ヨルバ語","yrl":"ニェエンガトゥ語","yue":"広東語","za":"チワン語","zap":"サポテカ語","zbl":"ブリスシンボル","zea":"ゼーラント語","zen":"ゼナガ語","zgh":"標準モロッコ タマジクト語","zh":"中国語","zh-Hans":"簡体中国語","zh-Hant":"繁体中国語","zu":"ズールー語","zun":"ズニ語","zxx":"言語的内容なし","zza":"ザザ語"},"short":{"az":"アゼリー語","en-GB":"英語(英国)","en-US":"英語(米国)"},"narrow":{}},"region":{"long":{"142":"アジア","143":"中央アジア","145":"西アジア","150":"ヨーロッパ","151":"東ヨーロッパ","154":"北ヨーロッパ","155":"西ヨーロッパ","202":"サブサハラアフリカ","419":"ラテンアメリカ","001":"世界","002":"アフリカ","003":"北アメリカ大陸","005":"南アメリカ","009":"オセアニア","011":"西アフリカ","013":"中央アメリカ","014":"東アフリカ","015":"北アフリカ","017":"中部アフリカ","018":"南部アフリカ","019":"アメリカ大陸","021":"北アメリカ","029":"カリブ","030":"東アジア","034":"南アジア","035":"東南アジア","039":"南ヨーロッパ","053":"オーストララシア","054":"メラネシア","057":"ミクロネシア","061":"ポリネシア","AC":"アセンション島","AD":"アンドラ","AE":"アラブ首長国連邦","AF":"アフガニスタン","AG":"アンティグア・バーブーダ","AI":"アンギラ","AL":"アルバニア","AM":"アルメニア","AO":"アンゴラ","AQ":"南極","AR":"アルゼンチン","AS":"米領サモア","AT":"オーストリア","AU":"オーストラリア","AW":"アルバ","AX":"オーランド諸島","AZ":"アゼルバイジャン","BA":"ボスニア・ヘルツェゴビナ","BB":"バルバドス","BD":"バングラデシュ","BE":"ベルギー","BF":"ブルキナファソ","BG":"ブルガリア","BH":"バーレーン","BI":"ブルンジ","BJ":"ベナン","BL":"サン・バルテルミー","BM":"バミューダ","BN":"ブルネイ","BO":"ボリビア","BQ":"オランダ領カリブ","BR":"ブラジル","BS":"バハマ","BT":"ブータン","BV":"ブーベ島","BW":"ボツワナ","BY":"ベラルーシ","BZ":"ベリーズ","CA":"カナダ","CC":"ココス(キーリング)諸島","CD":"コンゴ民主共和国(キンシャサ)","CF":"中央アフリカ共和国","CG":"コンゴ共和国(ブラザビル)","CH":"スイス","CI":"コートジボワール","CK":"クック諸島","CL":"チリ","CM":"カメルーン","CN":"中国","CO":"コロンビア","CP":"クリッパートン島","CR":"コスタリカ","CU":"キューバ","CV":"カーボベルデ","CW":"キュラソー","CX":"クリスマス島","CY":"キプロス","CZ":"チェコ","DE":"ドイツ","DG":"ディエゴガルシア島","DJ":"ジブチ","DK":"デンマーク","DM":"ドミニカ国","DO":"ドミニカ共和国","DZ":"アルジェリア","EA":"セウタ・メリリャ","EC":"エクアドル","EE":"エストニア","EG":"エジプト","EH":"西サハラ","ER":"エリトリア","ES":"スペイン","ET":"エチオピア","EU":"欧州連合","EZ":"ユーロ圏","FI":"フィンランド","FJ":"フィジー","FK":"フォークランド諸島","FM":"ミクロネシア連邦","FO":"フェロー諸島","FR":"フランス","GA":"ガボン","GB":"イギリス","GD":"グレナダ","GE":"ジョージア","GF":"仏領ギアナ","GG":"ガーンジー","GH":"ガーナ","GI":"ジブラルタル","GL":"グリーンランド","GM":"ガンビア","GN":"ギニア","GP":"グアドループ","GQ":"赤道ギニア","GR":"ギリシャ","GS":"サウスジョージア・サウスサンドウィッチ諸島","GT":"グアテマラ","GU":"グアム","GW":"ギニアビサウ","GY":"ガイアナ","HK":"中華人民共和国香港特別行政区","HM":"ハード島・マクドナルド諸島","HN":"ホンジュラス","HR":"クロアチア","HT":"ハイチ","HU":"ハンガリー","IC":"カナリア諸島","ID":"インドネシア","IE":"アイルランド","IL":"イスラエル","IM":"マン島","IN":"インド","IO":"英領インド洋地域","IQ":"イラク","IR":"イラン","IS":"アイスランド","IT":"イタリア","JE":"ジャージー","JM":"ジャマイカ","JO":"ヨルダン","JP":"日本","KE":"ケニア","KG":"キルギス","KH":"カンボジア","KI":"キリバス","KM":"コモロ","KN":"セントクリストファー・ネーヴィス","KP":"北朝鮮","KR":"韓国","KW":"クウェート","KY":"ケイマン諸島","KZ":"カザフスタン","LA":"ラオス","LB":"レバノン","LC":"セントルシア","LI":"リヒテンシュタイン","LK":"スリランカ","LR":"リベリア","LS":"レソト","LT":"リトアニア","LU":"ルクセンブルク","LV":"ラトビア","LY":"リビア","MA":"モロッコ","MC":"モナコ","MD":"モルドバ","ME":"モンテネグロ","MF":"サン・マルタン","MG":"マダガスカル","MH":"マーシャル諸島","MK":"北マケドニア","ML":"マリ","MM":"ミャンマー (ビルマ)","MN":"モンゴル","MO":"中華人民共和国マカオ特別行政区","MP":"北マリアナ諸島","MQ":"マルティニーク","MR":"モーリタニア","MS":"モントセラト","MT":"マルタ","MU":"モーリシャス","MV":"モルディブ","MW":"マラウイ","MX":"メキシコ","MY":"マレーシア","MZ":"モザンビーク","NA":"ナミビア","NC":"ニューカレドニア","NE":"ニジェール","NF":"ノーフォーク島","NG":"ナイジェリア","NI":"ニカラグア","NL":"オランダ","NO":"ノルウェー","NP":"ネパール","NR":"ナウル","NU":"ニウエ","NZ":"ニュージーランド","OM":"オマーン","PA":"パナマ","PE":"ペルー","PF":"仏領ポリネシア","PG":"パプアニューギニア","PH":"フィリピン","PK":"パキスタン","PL":"ポーランド","PM":"サンピエール島・ミクロン島","PN":"ピトケアン諸島","PR":"プエルトリコ","PS":"パレスチナ自治区","PT":"ポルトガル","PW":"パラオ","PY":"パラグアイ","QA":"カタール","QO":"オセアニア周辺地域","RE":"レユニオン","RO":"ルーマニア","RS":"セルビア","RU":"ロシア","RW":"ルワンダ","SA":"サウジアラビア","SB":"ソロモン諸島","SC":"セーシェル","SD":"スーダン","SE":"スウェーデン","SG":"シンガポール","SH":"セントヘレナ","SI":"スロベニア","SJ":"スバールバル諸島・ヤンマイエン島","SK":"スロバキア","SL":"シエラレオネ","SM":"サンマリノ","SN":"セネガル","SO":"ソマリア","SR":"スリナム","SS":"南スーダン","ST":"サントメ・プリンシペ","SV":"エルサルバドル","SX":"シント・マールテン","SY":"シリア","SZ":"エスワティニ","TA":"トリスタン・ダ・クーニャ","TC":"タークス・カイコス諸島","TD":"チャド","TF":"仏領極南諸島","TG":"トーゴ","TH":"タイ","TJ":"タジキスタン","TK":"トケラウ","TL":"東ティモール","TM":"トルクメニスタン","TN":"チュニジア","TO":"トンガ","TR":"トルコ","TT":"トリニダード・トバゴ","TV":"ツバル","TW":"台湾","TZ":"タンザニア","UA":"ウクライナ","UG":"ウガンダ","UM":"合衆国領有小離島","UN":"国際連合","US":"アメリカ合衆国","UY":"ウルグアイ","UZ":"ウズベキスタン","VA":"バチカン市国","VC":"セントビンセント及びグレナディーン諸島","VE":"ベネズエラ","VG":"英領ヴァージン諸島","VI":"米領ヴァージン諸島","VN":"ベトナム","VU":"バヌアツ","WF":"ウォリス・フツナ","WS":"サモア","XA":"疑似アクセント","XB":"疑似 BIDI","XK":"コソボ","YE":"イエメン","YT":"マヨット","ZA":"南アフリカ","ZM":"ザンビア","ZW":"ジンバブエ","ZZ":"不明な地域"},"short":{"GB":"英国","HK":"香港","MO":"マカオ","PS":"パレスチナ","UN":"国連","US":"アメリカ"},"narrow":{}},"script":{"long":{"Adlm":"Adlm","Afak":"アファカ文字","Aghb":"カフカス・アルバニア文字","Ahom":"Ahom","Arab":"アラビア文字","Armi":"帝国アラム文字","Armn":"アルメニア文字","Avst":"アヴェスター文字","Bali":"バリ文字","Bamu":"バムン文字","Bass":"バサ文字","Batk":"バタク文字","Beng":"ベンガル文字","Bhks":"Bhks","Blis":"ブリスシンボル","Bopo":"注音字母","Brah":"ブラーフミー文字","Brai":"ブライユ点字","Bugi":"ブギス文字","Buhd":"ブヒッド文字","Cakm":"チャクマ文字","Cans":"統合カナダ先住民音節文字","Cari":"カリア文字","Cham":"チャム文字","Cher":"チェロキー文字","Cirt":"キアス文字","Copt":"コプト文字","Cprt":"キプロス文字","Cyrl":"キリル文字","Cyrs":"古代教会スラブ語キリル文字","Deva":"デーバナーガリー文字","Dogr":"Dogr","Dsrt":"デセレット文字","Dupl":"デュプロワエ式速記","Egyd":"エジプト民衆文字","Egyh":"エジプト神官文字","Egyp":"エジプト聖刻文字","Elba":"エルバサン文字","Elym":"Elym","Ethi":"エチオピア文字","Geok":"ジョージア文字(フツリ)","Geor":"ジョージア文字","Glag":"グラゴル文字","Gong":"Gong","Gonm":"Gonm","Goth":"ゴート文字","Gran":"グランタ文字","Grek":"ギリシャ文字","Gujr":"グジャラート文字","Guru":"グルムキー文字","Hanb":"漢語注音字母","Hang":"ハングル","Hani":"漢字","Hano":"ハヌノオ文字","Hans":"簡体字","Hant":"繁体字","Hatr":"Hatr","Hebr":"ヘブライ文字","Hira":"ひらがな","Hluw":"アナトリア象形文字","Hmng":"パハウ・フモン文字","Hmnp":"Hmnp","Hrkt":"仮名","Hung":"古代ハンガリー文字","Inds":"インダス文字","Ital":"古イタリア文字","Jamo":"字母","Java":"ジャワ文字","Jpan":"日本語の文字","Jurc":"女真文字","Kali":"カヤー文字","Kana":"カタカナ","Khar":"カローシュティー文字","Khmr":"クメール文字","Khoj":"ホジャ文字","Knda":"カンナダ文字","Kore":"韓国語の文字","Kpel":"クペレ文字","Kthi":"カイティ文字","Lana":"ラーンナー文字","Laoo":"ラオ文字","Latf":"ラテン文字(ドイツ文字)","Latg":"ラテン文字 (ゲール文字)","Latn":"ラテン文字","Lepc":"レプチャ文字","Limb":"リンブ文字","Lina":"線文字A","Linb":"線文字B","Lisu":"フレイザー文字","Loma":"ロマ文字","Lyci":"リキア文字","Lydi":"リディア文字","Mahj":"マハージャニー文字","Maka":"Maka","Mand":"マンダ文字","Mani":"マニ文字","Marc":"Marc","Maya":"マヤ象形文字","Medf":"Medf","Mend":"メンデ文字","Merc":"メロエ文字草書体","Mero":"メロエ文字","Mlym":"マラヤーラム文字","Modi":"モーディー文字","Mong":"モンゴル文字","Moon":"ムーン文字","Mroo":"ムロ文字","Mtei":"メイテイ文字","Mult":"Mult","Mymr":"ミャンマー文字","Nand":"Nand","Narb":"古代北アラビア文字","Nbat":"ナバテア文字","Newa":"Newa","Nkgb":"ナシ族ゲバ文字","Nkoo":"ンコ文字","Nshu":"女書","Ogam":"オガム文字","Olck":"オルチキ文字","Orkh":"オルホン文字","Orya":"オディア文字","Osge":"Osge","Osma":"オスマニア文字","Palm":"パルミラ文字","Pauc":"パウ・チン・ハウ文字","Perm":"古ぺルム文字","Phag":"パスパ文字","Phli":"碑文パフラヴィー文字","Phlp":"詩編用パフラヴィー文字","Phlv":"書物用パフラヴィー文字","Phnx":"フェニキア文字","Plrd":"ポラード音声記号","Prti":"碑文パルティア文字","Qaag":"Qaag","Rjng":"ルジャン文字","Rohg":"Rohg","Roro":"ロンゴロンゴ文字","Runr":"ルーン文字","Samr":"サマリア文字","Sara":"サラティ文字","Sarb":"古代南アラビア文字","Saur":"サウラーシュトラ文字","Sgnw":"手話文字","Shaw":"ショー文字","Shrd":"シャーラダー文字","Sidd":"梵字","Sind":"クダワディ文字","Sinh":"シンハラ文字","Sogd":"Sogd","Sogo":"Sogo","Sora":"ソラング・ソンペング文字","Soyo":"Soyo","Sund":"スンダ文字","Sylo":"シロティ・ナグリ文字","Syrc":"シリア文字","Syre":"シリア文字(エストランゲロ文字)","Syrj":"シリア文字(西方シリア文字)","Syrn":"シリア文字(東方シリア文字)","Tagb":"タグバンワ文字","Takr":"タークリー文字","Tale":"タイ・レ文字","Talu":"新タイ・ルー文字","Taml":"タミル文字","Tang":"西夏文字","Tavt":"タイ・ヴェト文字","Telu":"テルグ文字","Teng":"テングワール文字","Tfng":"ティフナグ文字","Tglg":"タガログ文字","Thaa":"ターナ文字","Thai":"タイ文字","Tibt":"チベット文字","Tirh":"ティルフータ文字","Ugar":"ウガリット文字","Vaii":"ヴァイ文字","Visp":"視話法","Wara":"バラン・クシティ文字","Wcho":"Wcho","Wole":"ウォレアイ文字","Xpeo":"古代ペルシア文字","Xsux":"シュメール＝アッカド語楔形文字","Yiii":"イ文字","Zanb":"Zanb","Zinh":"基底文字の種別を継承する結合文字","Zmth":"数学記号","Zsye":"絵文字","Zsym":"記号文字","Zxxx":"非表記","Zyyy":"共通文字","Zzzz":"不明な文字"},"short":{},"narrow":{}},"currency":{"long":{"ADP":"アンドラ ペセタ","AED":"アラブ首長国連邦ディルハム","AFA":"アフガニスタン アフガニー (1927–2002)","AFN":"アフガニスタン アフガニー","ALK":"アルバニア レク (1946–1965)","ALL":"アルバニア レク","AMD":"アルメニア ドラム","ANG":"オランダ領アンティル ギルダー","AOA":"アンゴラ クワンザ","AOK":"アンゴラ クワンザ (1977–1991)","AON":"アンゴラ 新クワンザ (1990–2000)","AOR":"アンゴラ 旧クワンザ (1995–1999)","ARA":"アルゼンチン アゥストラール","ARL":"アルゼンチン・ペソ・レイ（1970–1983）","ARM":"アルゼンチン・ペソ（1881–1970）","ARP":"アルゼンチン ペソ (1983–1985)","ARS":"アルゼンチン ペソ","ATS":"オーストリア シリング","AUD":"オーストラリア ドル","AWG":"アルバ ギルダー","AZM":"アゼルバイジャン マナト (1993–2006)","AZN":"アゼルバイジャン マナト","BAD":"ボスニア・ヘルツェゴビナ ディナール (1992–1994)","BAM":"ボスニア・ヘルツェゴビナ 兌換マルク (BAM)","BAN":"ボスニア・ヘルツェゴビナ 新ディナール（1994–1997）","BBD":"バルバドス ドル","BDT":"バングラデシュ タカ","BEC":"ベルギー フラン (BEC)","BEF":"ベルギー フラン","BEL":"ベルギー フラン (BEL)","BGL":"ブルガリア レフ","BGM":"ブルガリア社会主義 レフ","BGN":"ブルガリア 新レフ","BGO":"ブルガリア レフ（1879–1952）","BHD":"バーレーン ディナール","BIF":"ブルンジ フラン","BMD":"バミューダ ドル","BND":"ブルネイ ドル","BOB":"ボリビア ボリビアーノ","BOL":"ボリビア ボリビアーノ (1863–1963)","BOP":"ボリビア ペソ","BOV":"ボリビア (Mvdol)","BRB":"ブラジル 新クルゼイロ (1967–1986)","BRC":"ブラジル クルザード (1986–1989)","BRE":"ブラジル クルゼイロ (1990–1993)","BRL":"ブラジル レアル","BRN":"ブラジル 新クルザード (1989–1990)","BRR":"ブラジル クルゼイロ (1993–1994)","BRZ":"ブラジル クルゼイロ（1942–1967）","BSD":"バハマ ドル","BTN":"ブータン ニュルタム","BUK":"ビルマ チャット","BWP":"ボツワナ プラ","BYB":"ベラルーシ 新ルーブル (1994–1999)","BYN":"ベラルーシ ルーブル","BYR":"ベラルーシ ルーブル (2000–2016)","BZD":"ベリーズ ドル","CAD":"カナダ ドル","CDF":"コンゴ フラン","CHE":"ユーロ (WIR)","CHF":"スイス フラン","CHW":"フラン (WIR)","CLE":"チリ エスクード","CLF":"チリ ウニダ・デ・フォメント (UF)","CLP":"チリ ペソ","CNH":"中国人民元(オフショア)","CNX":"中国人民銀行ドル","CNY":"中国人民元","COP":"コロンビア ペソ","COU":"コロンビア レアル （UVR)","CRC":"コスタリカ コロン","CSD":"セルビア ディナール (2002–2006)","CSK":"チェコスロバキア コルナ","CUC":"キューバ 兌換ペソ","CUP":"キューバ ペソ","CVE":"カーボベルデ エスクード","CYP":"キプロス ポンド","CZK":"チェコ コルナ","DDM":"東ドイツ マルク","DEM":"ドイツ マルク","DJF":"ジブチ フラン","DKK":"デンマーク クローネ","DOP":"ドミニカ ペソ","DZD":"アルジェリア ディナール","ECS":"エクアドル スクレ","ECV":"エクアドル (UVC)","EEK":"エストニア クルーン","EGP":"エジプト ポンド","ERN":"エリトリア ナクファ","ESA":"スペインペセタ（勘定A）","ESB":"スペイン 兌換ペセタ","ESP":"スペイン ペセタ","ETB":"エチオピア ブル","EUR":"ユーロ","FIM":"フィンランド マルカ","FJD":"フィジー ドル","FKP":"フォークランド（マルビナス）諸島 ポンド","FRF":"フランス フラン","GBP":"英国ポンド","GEK":"ジョージア クーポン ラリ","GEL":"ジョージア ラリ","GHC":"ガーナ セディ (1979–2007)","GHS":"ガーナ セディ","GIP":"ジブラルタル ポンド","GMD":"ガンビア ダラシ","GNF":"ギニア フラン","GNS":"ギニア シリー","GQE":"赤道ギニア エクウェレ","GRD":"ギリシャ ドラクマ","GTQ":"グアテマラ ケツァル","GWE":"ポルトガル領ギニア エスクード","GWP":"ギニアビサウ ペソ","GYD":"ガイアナ ドル","HKD":"香港ドル","HNL":"ホンジュラス レンピラ","HRD":"クロアチア ディナール","HRK":"クロアチア クーナ","HTG":"ハイチ グールド","HUF":"ハンガリー フォリント","IDR":"インドネシア ルピア","IEP":"アイリッシュ ポンド","ILP":"イスラエル ポンド","ILR":"イスラエル シェケル (1980–1985)","ILS":"イスラエル新シェケル","INR":"インド ルピー","IQD":"イラク ディナール","IRR":"イラン リアル","ISJ":"アイスランド クローナ (1918–1981)","ISK":"アイスランド クローナ","ITL":"イタリア リラ","JMD":"ジャマイカ ドル","JOD":"ヨルダン ディナール","JPY":"日本円","KES":"ケニア シリング","KGS":"キルギス ソム","KHR":"カンボジア リエル","KMF":"コモロ フラン","KPW":"北朝鮮ウォン","KRH":"韓国 ファン（1953–1962）","KRO":"韓国 ウォン（1945–1953）","KRW":"韓国ウォン","KWD":"クウェート ディナール","KYD":"ケイマン諸島 ドル","KZT":"カザフスタン テンゲ","LAK":"ラオス キープ","LBP":"レバノン ポンド","LKR":"スリランカ ルピー","LRD":"リベリア ドル","LSL":"レソト ロティ","LTL":"リトアニア リタス","LTT":"リトアニア タロナ","LUC":"ルクセンブルク 兌換フラン","LUF":"ルクセンブルグ フラン","LUL":"ルクセンブルク 金融フラン","LVL":"ラトビア ラッツ","LVR":"ラトビア ルーブル","LYD":"リビア ディナール","MAD":"モロッコ ディルハム","MAF":"モロッコ フラン","MCF":"モネガスク フラン","MDC":"モルドバ クーポン","MDL":"モルドバ レイ","MGA":"マダガスカル アリアリ","MGF":"マラガシ フラン","MKD":"マケドニア デナル","MKN":"マケドニア ディナール（1992–1993）","MLF":"マリ フラン","MMK":"ミャンマー チャット","MNT":"モンゴル トグログ","MOP":"マカオ パタカ","MRO":"モーリタニア ウギア (1973–2017)","MRU":"モーリタニア ウギア","MTL":"マルタ リラ","MTP":"マルタ ポンド","MUR":"モーリシャス ルピー","MVP":"モルディブ諸島 ルピー","MVR":"モルディブ ルフィア","MWK":"マラウィ クワチャ","MXN":"メキシコ ペソ","MXP":"メキシコ ペソ (1861–1992)","MXV":"メキシコ (UDI)","MYR":"マレーシア リンギット","MZE":"モザンピーク エスクード","MZM":"モザンビーク メティカル (1980–2006)","MZN":"モザンビーク メティカル","NAD":"ナミビア ドル","NGN":"ナイジェリア ナイラ","NIC":"ニカラグア コルドバ (1988–1991)","NIO":"ニカラグア コルドバ オロ","NLG":"オランダ ギルダー","NOK":"ノルウェー クローネ","NPR":"ネパール ルピー","NZD":"ニュージーランド ドル","OMR":"オマーン リアル","PAB":"パナマ バルボア","PEI":"ペルー インティ","PEN":"ペルー ソル","PES":"ペルー ソル (1863–1965)","PGK":"パプアニューギニア キナ","PHP":"フィリピン ペソ","PKR":"パキスタン ルピー","PLN":"ポーランド ズウォティ","PLZ":"ポーランド ズウォティ (1950–1995)","PTE":"ポルトガル エスクード","PYG":"パラグアイ グアラニ","QAR":"カタール リアル","RHD":"ローデシア ドル","ROL":"ルーマニア レイ (1952–2006)","RON":"ルーマニア レイ","RSD":"ディナール (セルビア)","RUB":"ロシア ルーブル","RUR":"ロシア ルーブル (1991–1998)","RWF":"ルワンダ フラン","SAR":"サウジ リヤル","SBD":"ソロモン諸島 ドル","SCR":"セーシェル ルピー","SDD":"スーダン ディナール (1992–2007)","SDG":"スーダン ポンド","SDP":"スーダン ポンド (1957–1998)","SEK":"スウェーデン クローナ","SGD":"シンガポール ドル","SHP":"セントヘレナ ポンド","SIT":"スロベニア トラール","SKK":"スロバキア コルナ","SLL":"シエラレオネ レオン","SOS":"ソマリア シリング","SRD":"スリナム ドル","SRG":"スリナム ギルダー","SSP":"南スーダン ポンド","STD":"サントメ・プリンシペ ドブラ (1977–2017)","STN":"サントメ・プリンシペ ドブラ","SUR":"ソ連 ルーブル","SVC":"エルサルバドル コロン","SYP":"シリア ポンド","SZL":"スワジランド リランゲニ","THB":"タイ バーツ","TJR":"タジキスタン ルーブル","TJS":"タジキスタン ソモニ","TMM":"トルクメニスタン マナト (1993–2009)","TMT":"トルクメニスタン マナト","TND":"チュニジア ディナール","TOP":"トンガ パ・アンガ","TPE":"ティモール エスクード","TRL":"トルコ リラ (1922–2005)","TRY":"新トルコリラ","TTD":"トリニダード・トバゴ ドル","TWD":"新台湾ドル","TZS":"タンザニア シリング","UAH":"ウクライナ グリブナ","UAK":"ウクライナ カルボバネツ","UGS":"ウガンダ シリング (1966–1987)","UGX":"ウガンダ シリング","USD":"米ドル","USN":"米ドル (翌日)","USS":"米ドル (当日)","UYI":"ウルグアイ ペソエン","UYP":"ウルグアイ ペソ (1975–1993)","UYU":"ウルグアイ ペソ","UYW":"UYW","UZS":"ウズベキスタン スム","VEB":"ベネズエラ ボリバル (1871–2008)","VEF":"ベネズエラ ボリバル (2008–2018)","VES":"ベネズエラ ボリバル","VND":"ベトナム ドン","VNN":"ベトナム ドン（1978–1985）","VUV":"バヌアツ バツ","WST":"サモア タラ","XAF":"中央アフリカ CFA フラン","XAG":"銀","XAU":"金","XBA":"ヨーロッパ混合単位 (EURCO)","XBB":"ヨーロッパ通貨単位 (EMU–6)","XBC":"ヨーロッパ勘定単位 (EUA–9)","XBD":"ヨーロッパ勘定単位 (EUA–17)","XCD":"東カリブ ドル","XDR":"特別引き出し権","XEU":"ヨーロッパ通貨単位","XFO":"フランス金フラン","XFU":"フランス フラン (UIC)","XOF":"西アフリカ CFA フラン","XPD":"パラジウム","XPF":"CFP フラン","XPT":"プラチナ","XRE":"RINET基金","XSU":"スクレ","XTS":"テスト用通貨コード","XUA":"UA (アフリカ開発銀行)","XXX":"不明または無効な通貨","YDD":"イエメン ディナール","YER":"イエメン リアル","YUD":"ユーゴスラビア ハード・ディナール (1966–1990)","YUM":"ユーゴスラビア ノビ・ディナール (1994–2002)","YUN":"ユーゴスラビア 兌換ディナール (1990–1992)","YUR":"ユーゴスラビア 改革ディナール（1992–1993）","ZAL":"南アフリカ ランド (ZAL)","ZAR":"南アフリカ ランド","ZMK":"ザンビア クワチャ (1968–2012)","ZMW":"ザンビア クワチャ","ZRN":"ザイール 新ザイール (1993–1998)","ZRZ":"ザイール ザイール (1971–1993)","ZWD":"ジンバブエ ドル (1980–2008)","ZWL":"ジンバブエ ドル (2009)","ZWR":"シンバブエ ドル（2008）"},"short":{},"narrow":{}}},"patterns":{"locale":"{0} ({1})"}}},"availableLocales":["ja"],"aliases":{},"parentLocales":{}},
    {"data":{"ko":{"types":{"language":{"long":{"aa":"아파르어","ab":"압카즈어","ace":"아체어","ach":"아콜리어","ada":"아당메어","ady":"아디게어","ae":"아베스타어","aeb":"튀니지 아랍어","af":"아프리칸스어","afh":"아프리힐리어","agq":"아그햄어","ain":"아이누어","ak":"아칸어","akk":"아카드어","ale":"알류트어","alt":"남부 알타이어","am":"암하라어","an":"아라곤어","ang":"고대 영어","anp":"앙가어","ar":"아랍어","ar-001":"현대 표준 아랍어","arc":"아람어","arn":"마푸둥군어","arp":"아라파호어","arq":"알제리 아랍어","ars":"아랍어(나즈디)","arw":"아라와크어","ary":"모로코 아랍어","arz":"이집트 아랍어","as":"아삼어","asa":"아수어","ast":"아스투리아어","av":"아바릭어","awa":"아와히어","ay":"아이마라어","az":"아제르바이잔어","ba":"바슈키르어","bal":"발루치어","ban":"발리어","bas":"바사어","bax":"바문어","bbj":"고말라어","be":"벨라루스어","bej":"베자어","bem":"벰바어","bez":"베나어","bfd":"바푸트어","bg":"불가리아어","bgn":"서부 발로치어","bho":"호즈푸리어","bi":"비슬라마어","bik":"비콜어","bin":"비니어","bkm":"콤어","bla":"식시카어","bm":"밤바라어","bn":"벵골어","bo":"티베트어","br":"브르타뉴어","bra":"브라지어","brh":"브라후이어","brx":"보도어","bs":"보스니아어","bss":"아쿠즈어","bua":"부리아타","bug":"부기어","bum":"불루어","byn":"브린어","byv":"메둠바어","ca":"카탈로니아어","cad":"카도어","car":"카리브어","cay":"카유가어","cch":"앗삼어","ccp":"차크마어","ce":"체첸어","ceb":"세부아노어","cgg":"치가어","ch":"차모로어","chb":"치브차어","chg":"차가타이어","chk":"추크어","chm":"마리어","chn":"치누크 자곤","cho":"촉토어","chp":"치페우얀","chr":"체로키어","chy":"샤이엔어","ckb":"소라니 쿠르드어","co":"코르시카어","cop":"콥트어","cr":"크리어","crh":"크리민 터키어; 크리민 타타르어","crs":"세이셸 크리올 프랑스어","cs":"체코어","csb":"카슈비아어","cu":"교회 슬라브어","cv":"추바시어","cy":"웨일스어","da":"덴마크어","dak":"다코타어","dar":"다르그와어","dav":"타이타어","de":"독일어","de-AT":"독일어(오스트리아)","de-CH":"고지 독일어(스위스)","del":"델라웨어어","den":"슬라브어","dgr":"도그리브어","din":"딩카어","dje":"자르마어","doi":"도그리어","dsb":"저지 소르비아어","dua":"두알라어","dum":"중세 네덜란드어","dv":"디베히어","dyo":"졸라 포니어","dyu":"드율라어","dz":"종카어","dzg":"다장가어","ebu":"엠부어","ee":"에웨어","efi":"이픽어","egy":"고대 이집트어","eka":"이카죽어","el":"그리스어","elx":"엘람어","en":"영어","en-AU":"영어(호주)","en-CA":"영어(캐나다)","en-GB":"영어(영국)","en-US":"영어(미국)","enm":"중세 영어","eo":"에스페란토어","es":"스페인어","es-419":"스페인어(라틴 아메리카)","es-ES":"스페인어(유럽)","es-MX":"스페인어(멕시코)","et":"에스토니아어","eu":"바스크어","ewo":"이원도어","fa":"페르시아어","fan":"팡그어","fat":"판티어","ff":"풀라어","fi":"핀란드어","fil":"필리핀어","fj":"피지어","fo":"페로어","fon":"폰어","fr":"프랑스어","fr-CA":"프랑스어(캐나다)","fr-CH":"프랑스어(스위스)","frc":"케이준 프랑스어","frm":"중세 프랑스어","fro":"고대 프랑스어","frr":"북부 프리지아어","frs":"동부 프리슬란드어","fur":"프리울리어","fy":"서부 프리지아어","ga":"아일랜드어","gaa":"가어","gag":"가가우스어","gan":"간어","gay":"가요어","gba":"그바야어","gbz":"조로아스터 다리어","gd":"스코틀랜드 게일어","gez":"게이즈어","gil":"키리바시어","gl":"갈리시아어","glk":"길라키어","gmh":"중세 고지 독일어","gn":"과라니어","goh":"고대 고지 독일어","gom":"고아 콘칸어","gon":"곤디어","gor":"고론탈로어","got":"고트어","grb":"게르보어","grc":"고대 그리스어","gsw":"독일어(스위스)","gu":"구자라트어","guz":"구시어","gv":"맹크스어","gwi":"그위친어","ha":"하우사어","hai":"하이다어","hak":"하카어","haw":"하와이어","he":"히브리어","hi":"힌디어","hif":"피지 힌디어","hil":"헤리가뇬어","hit":"하타이트어","hmn":"히몸어","ho":"히리 모투어","hr":"크로아티아어","hsb":"고지 소르비아어","hsn":"샹어","ht":"아이티어","hu":"헝가리어","hup":"후파어","hy":"아르메니아어","hz":"헤레로어","ia":"인터링구아","iba":"이반어","ibb":"이비비오어","id":"인도네시아어","ie":"인테르링구에","ig":"이그보어","ii":"쓰촨 이어","ik":"이누피아크어","ilo":"이로코어","inh":"인귀시어","io":"이도어","is":"아이슬란드어","it":"이탈리아어","iu":"이눅티투트어","ja":"일본어","jbo":"로반어","jgo":"응곰바어","jmc":"마차메어","jpr":"유대-페르시아어","jrb":"유대-아라비아어","jv":"자바어","ka":"조지아어","kaa":"카라칼파크어","kab":"커바일어","kac":"카친어","kaj":"까꼬토끄어","kam":"캄바어","kaw":"카위어","kbd":"카바르디어","kbl":"카넴부어","kcg":"티얍어","kde":"마콘데어","kea":"크리올어","kfo":"코로어","kg":"콩고어","kha":"카시어","kho":"호탄어","khq":"코이라 친니어","khw":"코와르어","ki":"키쿠유어","kj":"쿠안야마어","kk":"카자흐어","kkj":"카코어","kl":"그린란드어","kln":"칼렌진어","km":"크메르어","kmb":"킴분두어","kn":"칸나다어","ko":"한국어","koi":"코미페르먀크어","kok":"코카니어","kos":"코스라이엔어","kpe":"크펠레어","kr":"칸누리어","krc":"카라챠이-발카르어","krl":"카렐리야어","kru":"쿠르크어","ks":"카슈미르어","ksb":"샴발라어","ksf":"바피아어","ksh":"콜로그니안어","ku":"쿠르드어","kum":"쿠믹어","kut":"쿠테네어","kv":"코미어","kw":"콘월어","ky":"키르기스어","la":"라틴어","lad":"라디노어","lag":"랑기어","lah":"라한다어","lam":"람바어","lb":"룩셈부르크어","lez":"레즈기안어","lfn":"링구아 프랑카 노바","lg":"간다어","li":"림버거어","lkt":"라코타어","ln":"링갈라어","lo":"라오어","lol":"몽고어","lou":"루이지애나 크리올어","loz":"로지어","lrc":"북부 루리어","lt":"리투아니아어","lu":"루바-카탄가어","lua":"루바-룰루아어","lui":"루이세노어","lun":"룬다어","luo":"루오어","lus":"루샤이어","luy":"루야어","lv":"라트비아어","mad":"마두라어","maf":"마파어","mag":"마가히어","mai":"마이틸리어","mak":"마카사어","man":"만딩고어","mas":"마사이어","mde":"마바어","mdf":"모크샤어","mdr":"만다르어","men":"멘데어","mer":"메루어","mfe":"모리스얀어","mg":"말라가시어","mga":"중세 아일랜드어","mgh":"마크후와-메토어","mgo":"메타어","mh":"마셜어","mi":"마오리어","mic":"미크맥어","min":"미낭카바우어","mk":"마케도니아어","ml":"말라얄람어","mn":"몽골어","mnc":"만주어","mni":"마니푸리어","moh":"모호크어","mos":"모시어","mr":"마라티어","mrj":"서부 마리어","ms":"말레이어","mt":"몰타어","mua":"문당어","mul":"다중 언어","mus":"크리크어","mwl":"미란데어","mwr":"마르와리어","my":"버마어","mye":"미예네어","myv":"엘즈야어","mzn":"마잔데라니어","na":"나우루어","nan":"민난어","nap":"나폴리어","naq":"나마어","nb":"노르웨이어(보크말)","nd":"북부 은데벨레어","nds":"저지 독일어","nds-NL":"저지 색슨어","ne":"네팔어","new":"네와르어","ng":"느동가어","nia":"니아스어","niu":"니웨언어","nl":"네덜란드어","nl-BE":"플라망어","nmg":"크와시오어","nn":"노르웨이어(니노르스크)","nnh":"느기엠본어","no":"노르웨이어","nog":"노가이어","non":"고대 노르웨이어","nqo":"응코어","nr":"남부 은데벨레어","nso":"북부 소토어","nus":"누에르어","nv":"나바호어","nwc":"고전 네와르어","ny":"냔자어","nym":"니암웨지어","nyn":"니안콜어","nyo":"뉴로어","nzi":"느지마어","oc":"오크어","oj":"오지브와어","om":"오로모어","or":"오리야어","os":"오세트어","osa":"오세이지어","ota":"오스만 터키어","pa":"펀잡어","pag":"판가시난어","pal":"팔레비어","pam":"팜팡가어","pap":"파피아먼토어","pau":"팔라우어","pcm":"나이지리아 피진어","peo":"고대 페르시아어","phn":"페니키아어","pi":"팔리어","pl":"폴란드어","pnt":"폰틱어","pon":"폼페이어","prg":"프러시아어","pro":"고대 프로방스어","ps":"파슈토어","pt":"포르투갈어","pt-BR":"포르투갈어(브라질)","pt-PT":"포르투갈어(유럽)","qu":"케추아어","quc":"키체어","raj":"라자스탄어","rap":"라파뉴이","rar":"라로통가어","rm":"로만시어","rn":"룬디어","ro":"루마니아어","ro-MD":"몰도바어","rof":"롬보어","rom":"집시어","root":"어근","ru":"러시아어","rue":"루신어","rup":"아로마니아어","rw":"르완다어","rwk":"르와어","sa":"산스크리트어","sad":"산다웨어","sah":"야쿠트어","sam":"사마리아 아랍어","saq":"삼부루어","sas":"사사크어","sat":"산탈리어","sba":"느감바이어","sbp":"상구어","sc":"사르디니아어","scn":"시칠리아어","sco":"스코틀랜드어","sd":"신디어","sdh":"남부 쿠르드어","se":"북부 사미어","see":"세네카어","seh":"세나어","sel":"셀쿠프어","ses":"코이야보로 세니어","sg":"산고어","sga":"고대 아일랜드어","sh":"세르비아-크로아티아어","shi":"타셸히트어","shn":"샨어","shu":"차디언 아라비아어","si":"스리랑카어","sid":"시다모어","sk":"슬로바키아어","sl":"슬로베니아어","sm":"사모아어","sma":"남부 사미어","smj":"룰레 사미어","smn":"이나리 사미어","sms":"스콜트 사미어","sn":"쇼나어","snk":"소닌케어","so":"소말리아어","sog":"소그디엔어","sq":"알바니아어","sr":"세르비아어","srn":"스라난 통가어","srr":"세레르어","ss":"시스와티어","ssy":"사호어","st":"남부 소토어","su":"순다어","suk":"수쿠마어","sus":"수수어","sux":"수메르어","sv":"스웨덴어","sw":"스와힐리어","sw-CD":"콩고 스와힐리어","swb":"코모로어","syc":"고전 시리아어","syr":"시리아어","ta":"타밀어","te":"텔루구어","tem":"팀니어","teo":"테조어","ter":"테레노어","tet":"테툼어","tg":"타지크어","th":"태국어","ti":"티그리냐어","tig":"티그레어","tiv":"티브어","tk":"투르크멘어","tkl":"토켈라우제도어","tkr":"차후르어","tl":"타갈로그어","tlh":"클링온어","tli":"틀링깃족어","tly":"탈리쉬어","tmh":"타마섹어","tn":"츠와나어","to":"통가어","tog":"니아사 통가어","tpi":"토크 피신어","tr":"터키어","trv":"타로코어","ts":"총가어","tsi":"트심시안어","tt":"타타르어","tum":"툼부카어","tvl":"투발루어","tw":"트위어","twq":"타사와크어","ty":"타히티어","tyv":"투비니안어","tzm":"중앙 모로코 타마지트어","udm":"우드말트어","ug":"위구르어","uga":"유가리틱어","uk":"우크라이나어","umb":"움분두어","und":"알 수 없는 언어","ur":"우르두어","uz":"우즈베크어","vai":"바이어","ve":"벤다어","vi":"베트남어","vo":"볼라퓌크어","vot":"보틱어","vun":"분조어","wa":"왈론어","wae":"월저어","wal":"월라이타어","war":"와라이어","was":"와쇼어","wbp":"왈피리어","wo":"월로프어","wuu":"우어","xal":"칼미크어","xh":"코사어","xog":"소가어","yao":"야오족어","yap":"얍페세어","yav":"양본어","ybb":"옘바어","yi":"이디시어","yo":"요루바어","yue":"광둥어","za":"주앙어","zap":"사포테크어","zbl":"블리스 심볼","zen":"제나가어","zgh":"표준 모로코 타마지트어","zh":"중국어","zh-Hans":"중국어(간체)","zh-Hant":"중국어(번체)","zu":"줄루어","zun":"주니어","zxx":"언어 관련 내용 없음","zza":"자자어"},"short":{"az":"아제리어","en-GB":"영어(영국)","en-US":"영어(미국)"},"narrow":{}},"region":{"long":{"142":"아시아","143":"중앙 아시아","145":"서아시아","150":"유럽","151":"동유럽","154":"북유럽","155":"서유럽","202":"사하라 사막 이남 아프리카","419":"라틴 아메리카","001":"세계","002":"아프리카","003":"북아메리카","005":"남아메리카(남미)","009":"오세아니아","011":"서부 아프리카","013":"중앙 아메리카","014":"동부 아프리카","015":"북부 아프리카","017":"중부 아프리카","018":"남부 아프리카","019":"아메리카 대륙","021":"북부 아메리카","029":"카리브 제도","030":"동아시아","034":"남아시아","035":"동남아시아","039":"남유럽","053":"오스트랄라시아","054":"멜라네시아","057":"미크로네시아 지역","061":"폴리네시아","AC":"어센션 섬","AD":"안도라","AE":"아랍에미리트","AF":"아프가니스탄","AG":"앤티가 바부다","AI":"앵귈라","AL":"알바니아","AM":"아르메니아","AO":"앙골라","AQ":"남극 대륙","AR":"아르헨티나","AS":"아메리칸 사모아","AT":"오스트리아","AU":"오스트레일리아","AW":"아루바","AX":"올란드 제도","AZ":"아제르바이잔","BA":"보스니아 헤르체고비나","BB":"바베이도스","BD":"방글라데시","BE":"벨기에","BF":"부르키나파소","BG":"불가리아","BH":"바레인","BI":"부룬디","BJ":"베냉","BL":"생바르텔레미","BM":"버뮤다","BN":"브루나이","BO":"볼리비아","BQ":"네덜란드령 카리브","BR":"브라질","BS":"바하마","BT":"부탄","BV":"부베섬","BW":"보츠와나","BY":"벨라루스","BZ":"벨리즈","CA":"캐나다","CC":"코코스 제도","CD":"콩고-킨샤사","CF":"중앙 아프리카 공화국","CG":"콩고-브라자빌","CH":"스위스","CI":"코트디부아르","CK":"쿡 제도","CL":"칠레","CM":"카메룬","CN":"중국","CO":"콜롬비아","CP":"클립퍼튼 섬","CR":"코스타리카","CU":"쿠바","CV":"카보베르데","CW":"퀴라소","CX":"크리스마스섬","CY":"키프로스","CZ":"체코","DE":"독일","DG":"디에고 가르시아","DJ":"지부티","DK":"덴마크","DM":"도미니카","DO":"도미니카 공화국","DZ":"알제리","EA":"세우타 및 멜리야","EC":"에콰도르","EE":"에스토니아","EG":"이집트","EH":"서사하라","ER":"에리트리아","ES":"스페인","ET":"에티오피아","EU":"유럽 연합","EZ":"유로존","FI":"핀란드","FJ":"피지","FK":"포클랜드 제도","FM":"미크로네시아","FO":"페로 제도","FR":"프랑스","GA":"가봉","GB":"영국","GD":"그레나다","GE":"조지아","GF":"프랑스령 기아나","GG":"건지","GH":"가나","GI":"지브롤터","GL":"그린란드","GM":"감비아","GN":"기니","GP":"과들루프","GQ":"적도 기니","GR":"그리스","GS":"사우스조지아 사우스샌드위치 제도","GT":"과테말라","GU":"괌","GW":"기니비사우","GY":"가이아나","HK":"홍콩(중국 특별행정구)","HM":"허드 맥도널드 제도","HN":"온두라스","HR":"크로아티아","HT":"아이티","HU":"헝가리","IC":"카나리아 제도","ID":"인도네시아","IE":"아일랜드","IL":"이스라엘","IM":"맨 섬","IN":"인도","IO":"영국령 인도양 식민지","IQ":"이라크","IR":"이란","IS":"아이슬란드","IT":"이탈리아","JE":"저지","JM":"자메이카","JO":"요르단","JP":"일본","KE":"케냐","KG":"키르기스스탄","KH":"캄보디아","KI":"키리바시","KM":"코모로","KN":"세인트키츠 네비스","KP":"북한","KR":"대한민국","KW":"쿠웨이트","KY":"케이맨 제도","KZ":"카자흐스탄","LA":"라오스","LB":"레바논","LC":"세인트루시아","LI":"리히텐슈타인","LK":"스리랑카","LR":"라이베리아","LS":"레소토","LT":"리투아니아","LU":"룩셈부르크","LV":"라트비아","LY":"리비아","MA":"모로코","MC":"모나코","MD":"몰도바","ME":"몬테네그로","MF":"생마르탱","MG":"마다가스카르","MH":"마셜 제도","MK":"북마케도니아","ML":"말리","MM":"미얀마","MN":"몽골","MO":"마카오(중국 특별행정구)","MP":"북마리아나제도","MQ":"마르티니크","MR":"모리타니","MS":"몬트세라트","MT":"몰타","MU":"모리셔스","MV":"몰디브","MW":"말라위","MX":"멕시코","MY":"말레이시아","MZ":"모잠비크","NA":"나미비아","NC":"뉴칼레도니아","NE":"니제르","NF":"노퍽섬","NG":"나이지리아","NI":"니카라과","NL":"네덜란드","NO":"노르웨이","NP":"네팔","NR":"나우루","NU":"니우에","NZ":"뉴질랜드","OM":"오만","PA":"파나마","PE":"페루","PF":"프랑스령 폴리네시아","PG":"파푸아뉴기니","PH":"필리핀","PK":"파키스탄","PL":"폴란드","PM":"생피에르 미클롱","PN":"핏케언 섬","PR":"푸에르토리코","PS":"팔레스타인 지구","PT":"포르투갈","PW":"팔라우","PY":"파라과이","QA":"카타르","QO":"오세아니아 외곽","RE":"리유니온","RO":"루마니아","RS":"세르비아","RU":"러시아","RW":"르완다","SA":"사우디아라비아","SB":"솔로몬 제도","SC":"세이셸","SD":"수단","SE":"스웨덴","SG":"싱가포르","SH":"세인트헬레나","SI":"슬로베니아","SJ":"스발바르제도-얀마웬섬","SK":"슬로바키아","SL":"시에라리온","SM":"산마리노","SN":"세네갈","SO":"소말리아","SR":"수리남","SS":"남수단","ST":"상투메 프린시페","SV":"엘살바도르","SX":"신트마르턴","SY":"시리아","SZ":"에스와티니","TA":"트리스탄다쿠나","TC":"터크스 케이커스 제도","TD":"차드","TF":"프랑스 남부 지방","TG":"토고","TH":"태국","TJ":"타지키스탄","TK":"토켈라우","TL":"동티모르","TM":"투르크메니스탄","TN":"튀니지","TO":"통가","TR":"터키","TT":"트리니다드 토바고","TV":"투발루","TW":"대만","TZ":"탄자니아","UA":"우크라이나","UG":"우간다","UM":"미국령 해외 제도","UN":"유엔","US":"미국","UY":"우루과이","UZ":"우즈베키스탄","VA":"바티칸 시국","VC":"세인트빈센트그레나딘","VE":"베네수엘라","VG":"영국령 버진아일랜드","VI":"미국령 버진아일랜드","VN":"베트남","VU":"바누아투","WF":"왈리스-푸투나 제도","WS":"사모아","XA":"유사 억양","XB":"유사 양방향","XK":"코소보","YE":"예멘","YT":"마요트","ZA":"남아프리카","ZM":"잠비아","ZW":"짐바브웨","ZZ":"알려지지 않은 지역"},"short":{"GB":"영국","HK":"홍콩","MO":"마카오","PS":"팔레스타인","UN":"유엔","US":"미국"},"narrow":{}},"script":{"long":{"Adlm":"Adlm","Afak":"아파카 문자","Aghb":"코카시안 알바니아 문자","Ahom":"Ahom","Arab":"아랍 문자","Armi":"아랍제국 문자","Armn":"아르메니아 문자","Avst":"아베스타 문자","Bali":"발리 문자","Bamu":"바뭄 문자","Bass":"바사바흐 문자","Batk":"바타크 문자","Beng":"벵골 문자","Bhks":"Bhks","Blis":"블리스기호 문자","Bopo":"주음부호","Brah":"브라미","Brai":"브라유 점자","Bugi":"부기 문자","Buhd":"부히드 문자","Cakm":"차크마 문자","Cans":"통합 캐나다 토착어","Cari":"카리 문자","Cham":"칸 고어","Cher":"체로키 문자","Cirt":"키르쓰","Copt":"콥트 문자","Cprt":"키프로스 문자","Cyrl":"키릴 문자","Cyrs":"고대교회슬라브어 키릴문자","Deva":"데바나가리 문자","Dogr":"Dogr","Dsrt":"디저렛 문자","Dupl":"듀플로이안 문자","Egyd":"고대 이집트 민중문자","Egyh":"고대 이집트 신관문자","Egyp":"고대 이집트 신성문자","Elba":"엘바산 문자","Elym":"Elym","Ethi":"에티오피아 문자","Geok":"그루지야 쿠츠리 문자","Geor":"조지아 문자","Glag":"글라골 문자","Gong":"Gong","Gonm":"Gonm","Goth":"고트 문자","Gran":"그란타 문자","Grek":"그리스 문자","Gujr":"구자라트 문자","Guru":"구르무키 문자","Hanb":"주음 자모","Hang":"한글","Hani":"한자","Hano":"하누누 문자","Hans":"간체","Hant":"번체","Hatr":"Hatr","Hebr":"히브리 문자","Hira":"히라가나","Hluw":"아나톨리아 상형문자","Hmng":"파하우 몽 문자","Hmnp":"Hmnp","Hrkt":"가나","Hung":"고대 헝가리 문자","Inds":"인더스 문자","Ital":"고대 이탈리아 문자","Jamo":"자모","Java":"자바 문자","Jpan":"일본 문자","Jurc":"줄첸 문자","Kali":"카야 리 문자","Kana":"가타카나","Khar":"카로슈티 문자","Khmr":"크메르 문자","Khoj":"코즈키 문자","Knda":"칸나다 문자","Kore":"한국어","Kpel":"크펠레 문자","Kthi":"카이시 문자","Lana":"란나 문자","Laoo":"라오 문자","Latf":"독일식 로마자","Latg":"아일랜드식 로마자","Latn":"로마자","Lepc":"렙차 문자","Limb":"림부 문자","Lina":"선형 문자(A)","Linb":"선형 문자(B)","Lisu":"프레이저 문자","Loma":"로마 문자","Lyci":"리키아 문자","Lydi":"리디아 문자","Mahj":"마하자니 문자","Maka":"Maka","Mand":"만다이아 문자","Mani":"마니교 문자","Marc":"Marc","Maya":"마야 상형 문자","Medf":"Medf","Mend":"멘데 문자","Merc":"메로에 필기체","Mero":"메로에 문자","Mlym":"말라얄람 문자","Modi":"Modi","Mong":"몽골 문자","Moon":"문 문자","Mroo":"므로 문자","Mtei":"메이테이 마옉 문자","Mult":"Mult","Mymr":"미얀마 문자","Nand":"Nand","Narb":"옛 북부 아라비아 문자","Nbat":"나바테아 문자","Newa":"Newa","Nkgb":"나시 게바 문자","Nkoo":"응코 문자","Nshu":"누슈 문자","Ogam":"오검 문자","Olck":"올 치키 문자","Orkh":"오르혼어","Orya":"오리야 문자","Osge":"Osge","Osma":"오스마니아 문자","Palm":"팔미라 문자","Pauc":"Pauc","Perm":"고대 페름 문자","Phag":"파스파 문자","Phli":"명문 팔라비 문자","Phlp":"솔터 팔라비 문자","Phlv":"북 팔라비 문자","Phnx":"페니키아 문자","Plrd":"폴라드 표음 문자","Prti":"명문 파라티아 문자","Qaag":"Qaag","Rjng":"레장 문자","Rohg":"Rohg","Roro":"롱고롱고","Runr":"룬 문자","Samr":"사마리아 문자","Sara":"사라티","Sarb":"옛 남부 아라비아 문자","Saur":"사우라슈트라 문자","Sgnw":"수화 문자","Shaw":"샤비안 문자","Shrd":"사라다 문자","Sidd":"실담자","Sind":"쿠다와디 문자","Sinh":"신할라 문자","Sogd":"Sogd","Sogo":"Sogo","Sora":"소라 솜펭 문자","Soyo":"Soyo","Sund":"순다 문자","Sylo":"실헤티 나가리","Syrc":"시리아 문자","Syre":"에스트랑겔로식 시리아 문자","Syrj":"서부 시리아 문자","Syrn":"동부 시리아 문자","Tagb":"타그반와 문자","Takr":"타크리 문자","Tale":"타이 레 문자","Talu":"신 타이 루에","Taml":"타밀 문자","Tang":"탕구트 문자","Tavt":"태국 베트남 문자","Telu":"텔루구 문자","Teng":"텡과르 문자","Tfng":"티피나그 문자","Tglg":"타갈로그 문자","Thaa":"타나 문자","Thai":"타이 문자","Tibt":"티베트 문자","Tirh":"티르후타 문자","Ugar":"우가리트 문자","Vaii":"바이 문자","Visp":"시화법","Wara":"바랑 크시티 문자","Wcho":"Wcho","Wole":"울레아이","Xpeo":"고대 페르시아 문자","Xsux":"수메르-아카드어 설형문자","Yiii":"이 문자","Zanb":"Zanb","Zinh":"구전 문자","Zmth":"수학 기호","Zsye":"이모티콘","Zsym":"기호","Zxxx":"구전","Zyyy":"일반 문자","Zzzz":"알 수 없는 문자"},"short":{},"narrow":{}},"currency":{"long":{"ADP":"안도라 페세타","AED":"아랍에미리트 디르함","AFA":"아프가니 (1927–2002)","AFN":"아프가니스탄 아프가니","ALK":"ALK","ALL":"알바니아 레크","AMD":"아르메니아 드람","ANG":"네덜란드령 안틸레스 길더","AOA":"앙골라 콴자","AOK":"앙골라 콴자 (1977–1990)","AON":"앙골라 신콴자 (1990–2000)","AOR":"앙골라 재조정 콴자 (1995–1999)","ARA":"아르헨티나 오스트랄","ARL":"아르헨티나 페소 레이 (1970–1983)","ARM":"아르헨티나 페소 (18810–1970)","ARP":"아르헨티나 페소 (1983–1985)","ARS":"아르헨티나 페소","ATS":"호주 실링","AUD":"호주 달러","AWG":"아루바 플로린","AZM":"아제르바이젠 마나트(1993–2006)","AZN":"아제르바이잔 마나트","BAD":"보스니아-헤르체고비나 디나르","BAM":"보스니아-헤르체고비나 태환 마르크","BAN":"보스니아-헤르체고비나 신디나르 (1994–1997)","BBD":"바베이도스 달러","BDT":"방글라데시 타카","BEC":"벨기에 프랑 (태환)","BEF":"벨기에 프랑","BEL":"벨기에 프랑 (금융)","BGL":"불가리아 동전 렛","BGM":"불가리아 사회주의자 렛","BGN":"불가리아 레프","BGO":"불가리아 렛 (1879–1952)","BHD":"바레인 디나르","BIF":"부룬디 프랑","BMD":"버뮤다 달러","BND":"부루나이 달러","BOB":"볼리비아노","BOL":"볼리비아 볼리비아노 (1863–1963)","BOP":"볼리비아노 페소","BOV":"볼리비아노 Mvdol(기금)","BRB":"볼리비아노 크루제이루 노보 (1967–1986)","BRC":"브라질 크루자두","BRE":"브라질 크루제이루 (1990–1993)","BRL":"브라질 레알","BRN":"브라질 크루자두 노보","BRR":"브라질 크루제이루","BRZ":"브라질 크루제이루 (1942–1967)","BSD":"바하마 달러","BTN":"부탄 눌투눔","BUK":"버마 차트","BWP":"보츠와나 폴라","BYB":"벨라루스 신권 루블 (1994–1999)","BYN":"벨라루스 루블","BYR":"벨라루스 루블 (2000–2016)","BZD":"벨리즈 달러","CAD":"캐나다 달러","CDF":"콩고 프랑 콩골라스","CHE":"유로 (WIR)","CHF":"스위스 프랑","CHW":"프랑 (WIR)","CLE":"칠레 에스쿠도","CLF":"칠레 (UF)","CLP":"칠레 페소","CNH":"중국 위안화(역외)","CNX":"CNX","CNY":"중국 위안화","COP":"콜롬비아 페소","COU":"콜롬비아 실가 단위","CRC":"코스타리카 콜론","CSD":"고 세르비아 디나르","CSK":"체코슬로바키아 동전 코루나","CUC":"쿠바 태환 페소","CUP":"쿠바 페소","CVE":"카보베르데 에스쿠도","CYP":"싸이프러스 파운드","CZK":"체코 공화국 코루나","DDM":"동독 오스트마르크","DEM":"독일 마르크","DJF":"지부티 프랑","DKK":"덴마크 크로네","DOP":"도미니카 페소","DZD":"알제리 디나르","ECS":"에쿠아도르 수크레","ECV":"에콰도르 (UVC)","EEK":"에스토니아 크룬","EGP":"이집트 파운드","ERN":"에리트리아 나크파","ESA":"스페인 페세타(예금)","ESB":"스페인 페세타(변환 예금)","ESP":"스페인 페세타","ETB":"에티오피아 비르","EUR":"유로","FIM":"핀란드 마르카","FJD":"피지 달러","FKP":"포클랜드제도 파운드","FRF":"프랑스 프랑","GBP":"파운드","GEK":"그루지야 지폐 라리트","GEL":"조지아 라리","GHC":"가나 시디 (1979–2007)","GHS":"가나 시디","GIP":"지브롤터 파운드","GMD":"감비아 달라시","GNF":"기니 프랑","GNS":"기니 시리","GQE":"적도 기니 에쿨 (Ekwele)","GRD":"그리스 드라크마","GTQ":"과테말라 케트살","GWE":"포르투갈령 기니 에스쿠도","GWP":"기네비쏘 페소","GYD":"가이아나 달러","HKD":"홍콩 달러","HNL":"온두라스 렘피라","HRD":"크로아티아 디나르","HRK":"크로아티아 쿠나","HTG":"하이티 구르드","HUF":"헝가리 포린트","IDR":"인도네시아 루피아","IEP":"아일랜드 파운드","ILP":"이스라엘 파운드","ILR":"ILR","ILS":"이스라엘 신권 세켈","INR":"인도 루피","IQD":"이라크 디나르","IRR":"이란 리얄","ISJ":"ISJ","ISK":"아이슬란드 크로나","ITL":"이탈리아 리라","JMD":"자메이카 달러","JOD":"요르단 디나르","JPY":"일본 엔화","KES":"케냐 실링","KGS":"키르기스스탄 솜","KHR":"캄보디아 리얄","KMF":"코모르 프랑","KPW":"조선 민주주의 인민 공화국 원","KRH":"대한민국 환 (1953–1962)","KRO":"KRO","KRW":"대한민국 원","KWD":"쿠웨이트 디나르","KYD":"케이맨 제도 달러","KZT":"카자흐스탄 텐게","LAK":"라오스 키프","LBP":"레바논 파운드","LKR":"스리랑카 루피","LRD":"라이베리아 달러","LSL":"레소토 로티","LTL":"리투아니아 리타","LTT":"룩셈부르크 타로나","LUC":"룩셈부르크 변환 프랑","LUF":"룩셈부르크 프랑","LUL":"룩셈부르크 재정 프랑","LVL":"라트비아 라트","LVR":"라트비아 루블","LYD":"리비아 디나르","MAD":"모로코 디렘","MAF":"모로코 프랑","MCF":"모나코 프랑","MDC":"몰도바 쿠폰","MDL":"몰도바 레이","MGA":"마다가스카르 아리아리","MGF":"마다가스카르 프랑","MKD":"마케도니아 디나르","MKN":"MKN","MLF":"말리 프랑","MMK":"미얀마 키얏","MNT":"몽골 투그릭","MOP":"마카오 파타카","MRO":"모리타니 우기야 (1973–2017)","MRU":"모리타니 우기야","MTL":"몰타 리라","MTP":"몰타 파운드","MUR":"모리셔스 루피","MVP":"MVP","MVR":"몰디브 제도 루피아","MWK":"말라위 콰쳐","MXN":"멕시코 페소","MXP":"멕시코 실버 페소 (1861–1992)","MXV":"멕시코 (UDI)","MYR":"말레이시아 링깃","MZE":"모잠비크 에스쿠도","MZM":"고 모잠비크 메티칼","MZN":"모잠비크 메티칼","NAD":"나미비아 달러","NGN":"니제르 나이라","NIC":"니카라과 코르도바","NIO":"니카라과 코르도바 오로","NLG":"네델란드 길더","NOK":"노르웨이 크로네","NPR":"네팔 루피","NZD":"뉴질랜드 달러","OMR":"오만 리얄","PAB":"파나마 발보아","PEI":"페루 인티","PEN":"페루 솔","PES":"페루 솔 (1863–1965)","PGK":"파푸아뉴기니 키나","PHP":"필리핀 페소","PKR":"파키스탄 루피","PLN":"폴란드 즐로티","PLZ":"폴란드 즐로티 (1950–1995)","PTE":"포르투갈 에스쿠도","PYG":"파라과이 과라니","QAR":"카타르 리얄","RHD":"로디지아 달러","ROL":"루마니아 레이","RON":"루마니아 레우","RSD":"세르비아 디나르","RUB":"러시아 루블","RUR":"러시아 루블 (1991–1998)","RWF":"르완다 프랑","SAR":"사우디아라비아 리얄","SBD":"솔로몬 제도 달러","SCR":"세이셸 루피","SDD":"수단 디나르","SDG":"수단 파운드","SDP":"고 수단 파운드","SEK":"스웨덴 크로나","SGD":"싱가폴 달러","SHP":"세인트헬레나 파운드","SIT":"슬로베니아 톨라르","SKK":"슬로바키아 코루나","SLL":"시에라리온 리온","SOS":"소말리아 실링","SRD":"수리남 달러","SRG":"수리남 길더","SSP":"남수단 파운드","STD":"상투메 프린시페 도브라 (1977–2017)","STN":"상투메 프린시페 도브라","SUR":"소련 루블","SVC":"엘살바도르 콜론","SYP":"시리아 파운드","SZL":"스와질란드 릴랑게니","THB":"태국 바트","TJR":"타지키스탄 루블","TJS":"타지키스탄 소모니","TMM":"투르크메니스탄 마나트 (1993–2009)","TMT":"투르크메니스탄 마나트","TND":"튀니지 디나르","TOP":"통가 파앙가","TPE":"티모르 에스쿠도","TRL":"터키 리라","TRY":"신 터키 리라","TTD":"트리니다드 토바고 달러","TWD":"신 타이완 달러","TZS":"탄자니아 실링","UAH":"우크라이나 그리브나","UAK":"우크라이나 카보바네츠","UGS":"우간다 실링 (1966–1987)","UGX":"우간다 실링","USD":"미국 달러","USN":"미국 달러(다음날)","USS":"미국 달러(당일)","UYI":"우루과이 페소 (UI)","UYP":"우루과이 페소 (1975–1993)","UYU":"우루과이 페소 우루과요","UYW":"UYW","UZS":"우즈베키스탄 숨","VEB":"베네주엘라 볼리바르 (1871–2008)","VEF":"베네수엘라 볼리바르 (2008–2018)","VES":"베네수엘라 볼리바르","VND":"베트남 동","VNN":"베트남 동 (1978–1985)","VUV":"바누아투 바투","WST":"서 사모아 탈라","XAF":"중앙아프리카 CFA 프랑","XAG":"은화","XAU":"금","XBA":"유르코 (유럽 회계 단위)","XBB":"유럽 통화 동맹","XBC":"유럽 계산 단위 (XBC)","XBD":"유럽 계산 단위 (XBD)","XCD":"동카리브 달러","XDR":"특별인출권","XEU":"유럽 환율 단위","XFO":"프랑스 프랑 (Gold)","XFU":"프랑스 프랑 (UIC)","XOF":"서아프리카 CFA 프랑","XPD":"팔라듐","XPF":"CFP 프랑","XPT":"백금","XRE":"RINET 기금","XSU":"XSU","XTS":"테스트 통화 코드","XUA":"XUA","XXX":"알 수 없는 통화 단위","YDD":"예멘 디나르","YER":"예멘 리알","YUD":"유고슬라비아 동전 디나르","YUM":"유고슬라비아 노비 디나르","YUN":"유고슬라비아 전환 디나르","YUR":"YUR","ZAL":"남아프리카 랜드 (금융)","ZAR":"남아프리카 랜드","ZMK":"쟘비아 콰쳐 (1968–2012)","ZMW":"잠비아 콰쳐","ZRN":"자이르 신권 자이르","ZRZ":"자이르 자이르","ZWD":"짐바브웨 달러","ZWL":"짐바브웨 달러 (2009)","ZWR":"짐바브웨 달러 (2008)"},"short":{},"narrow":{}}},"patterns":{"locale":"{0}({1})"}}},"availableLocales":["ko"],"aliases":{},"parentLocales":{}},
    {"data":{"th":{"types":{"language":{"long":{"aa":"อะฟาร์","ab":"อับฮาเซีย","ace":"อาเจะห์","ach":"อาโคลิ","ada":"อาแดงมี","ady":"อะดืยเก","ae":"อเวสตะ","aeb":"อาหรับตูนิเซีย","af":"แอฟริกานส์","afh":"แอฟริฮีลี","agq":"อักเฮม","ain":"ไอนุ","ak":"อาคาน","akk":"อักกาด","akz":"แอละแบมา","ale":"อาลิวต์","aln":"เกกแอลเบเนีย","alt":"อัลไตใต้","am":"อัมฮารา","an":"อารากอน","ang":"อังกฤษโบราณ","anp":"อังคิกา","ar":"อาหรับ","ar-001":"อาหรับมาตรฐานสมัยใหม่","arc":"อราเมอิก","arn":"มาปูเช","aro":"อาเรานา","arp":"อาราปาโฮ","arq":"อาหรับแอลจีเรีย","ars":"อาหรับนัจญ์ดี","arw":"อาราวัก","ary":"อาหรับโมร็อกโก","arz":"อาหรับพื้นเมืองอียิปต์","as":"อัสสัม","asa":"อาซู","ase":"ภาษามืออเมริกัน","ast":"อัสตูเรียส","av":"อาวาร์","avk":"โคตาวา","awa":"อวธี","ay":"ไอย์มารา","az":"อาเซอร์ไบจาน","ba":"บัชคีร์","bal":"บาลูชิ","ban":"บาหลี","bar":"บาวาเรีย","bas":"บาสา","bax":"บามัน","bbc":"บาตักโทบา","bbj":"โคมาลา","be":"เบลารุส","bej":"เบจา","bem":"เบมบา","bew":"เบตาวี","bez":"เบนา","bfd":"บาฟัต","bfq":"พทคะ","bg":"บัลแกเรีย","bgn":"บาลูจิตะวันตก","bho":"โภชปุรี","bi":"บิสลามา","bik":"บิกอล","bin":"บินี","bjn":"บันจาร์","bkm":"กม","bla":"สิกสิกา","bm":"บัมบารา","bn":"บังกลา","bo":"ทิเบต","bpy":"พิศนุปริยะ","bqi":"บักติยารี","br":"เบรตัน","bra":"พัรช","brh":"บราฮุย","brx":"โพโฑ","bs":"บอสเนีย","bss":"อาโคซี","bua":"บูเรียต","bug":"บูกิส","bum":"บูลู","byn":"บลิน","byv":"เมดุมบา","ca":"คาตาลัน","cad":"คัดโด","car":"คาริบ","cay":"คายูกา","cch":"แอตแซม","ccp":"จักม่า","ce":"เชเชน","ceb":"เซบู","cgg":"คีกา","ch":"ชามอร์โร","chb":"ชิบชา","chg":"ชะกะไต","chk":"ชูก","chm":"มารี","chn":"ชินุกจาร์กอน","cho":"ช็อกทอว์","chp":"ชิพิวยัน","chr":"เชอโรกี","chy":"เชเยนเน","ckb":"เคิร์ดตอนกลาง","co":"คอร์ซิกา","cop":"คอปติก","cps":"กาปิซนอน","cr":"ครี","crh":"ตุรกีไครเมีย","crs":"ครีโอลเซเซลส์ฝรั่งเศส","cs":"เช็ก","csb":"คาซูเบียน","cu":"เชอร์ชสลาวิก","cv":"ชูวัช","cy":"เวลส์","da":"เดนมาร์ก","dak":"ดาโกทา","dar":"ดาร์กิน","dav":"ไททา","de":"เยอรมัน","de-AT":"เยอรมัน - ออสเตรีย","de-CH":"เยอรมันสูง (สวิส)","del":"เดลาแวร์","den":"สเลวี","dgr":"โดกริบ","din":"ดิงกา","dje":"ซาร์มา","doi":"โฑครี","dsb":"ซอร์เบียตอนล่าง","dtp":"ดูซุนกลาง","dua":"ดัวลา","dum":"ดัตช์กลาง","dv":"ธิเวหิ","dyo":"โจลา-ฟอนยี","dyu":"ดิวลา","dz":"ซองคา","dzg":"ดาซากา","ebu":"เอ็มบู","ee":"เอเว","efi":"อีฟิก","egl":"เอมีเลีย","egy":"อียิปต์โบราณ","eka":"อีกาจุก","el":"กรีก","elx":"อีลาไมต์","en":"อังกฤษ","en-AU":"อังกฤษ - ออสเตรเลีย","en-CA":"อังกฤษ - แคนาดา","en-GB":"อังกฤษ - สหราชอาณาจักร","en-US":"อังกฤษ - อเมริกัน","enm":"อังกฤษกลาง","eo":"เอสเปรันโต","es":"สเปน","es-419":"สเปน - ละตินอเมริกา","es-ES":"สเปน - ยุโรป","es-MX":"สเปน - เม็กซิโก","esu":"ยูพิกกลาง","et":"เอสโตเนีย","eu":"บาสก์","ewo":"อีวันโด","ext":"เอกซ์เตรมาดูรา","fa":"เปอร์เซีย","fan":"ฟอง","fat":"ฟันติ","ff":"ฟูลาห์","fi":"ฟินแลนด์","fil":"ฟิลิปปินส์","fit":"ฟินแลนด์ทอร์เนดาเล็น","fj":"ฟิจิ","fo":"แฟโร","fon":"ฟอน","fr":"ฝรั่งเศส","fr-CA":"ฝรั่งเศส - แคนาดา","fr-CH":"ฝรั่งเศส (สวิส)","frc":"ฝรั่งเศสกาฌ็อง","frm":"ฝรั่งเศสกลาง","fro":"ฝรั่งเศสโบราณ","frp":"อาร์พิตา","frr":"ฟริเซียนเหนือ","frs":"ฟริเซียนตะวันออก","fur":"ฟรูลี","fy":"ฟริเซียนตะวันตก","ga":"ไอริช","gaa":"กา","gag":"กากาอุซ","gan":"จีนกั้น","gay":"กาโย","gba":"กบายา","gbz":"ดารีโซโรอัสเตอร์","gd":"เกลิกสกอต","gez":"กีซ","gil":"กิลเบอร์ต","gl":"กาลิเซีย","glk":"กิลากี","gmh":"เยอรมันสูงกลาง","gn":"กัวรานี","goh":"เยอรมันสูงโบราณ","gom":"กอนกานีของกัว","gon":"กอนดิ","gor":"กอรอนทาโล","got":"โกธิก","grb":"เกรโบ","grc":"กรีกโบราณ","gsw":"เยอรมันสวิส","gu":"คุชราต","guc":"วายู","gur":"ฟราฟรา","guz":"กุซซี","gv":"มานซ์","gwi":"กวิชอิน","ha":"เฮาซา","hai":"ไฮดา","hak":"จีนแคะ","haw":"ฮาวาย","he":"ฮิบรู","hi":"ฮินดี","hif":"ฮินดีฟิจิ","hil":"ฮีลีกัยนน","hit":"ฮิตไตต์","hmn":"ม้ง","ho":"ฮีรีโมตู","hr":"โครเอเชีย","hsb":"ซอร์เบียตอนบน","hsn":"จีนเซียง","ht":"เฮติครีโอล","hu":"ฮังการี","hup":"ฮูปา","hy":"อาร์เมเนีย","hz":"เฮเรโร","ia":"อินเตอร์ลิงกัว","iba":"อิบาน","ibb":"อิบิบิโอ","id":"อินโดนีเซีย","ie":"อินเตอร์ลิงกิว","ig":"อิกโบ","ii":"เสฉวนยี่","ik":"อีนูเปียก","ilo":"อีโลโก","inh":"อินกุช","io":"อีโด","is":"ไอซ์แลนด์","it":"อิตาลี","iu":"อินุกติตุต","izh":"อินเกรียน","ja":"ญี่ปุ่น","jam":"อังกฤษคลีโอลจาเมกา","jbo":"โลชบัน","jgo":"อึนกอมบา","jmc":"มาชาเม","jpr":"ยิว-เปอร์เซีย","jrb":"ยิว-อาหรับ","jut":"จัท","jv":"ชวา","ka":"จอร์เจีย","kaa":"การา-กาลพาก","kab":"กาไบล","kac":"กะฉิ่น","kaj":"คจู","kam":"คัมบา","kaw":"กวี","kbd":"คาร์บาเดีย","kbl":"คาเนมบู","kcg":"ทีแยป","kde":"มาคอนเด","kea":"คาบูเวอร์เดียนู","ken":"เกินยาง","kfo":"โคโร","kg":"คองโก","kgp":"เคนก่าง","kha":"กาสี","kho":"โคตัน","khq":"โคย์ราชีนี","khw":"โควาร์","ki":"กีกูยู","kiu":"เคอร์มานิกิ","kj":"กวนยามา","kk":"คาซัค","kkj":"คาโก","kl":"กรีนแลนด์","kln":"คาเลนจิน","km":"เขมร","kmb":"คิมบุนดู","kn":"กันนาดา","ko":"เกาหลี","koi":"โคมิ-เปียร์เมียค","kok":"กอนกานี","kos":"คูสไร","kpe":"กาแปล","kr":"คานูรี","krc":"คาราไช-บัลคาร์","kri":"คริโอ","krj":"กินารายอา","krl":"แกรเลียน","kru":"กุรุข","ks":"แคชเมียร์","ksb":"ชัมบาลา","ksf":"บาเฟีย","ksh":"โคโลญ","ku":"เคิร์ด","kum":"คูมืยค์","kut":"คูเทไน","kv":"โกมิ","kw":"คอร์นิช","ky":"คีร์กีซ","la":"ละติน","lad":"ลาดิโน","lag":"แลนจี","lah":"ลาฮ์นดา","lam":"แลมบา","lb":"ลักเซมเบิร์ก","lez":"เลซเกียน","lfn":"ลิงกัวฟรังกาโนวา","lg":"ยูกันดา","li":"ลิมเบิร์ก","lij":"ลิกูเรีย","liv":"ลิโวเนีย","lkt":"ลาโกตา","lmo":"ลอมบาร์ด","ln":"ลิงกาลา","lo":"ลาว","lol":"มองโก","lou":"ภาษาครีโอลุยเซียนา","loz":"โลซิ","lrc":"ลูรีเหนือ","lt":"ลิทัวเนีย","ltg":"ลัตเกล","lu":"ลูบา-กาตองกา","lua":"ลูบา-ลูลัว","lui":"ลุยเซโน","lun":"ลันดา","luo":"ลัว","lus":"มิโซ","luy":"ลูเยีย","lv":"ลัตเวีย","lzh":"จีนคลาสสิก","lzz":"แลซ","mad":"มาดูรา","maf":"มาฟา","mag":"มคหี","mai":"ไมถิลี","mak":"มากาซาร์","man":"มันดิงกา","mas":"มาไซ","mde":"มาบา","mdf":"มอคชา","mdr":"มานดาร์","men":"เมนเด","mer":"เมรู","mfe":"มอริสเยน","mg":"มาลากาซี","mga":"ไอริชกลาง","mgh":"มากัววา-มีทโท","mgo":"เมตา","mh":"มาร์แชลลิส","mi":"เมารี","mic":"มิกแมก","min":"มีนังกาเบา","mk":"มาซิโดเนีย","ml":"มาลายาลัม","mn":"มองโกเลีย","mnc":"แมนจู","mni":"มณีปุระ","moh":"โมฮอว์ก","mos":"โมซี","mr":"มราฐี","mrj":"มารีตะวันตก","ms":"มาเลย์","mt":"มอลตา","mua":"มันดัง","mul":"หลายภาษา","mus":"ครีก","mwl":"มีรันดา","mwr":"มารวาฑี","mwv":"เม็นตาไว","my":"พม่า","mye":"มยีน","myv":"เอียร์ซยา","mzn":"มาซันดารานี","na":"นาอูรู","nan":"จีนมินหนาน","nap":"นาโปลี","naq":"นามา","nb":"นอร์เวย์บุคมอล","nd":"เอ็นเดเบเลเหนือ","nds":"เยอรมันต่ำ","nds-NL":"แซกซอนใต้","ne":"เนปาล","new":"เนวาร์","ng":"ดองกา","nia":"นีอัส","niu":"นีวเว","njo":"อ๋าวนากา","nl":"ดัตช์","nl-BE":"เฟลมิช","nmg":"กวาซิโอ","nn":"นอร์เวย์นีนอสก์","nnh":"จีมบูน","no":"นอร์เวย์","nog":"โนไก","non":"นอร์สโบราณ","nov":"โนเวียล","nqo":"เอ็นโก","nr":"เอ็นเดเบเลใต้","nso":"โซโทเหนือ","nus":"เนือร์","nv":"นาวาโฮ","nwc":"เนวาร์ดั้งเดิม","ny":"เนียนจา","nym":"เนียมเวซี","nyn":"เนียนโกเล","nyo":"นิโอโร","nzi":"นซิมา","oc":"อ็อกซิตัน","oj":"โอจิบวา","om":"โอโรโม","or":"โอดิยา","os":"ออสเซเตีย","osa":"โอซากี","ota":"ตุรกีออตโตมัน","pa":"ปัญจาบ","pag":"ปางาซีนัน","pal":"ปะห์ลาวี","pam":"ปัมปางา","pap":"ปาเปียเมนโต","pau":"ปาเลา","pcd":"ปิการ์","pcm":"พิดจิน","pdc":"เยอรมันเพนซิลเวเนีย","pdt":"เพลาท์ดิช","peo":"เปอร์เซียโบราณ","pfl":"เยอรมันพาลาทิเนต","phn":"ฟินิเชีย","pi":"บาลี","pl":"โปแลนด์","pms":"พีดมอนต์","pnt":"พอนติก","pon":"พอห์นเพ","prg":"ปรัสเซีย","pro":"โปรวองซาลโบราณ","ps":"พัชโต","pt":"โปรตุเกส","pt-BR":"โปรตุเกส - บราซิล","pt-PT":"โปรตุเกส - ยุโรป","qu":"เคชวา","quc":"กีเช","qug":"ควิชัวไฮแลนด์ชิมโบราโซ","raj":"ราชสถาน","rap":"ราปานู","rar":"ราโรทองกา","rgn":"โรมัณโญ","rif":"ริฟฟิอัน","rm":"โรแมนซ์","rn":"บุรุนดี","ro":"โรมาเนีย","ro-MD":"มอลโดวา","rof":"รอมโบ","rom":"โรมานี","root":"รูท","rtm":"โรทูมัน","ru":"รัสเซีย","rue":"รูซิน","rug":"โรเวียนา","rup":"อาโรมาเนียน","rw":"รวันดา","rwk":"รวา","sa":"สันสกฤต","sad":"ซันดาเว","sah":"ซาคา","sam":"อราเมอิกซามาเรีย","saq":"แซมบูรู","sas":"ซาซัก","sat":"สันตาลี","saz":"เสาราษฏร์","sba":"กัมเบ","sbp":"แซงกู","sc":"ซาร์เดญา","scn":"ซิซิลี","sco":"สกอตส์","sd":"สินธิ","sdc":"ซาร์ดิเนียซาสซารี","sdh":"เคอร์ดิชใต้","se":"ซามิเหนือ","see":"เซนิกา","seh":"เซนา","sei":"เซรี","sel":"เซลคุป","ses":"โคย์ราโบโรเซนนี","sg":"ซันโก","sga":"ไอริชโบราณ","sgs":"ซาโมจิเตียน","sh":"เซอร์โบ-โครเอเชีย","shi":"ทาเชลีห์ท","shn":"ไทใหญ่","shu":"อาหรับ-ชาด","si":"สิงหล","sid":"ซิดาโม","sk":"สโลวัก","sl":"สโลวีเนีย","sli":"ไซลีเซียตอนล่าง","sly":"เซลายาร์","sm":"ซามัว","sma":"ซามิใต้","smj":"ซามิลูเล","smn":"ซามิอีนารี","sms":"ซามิสคอลต์","sn":"โชนา","snk":"โซนีนเก","so":"โซมาลี","sog":"ซอกดีน","sq":"แอลเบเนีย","sr":"เซอร์เบีย","srn":"ซูรินาเม","srr":"เซแรร์","ss":"สวาติ","ssy":"ซาโฮ","st":"โซโทใต้","stq":"ฟรีเซียนซัทเธอร์แลนด์","su":"ซุนดา","suk":"ซูคูมา","sus":"ซูซู","sux":"ซูเมอ","sv":"สวีเดน","sw":"สวาฮีลี","sw-CD":"สวาฮีลี - คองโก","swb":"โคเมอเรียน","syc":"ซีเรียแบบดั้งเดิม","syr":"ซีเรีย","szl":"ไซลีเซีย","ta":"ทมิฬ","tcy":"ตูลู","te":"เตลูกู","tem":"ทิมเน","teo":"เตโซ","ter":"เทเรโน","tet":"เตตุม","tg":"ทาจิก","th":"ไทย","ti":"ติกริญญา","tig":"ตีเกร","tiv":"ทิฟ","tk":"เติร์กเมน","tkl":"โตเกเลา","tkr":"แซคเซอร์","tl":"ตากาล็อก","tlh":"คลิงงอน","tli":"ทลิงกิต","tly":"ทาลิช","tmh":"ทามาเชก","tn":"บอตสวานา","to":"ตองกา","tog":"ไนอะซาตองกา","tpi":"ท็อกพิซิน","tr":"ตุรกี","tru":"ตูโรโย","trv":"ทาโรโก","ts":"ซิตซองกา","tsd":"ซาโคเนีย","tsi":"ซิมชีแอน","tt":"ตาตาร์","ttt":"ตัตมุสลิม","tum":"ทุมบูกา","tvl":"ตูวาลู","tw":"ทวิ","twq":"ตัสซาวัค","ty":"ตาฮิตี","tyv":"ตูวา","tzm":"ทามาไซต์แอตลาสกลาง","udm":"อุดมูร์ต","ug":"อุยกูร์","uga":"ยูการิต","uk":"ยูเครน","umb":"อุมบุนดู","und":"ภาษาที่ไม่รู้จัก","ur":"อูรดู","uz":"อุซเบก","vai":"ไว","ve":"เวนดา","vec":"เวเนโต้","vep":"เวปส์","vi":"เวียดนาม","vls":"เฟลมิชตะวันตก","vmf":"เมน-ฟรานโกเนีย","vo":"โวลาพึค","vot":"โวทิก","vro":"โวโร","vun":"วุนจู","wa":"วาโลนี","wae":"วัลเซอร์","wal":"วาลาโม","war":"วาเรย์","was":"วาโช","wbp":"วอล์เพอร์รี","wo":"โวลอฟ","wuu":"จีนอู๋","xal":"คัลมืยค์","xh":"คะห์โอซา","xmf":"เมเกรเลีย","xog":"โซกา","yao":"เย้า","yap":"ยัป","yav":"แยงเบน","ybb":"เยมบา","yi":"ยิดดิช","yo":"โยรูบา","yrl":"เหงงกาตุ","yue":"กวางตุ้ง","za":"จ้วง","zap":"ซาโปเตก","zbl":"บลิสซิมโบลส์","zea":"เซแลนด์","zen":"เซนากา","zgh":"ทามาไซต์โมร็อกโกมาตรฐาน","zh":"จีน","zh-Hans":"จีนประยุกต์","zh-Hant":"จีนดั้งเดิม","zu":"ซูลู","zun":"ซูนิ","zxx":"ไม่มีข้อมูลภาษา","zza":"ซาซา"},"short":{"az":"อะเซอรี","en-GB":"อังกฤษ - อังกฤษ","en-US":"อังกฤษ - อเมริกัน"},"narrow":{}},"region":{"long":{"142":"เอเชีย","143":"เอเชียกลาง","145":"เอเชียตะวันตก","150":"ยุโรป","151":"ยุโรปตะวันออก","154":"ยุโรปเหนือ","155":"ยุโรปตะวันตก","202":"แอฟริกาใต้สะฮารา","419":"ละตินอเมริกา","001":"โลก","002":"แอฟริกา","003":"อเมริกาเหนือ","005":"อเมริกาใต้","009":"โอเชียเนีย","011":"แอฟริกาตะวันตก","013":"อเมริกากลาง","014":"แอฟริกาตะวันออก","015":"แอฟริกาเหนือ","017":"แอฟริกากลาง","018":"แอฟริกาตอนใต้","019":"อเมริกา","021":"อเมริกาตอนเหนือ","029":"แคริบเบียน","030":"เอเชียตะวันออก","034":"เอเชียใต้","035":"เอเชียตะวันออกเฉียงใต้","039":"ยุโรปใต้","053":"ออสตราเลเซีย","054":"เมลานีเซีย","057":"เขตไมโครนีเซีย","061":"โปลินีเซีย","AC":"เกาะแอสเซนชัน","AD":"อันดอร์รา","AE":"สหรัฐอาหรับเอมิเรตส์","AF":"อัฟกานิสถาน","AG":"แอนติกาและบาร์บูดา","AI":"แองกวิลลา","AL":"แอลเบเนีย","AM":"อาร์เมเนีย","AO":"แองโกลา","AQ":"แอนตาร์กติกา","AR":"อาร์เจนตินา","AS":"อเมริกันซามัว","AT":"ออสเตรีย","AU":"ออสเตรเลีย","AW":"อารูบา","AX":"หมู่เกาะโอลันด์","AZ":"อาเซอร์ไบจาน","BA":"บอสเนียและเฮอร์เซโกวีนา","BB":"บาร์เบโดส","BD":"บังกลาเทศ","BE":"เบลเยียม","BF":"บูร์กินาฟาโซ","BG":"บัลแกเรีย","BH":"บาห์เรน","BI":"บุรุนดี","BJ":"เบนิน","BL":"เซนต์บาร์เธเลมี","BM":"เบอร์มิวดา","BN":"บรูไน","BO":"โบลิเวีย","BQ":"เนเธอร์แลนด์แคริบเบียน","BR":"บราซิล","BS":"บาฮามาส","BT":"ภูฏาน","BV":"เกาะบูเว","BW":"บอตสวานา","BY":"เบลารุส","BZ":"เบลีซ","CA":"แคนาดา","CC":"หมู่เกาะโคโคส (คีลิง)","CD":"คองโก - กินชาซา","CF":"สาธารณรัฐแอฟริกากลาง","CG":"คองโก - บราซซาวิล","CH":"สวิตเซอร์แลนด์","CI":"โกตดิวัวร์","CK":"หมู่เกาะคุก","CL":"ชิลี","CM":"แคเมอรูน","CN":"จีน","CO":"โคลอมเบีย","CP":"เกาะคลิปเปอร์ตัน","CR":"คอสตาริกา","CU":"คิวบา","CV":"เคปเวิร์ด","CW":"คูราเซา","CX":"เกาะคริสต์มาส","CY":"ไซปรัส","CZ":"เช็ก","DE":"เยอรมนี","DG":"ดิเอโกการ์เซีย","DJ":"จิบูตี","DK":"เดนมาร์ก","DM":"โดมินิกา","DO":"สาธารณรัฐโดมินิกัน","DZ":"แอลจีเรีย","EA":"เซวตาและเมลียา","EC":"เอกวาดอร์","EE":"เอสโตเนีย","EG":"อียิปต์","EH":"ซาฮาราตะวันตก","ER":"เอริเทรีย","ES":"สเปน","ET":"เอธิโอเปีย","EU":"สหภาพยุโรป","EZ":"ยูโรโซน","FI":"ฟินแลนด์","FJ":"ฟิจิ","FK":"หมู่เกาะฟอล์กแลนด์","FM":"ไมโครนีเซีย","FO":"หมู่เกาะแฟโร","FR":"ฝรั่งเศส","GA":"กาบอง","GB":"สหราชอาณาจักร","GD":"เกรเนดา","GE":"จอร์เจีย","GF":"เฟรนช์เกียนา","GG":"เกิร์นซีย์","GH":"กานา","GI":"ยิบรอลตาร์","GL":"กรีนแลนด์","GM":"แกมเบีย","GN":"กินี","GP":"กวาเดอลูป","GQ":"อิเควทอเรียลกินี","GR":"กรีซ","GS":"เกาะเซาท์จอร์เจียและหมู่เกาะเซาท์แซนด์วิช","GT":"กัวเตมาลา","GU":"กวม","GW":"กินี-บิสเซา","GY":"กายอานา","HK":"เขตปกครองพิเศษฮ่องกงแห่งสาธารณรัฐประชาชนจีน","HM":"เกาะเฮิร์ดและหมู่เกาะแมกดอนัลด์","HN":"ฮอนดูรัส","HR":"โครเอเชีย","HT":"เฮติ","HU":"ฮังการี","IC":"หมู่เกาะคานารี","ID":"อินโดนีเซีย","IE":"ไอร์แลนด์","IL":"อิสราเอล","IM":"เกาะแมน","IN":"อินเดีย","IO":"บริติชอินเดียนโอเชียนเทร์ริทอรี","IQ":"อิรัก","IR":"อิหร่าน","IS":"ไอซ์แลนด์","IT":"อิตาลี","JE":"เจอร์ซีย์","JM":"จาเมกา","JO":"จอร์แดน","JP":"ญี่ปุ่น","KE":"เคนยา","KG":"คีร์กีซสถาน","KH":"กัมพูชา","KI":"คิริบาส","KM":"คอโมโรส","KN":"เซนต์คิตส์และเนวิส","KP":"เกาหลีเหนือ","KR":"เกาหลีใต้","KW":"คูเวต","KY":"หมู่เกาะเคย์แมน","KZ":"คาซัคสถาน","LA":"ลาว","LB":"เลบานอน","LC":"เซนต์ลูเซีย","LI":"ลิกเตนสไตน์","LK":"ศรีลังกา","LR":"ไลบีเรีย","LS":"เลโซโท","LT":"ลิทัวเนีย","LU":"ลักเซมเบิร์ก","LV":"ลัตเวีย","LY":"ลิเบีย","MA":"โมร็อกโก","MC":"โมนาโก","MD":"มอลโดวา","ME":"มอนเตเนโกร","MF":"เซนต์มาร์ติน","MG":"มาดากัสการ์","MH":"หมู่เกาะมาร์แชลล์","MK":"มาซิโดเนียเหนือ","ML":"มาลี","MM":"เมียนมาร์ (พม่า)","MN":"มองโกเลีย","MO":"เขตปกครองพิเศษมาเก๊าแห่งสาธารณรัฐประชาชนจีน","MP":"หมู่เกาะนอร์เทิร์นมาเรียนา","MQ":"มาร์ตินีก","MR":"มอริเตเนีย","MS":"มอนต์เซอร์รัต","MT":"มอลตา","MU":"มอริเชียส","MV":"มัลดีฟส์","MW":"มาลาวี","MX":"เม็กซิโก","MY":"มาเลเซีย","MZ":"โมซัมบิก","NA":"นามิเบีย","NC":"นิวแคลิโดเนีย","NE":"ไนเจอร์","NF":"เกาะนอร์ฟอล์ก","NG":"ไนจีเรีย","NI":"นิการากัว","NL":"เนเธอร์แลนด์","NO":"นอร์เวย์","NP":"เนปาล","NR":"นาอูรู","NU":"นีอูเอ","NZ":"นิวซีแลนด์","OM":"โอมาน","PA":"ปานามา","PE":"เปรู","PF":"เฟรนช์โปลินีเซีย","PG":"ปาปัวนิวกินี","PH":"ฟิลิปปินส์","PK":"ปากีสถาน","PL":"โปแลนด์","PM":"แซงปีแยร์และมีเกอลง","PN":"หมู่เกาะพิตแคร์น","PR":"เปอร์โตริโก","PS":"ดินแดนปาเลสไตน์","PT":"โปรตุเกส","PW":"ปาเลา","PY":"ปารากวัย","QA":"กาตาร์","QO":"เอาต์ไลอิงโอเชียเนีย","RE":"เรอูนียง","RO":"โรมาเนีย","RS":"เซอร์เบีย","RU":"รัสเซีย","RW":"รวันดา","SA":"ซาอุดีอาระเบีย","SB":"หมู่เกาะโซโลมอน","SC":"เซเชลส์","SD":"ซูดาน","SE":"สวีเดน","SG":"สิงคโปร์","SH":"เซนต์เฮเลนา","SI":"สโลวีเนีย","SJ":"สฟาลบาร์และยานไมเอน","SK":"สโลวะเกีย","SL":"เซียร์ราลีโอน","SM":"ซานมาริโน","SN":"เซเนกัล","SO":"โซมาเลีย","SR":"ซูรินาเม","SS":"ซูดานใต้","ST":"เซาตูเมและปรินซิปี","SV":"เอลซัลวาดอร์","SX":"ซินต์มาร์เทน","SY":"ซีเรีย","SZ":"เอสวาตีนี","TA":"ทริสตันดาคูนา","TC":"หมู่เกาะเติกส์และหมู่เกาะเคคอส","TD":"ชาด","TF":"เฟรนช์เซาเทิร์นเทร์ริทอรีส์","TG":"โตโก","TH":"ไทย","TJ":"ทาจิกิสถาน","TK":"โตเกเลา","TL":"ติมอร์-เลสเต","TM":"เติร์กเมนิสถาน","TN":"ตูนิเซีย","TO":"ตองกา","TR":"ตุรกี","TT":"ตรินิแดดและโตเบโก","TV":"ตูวาลู","TW":"ไต้หวัน","TZ":"แทนซาเนีย","UA":"ยูเครน","UG":"ยูกันดา","UM":"หมู่เกาะรอบนอกของสหรัฐอเมริกา","UN":"สหประชาชาติ","US":"สหรัฐอเมริกา","UY":"อุรุกวัย","UZ":"อุซเบกิสถาน","VA":"นครวาติกัน","VC":"เซนต์วินเซนต์และเกรนาดีนส์","VE":"เวเนซุเอลา","VG":"หมู่เกาะบริติชเวอร์จิน","VI":"หมู่เกาะเวอร์จินของสหรัฐอเมริกา","VN":"เวียดนาม","VU":"วานูอาตู","WF":"วาลลิสและฟุตูนา","WS":"ซามัว","XA":"สำเนียงไม่จริง","XB":"Bidi ไม่จริง","XK":"โคโซโว","YE":"เยเมน","YT":"มายอต","ZA":"แอฟริกาใต้","ZM":"แซมเบีย","ZW":"ซิมบับเว","ZZ":"ภูมิภาคที่ไม่รู้จัก"},"short":{"GB":"สหราชอาณาจักร","HK":"ฮ่องกง","MO":"มาเก๊า","PS":"ปาเลสไตน์","UN":"สหประชาชาติ","US":"สหรัฐฯ"},"narrow":{}},"script":{"long":{"Adlm":"Adlm","Afak":"อะฟาคา","Aghb":"แอลเบเนีย คอเคเซีย","Ahom":"Ahom","Arab":"อาหรับ","Armi":"อิมพีเรียล อราเมอิก","Armn":"อาร์เมเนีย","Avst":"อเวสตะ","Bali":"บาหลี","Bamu":"บามุม","Bass":"บัสซา","Batk":"บาตัก","Beng":"เบงกาลี","Bhks":"Bhks","Blis":"บลิสซิมโบลส์","Bopo":"ปอพอมอฟอ","Brah":"พราหมี","Brai":"เบรลล์","Bugi":"บูกิส","Buhd":"บูฮิด","Cakm":"ชากมา","Cans":"สัญลักษณ์ชนเผ่าพื้นเมืองแคนาดา","Cari":"คาเรีย","Cham":"จาม","Cher":"เชอโรกี","Cirt":"เซิร์ท","Copt":"คอปติก","Cprt":"ไซเปรียท","Cyrl":"ซีริลลิก","Cyrs":"เชอร์ชสลาโวนิกซีริลลิกโบราณ","Deva":"เทวนาครี","Dogr":"Dogr","Dsrt":"เดเซเรท","Dupl":"ชวเลขดัปโลยัน","Egyd":"ดีโมติกอียิปต์","Egyh":"เฮียราติกอียิปต์","Egyp":"เฮียโรกลิฟส์อียิปต์","Elba":"เอลบ์ซาน","Elym":"Elym","Ethi":"เอธิโอปิก","Geok":"คัตซูรีจอร์เจีย","Geor":"จอร์เจีย","Glag":"กลาโกลิติก","Gong":"Gong","Gonm":"Gonm","Goth":"โกธิก","Gran":"คฤณห์","Grek":"กรีก","Gujr":"คุชราต","Guru":"กูร์มูคี","Hanb":"จีนกลาง","Hang":"ฮันกึล","Hani":"ฮั่น","Hano":"ฮานูโนโอ","Hans":"ตัวย่อ","Hant":"ตัวเต็ม","Hatr":"Hatr","Hebr":"ฮีบรู","Hira":"ฮิระงะนะ","Hluw":"อักขระอานาโตเลีย","Hmng":"ปาเฮาห์ม้ง","Hmnp":"Hmnp","Hrkt":"คะตะกะนะหรือฮิระงะนะ","Hung":"ฮังการีโบราณ","Inds":"อินดัส","Ital":"อิตาลีโบราณ","Jamo":"จาโม","Java":"ชวา","Jpan":"ญี่ปุ่น","Jurc":"จูร์เชน","Kali":"คยาห์","Kana":"คะตะกะนะ","Khar":"ขโรษฐี","Khmr":"เขมร","Khoj":"คอจคี","Knda":"กันนาดา","Kore":"เกาหลี","Kpel":"เปลเล","Kthi":"กายติ","Lana":"ล้านนา","Laoo":"ลาว","Latf":"ลาติน - ฟรังเตอร์","Latg":"ลาติน - แกลิก","Latn":"ละติน","Lepc":"เลปชา","Limb":"ลิมบู","Lina":"ลีเนียร์เอ","Linb":"ลีเนียร์บี","Lisu":"เฟรเซอร์","Loma":"โลมา","Lyci":"ไลเซีย","Lydi":"ลีเดีย","Mahj":"มหาชนี","Maka":"Maka","Mand":"แมนเดียน","Mani":"มานิแชน","Marc":"Marc","Maya":"มายาไฮโรกลิฟส์","Medf":"Medf","Mend":"เมนเด","Merc":"เคอร์ซีฟ-เมโรอิติก","Mero":"เมโรติก","Mlym":"มาลายาลัม","Modi":"โมฑี","Mong":"มองโกเลีย","Moon":"มูน","Mroo":"มโร","Mtei":"เมเทมาเยก","Mult":"Mult","Mymr":"พม่า","Nand":"Nand","Narb":"อาระเบียเหนือโบราณ","Nbat":"นาบาทาเอียน","Newa":"Newa","Nkgb":"กีบา-นาซี","Nkoo":"เอ็นโก","Nshu":"นุซุ","Ogam":"โอคัม","Olck":"โอลชิกิ","Orkh":"ออร์คอน","Orya":"โอริยา","Osge":"Osge","Osma":"ออสมันยา","Palm":"พาลไมรีน","Pauc":"ป่อจิ้งฮอ","Perm":"เปอร์มิกโบราณ","Phag":"ฟากส์-ปา","Phli":"ปะห์ลาวีอินสคริปชันแนล","Phlp":"ปะห์ลาวีซอลเตอร์","Phlv":"ปะห์ลาวีบุ๊ก","Phnx":"ฟินิเชีย","Plrd":"สัทศาสตร์พอลลาร์ด","Prti":"พาร์เทียอินสคริปชันแนล","Qaag":"Qaag","Rjng":"เรจัง","Rohg":"Rohg","Roro":"รองโกรองโก","Runr":"รูนิก","Samr":"ซามาเรีย","Sara":"ซาราติ","Sarb":"อาระเบียใต้โบราณ","Saur":"โสวรัสตระ","Sgnw":"ไซน์ไรติ้ง","Shaw":"ซอเวียน","Shrd":"ชาราดา","Sidd":"สิทธัม","Sind":"คุดาวาดี","Sinh":"สิงหล","Sogd":"Sogd","Sogo":"Sogo","Sora":"โสราสมเป็ง","Soyo":"Soyo","Sund":"ซุนดา","Sylo":"ซิโลตินากรี","Syrc":"ซีเรีย","Syre":"ซีเรียเอสทรานจีโล","Syrj":"ซีเรียตะวันตก","Syrn":"ซีเรียตะวันออก","Tagb":"ตักบันวา","Takr":"ทาครี","Tale":"ไทเล","Talu":"ไทลื้อใหม่","Taml":"ทมิฬ","Tang":"ตันกัท","Tavt":"ไทเวียต","Telu":"เตลูกู","Teng":"เทงกวาร์","Tfng":"ทิฟินาก","Tglg":"ตากาล็อก","Thaa":"ทานา","Thai":"ไทย","Tibt":"ทิเบต","Tirh":"เทอฮุทา","Ugar":"ยูการิต","Vaii":"ไว","Visp":"คำพูดที่มองเห็นได้","Wara":"วารังกสิติ","Wcho":"Wcho","Wole":"โอลีเอ","Xpeo":"เปอร์เซียโบราณ","Xsux":"อักษรรูปลิ่มสุเมเรีย-อัคคาเดีย","Yiii":"ยิ","Zanb":"Zanb","Zinh":"อินเฮอริต","Zmth":"เครื่องหมายทางคณิตศาสตร์","Zsye":"อีโมจิ","Zsym":"สัญลักษณ์","Zxxx":"ไม่มีภาษาเขียน","Zyyy":"สามัญ","Zzzz":"ตัวอักษรที่ไม่รู้จัก"},"short":{},"narrow":{}},"currency":{"long":{"ADP":"เปเซตาอันดอร์รา","AED":"เดอร์แฮมสหรัฐอาหรับเอมิเรตส์","AFA":"อัฟกานีอัฟกานิสถาน (1927–2002)","AFN":"อัฟกานิอัฟกานิสถาน","ALK":"ALK","ALL":"เลกแอลเบเนีย","AMD":"แดรมอาร์เมเนีย","ANG":"กิลเดอร์เนเธอร์แลนด์แอนทิลลิส","AOA":"กวานซาแองโกลา","AOK":"กวานซาแองโกลา (1977–1990)","AON":"นิวกวานซาแองโกลา (1990–2000)","AOR":"กวานซารีจัสทาโดแองโกลา (1995–1999)","ARA":"ออสตรัลอาร์เจนตินา","ARL":"เปโซเลย์อาร์เจนตินา (1970–1983)","ARM":"เปโซอาร์เจนตินา (1881–1970)","ARP":"เปโซอาร์เจนตินา (1983–1985)","ARS":"เปโซอาร์เจนตินา","ATS":"ชิลลิงออสเตรีย","AUD":"ดอลลาร์ออสเตรเลีย","AWG":"ฟลอรินอารูบา","AZM":"มานัตอาเซอร์ไบจาน (1993–2006)","AZN":"มานัตอาเซอร์ไบจาน","BAD":"ดีนาร์บอสเนีย-เฮอร์เซโกวีนา","BAM":"มาร์กบอสเนีย-เฮอร์เซโกวีนา","BAN":"ดีนาร์ใหม่บอสเนีย-เฮอร์เซโกวีนา (1994–1997)","BBD":"ดอลลาร์บาร์เบโดส","BDT":"ตากาบังกลาเทศ","BEC":"ฟรังก์เบลเยียม (เปลี่ยนแปลงได้)","BEF":"ฟรังก์เบลเยียม","BEL":"ฟรังก์เบลเยียม (การเงิน)","BGL":"ฮาร์ดเลฟบัลแกเรีย","BGM":"โซเชียลลิสต์เลฟบัลแกเรีย","BGN":"เลฟบัลแกเรีย","BGO":"เลฟบัลเกเรีย (1879–1952)","BHD":"ดีนาร์บาห์เรน","BIF":"ฟรังก์บุรุนดี","BMD":"ดอลลาร์เบอร์มิวดา","BND":"ดอลลาร์บรูไน","BOB":"โบลิเวียโนโบลิเวีย","BOL":"โบลิเวียโนโบลิเวีย (1863–1963)","BOP":"เปโซโบลิเวีย","BOV":"มฟดอลโบลิเวีย","BRB":"ครูเซโรโนโวบราซิล (1967–1986)","BRC":"ครูซาโดบราซิล","BRE":"ครูเซโรบราซิล (1990–1993)","BRL":"เรียลบราซิล","BRN":"ครูซาโดโนโวบราซิล","BRR":"ครูเซโรบราซิล","BRZ":"ครูเซโรบราซิล (1942–1967)","BSD":"ดอลลาร์บาฮามาส","BTN":"เอ็งกุลตรัมภูฏาน","BUK":"จ๊าดพม่า","BWP":"ปูลาบอตสวานา","BYB":"นิวรูเบิลเบลารุส (1994–1999)","BYN":"รูเบิลเบลารุส","BYR":"รูเบิลเบลารุส (2000–2016)","BZD":"ดอลลาร์เบลีซ","CAD":"ดอลลาร์แคนาดา","CDF":"ฟรังก์คองโก","CHE":"ยูโรดับเบิลยูไออาร์","CHF":"ฟรังก์สวิส","CHW":"ฟรังก์ดับเบิลยูไออาร์","CLE":"เอสคูโดชิลี","CLF":"ฟูเมนโตชิลี","CLP":"เปโซชิลี","CNH":"หยวน","CNX":"CNX","CNY":"หยวนจีน","COP":"เปโซโคลอมเบีย","COU":"วาเลอร์เรียลโคลอมเบีย","CRC":"โกลองคอสตาริกา","CSD":"ดีนาร์เซอร์เบียเก่า","CSK":"ฮาร์ดโครูนาเช็กโกสโลวัก","CUC":"เปโซคิวบา (แปลงสภาพ)","CUP":"เปโซคิวบา","CVE":"เอสคูโดเคปเวิร์ด","CYP":"ปอนด์ไซปรัส","CZK":"โครูนาสาธารณรัฐเช็ก","DDM":"มาร์กเยอรมันตะวันออก","DEM":"มาร์กเยอรมัน","DJF":"ฟรังก์จิบูตี","DKK":"โครนเดนมาร์ก","DOP":"เปโซโดมินิกัน","DZD":"ดีนาร์แอลจีเรีย","ECS":"ซูเกรเอกวาดอร์","ECV":"วาเลอร์คอนสแตนต์เอกวาดอร์","EEK":"ครูนเอสโตเนีย","EGP":"ปอนด์อียิปต์","ERN":"แนกฟาเอริเทรีย","ESA":"เปเซตาสเปน (บัญชีเอ)","ESB":"เปเซตาสเปน (บัญชีที่เปลี่ยนแปลงได้)","ESP":"เปเซตาสเปน","ETB":"เบอรร์เอธิโอเปีย","EUR":"ยูโร","FIM":"มาร์กกาฟินแลนด์","FJD":"ดอลลาร์ฟิจิ","FKP":"ปอนด์หมู่เกาะฟอล์กแลนด์","FRF":"ฟรังก์ฝรั่งเศส","GBP":"ปอนด์สเตอร์ลิง (สหราชอาณาจักร)","GEK":"คูปอนลาริตจอร์เจีย","GEL":"ลารีจอร์เจีย","GHC":"เซดีกานา (1979–2007)","GHS":"เซดีกานา","GIP":"ปอนด์ยิบรอลตาร์","GMD":"ดาลาซีแกมเบีย","GNF":"ฟรังก์กินี","GNS":"ไซลีกินี","GQE":"เอ็กเวเลอิเควทอเรียลกินี","GRD":"ดรัชมากรีก","GTQ":"เควตซัลกัวเตมาลา","GWE":"เอสคูโดกินีโปรตุเกส","GWP":"เปโซกินี-บิสเซา","GYD":"ดอลลาร์กายอานา","HKD":"ดอลลาร์ฮ่องกง","HNL":"เลมปิราฮอนดูรัส","HRD":"ดีนาร์โครเอเชีย","HRK":"คูนาโครเอเชีย","HTG":"กูร์ดเฮติ","HUF":"ฟอรินต์ฮังการี","IDR":"รูเปียห์อินโดนีเซีย","IEP":"ปอนด์ไอริช","ILP":"ปอนด์อิสราเอล","ILR":"ILR","ILS":"นิวเชเกลอิสราเอล","INR":"รูปีอินเดีย","IQD":"ดีนาร์อิรัก","IRR":"เรียลอิหร่าน","ISJ":"ISJ","ISK":"โครนาไอซ์แลนด์","ITL":"ลีราอิตาลี","JMD":"ดอลลาร์จาเมกา","JOD":"ดีนาร์จอร์แดน","JPY":"เยนญี่ปุ่น","KES":"ชิลลิงเคนยา","KGS":"ซอมคีร์กีซสถาน","KHR":"เรียลกัมพูชา","KMF":"ฟรังก์คอโมโรส","KPW":"วอนเกาหลีเหนือ","KRH":"ฮวานเกาหลีใต้ (1953–1962)","KRO":"วอนเกาหลีใต้ (1945–1953)","KRW":"วอนเกาหลีใต้","KWD":"ดีนาร์คูเวต","KYD":"ดอลลาร์หมู่เกาะเคย์แมน","KZT":"เทงเจคาซัคสถาน","LAK":"กีบลาว","LBP":"ปอนด์เลบานอน","LKR":"รูปีศรีลังกา","LRD":"ดอลลาร์ไลบีเรีย","LSL":"โลตีเลโซโท","LTL":"ลีตัสลิทัวเนีย","LTT":"ทาโลนัสลิทัวเนีย","LUC":"คอนเวอร์ทิเบิลฟรังก์ลักเซมเบิร์ก","LUF":"ฟรังก์ลักเซมเบิร์ก","LUL":"ไฟแนลเชียลฟรังก์ลักเซมเบิร์ก","LVL":"ลัตส์ลัตเวีย","LVR":"รูเบิลลัตเวีย","LYD":"ดีนาร์ลิเบีย","MAD":"ดีแรห์มโมร็อกโก","MAF":"ฟรังก์โมร็อกโก","MCF":"ฟรังก์โมนาโก","MDC":"บัตรปันส่วนมอลโดวา","MDL":"ลิวมอลโดวา","MGA":"อาเรียรีมาลากาซี","MGF":"ฟรังก์มาดากัสการ์","MKD":"ดีนาร์มาซิโดเนีย","MKN":"ดีนาร์มาซิโดเนีย (1992–1993)","MLF":"ฟรังก์มาลี","MMK":"จ๊าตพม่า","MNT":"ทูกริกมองโกเลีย","MOP":"ปาตากามาเก๊า","MRO":"อูกียามอริเตเนีย (1973–2017)","MRU":"อูกียามอริเตเนีย","MTL":"ลีรามอลตา","MTP":"ปอนด์มอลตา","MUR":"รูปีมอริเชียส","MVP":"MVP","MVR":"รูฟิยามัลดีฟส์","MWK":"ควาชามาลาวี","MXN":"เปโซเม็กซิโก","MXP":"เงินเปโซเม็กซิโก (1861–1992)","MXV":"ยูนิแดด ดี อินเวอร์ชั่น เม็กซิโก","MYR":"ริงกิตมาเลเซีย","MZE":"เอสคูโดโมซัมบิก","MZM":"เมติคัลโมซัมบิกเก่า","MZN":"เมติคัลโมซัมบิก","NAD":"ดอลลาร์นามิเบีย","NGN":"ไนราไนจีเรีย","NIC":"คอร์โดบานิการากัว","NIO":"กอร์โดบานิการากัว","NLG":"กิลเดอร์เนเธอร์แลนด์","NOK":"โครนนอร์เวย์","NPR":"รูปีเนปาล","NZD":"ดอลลาร์นิวซีแลนด์","OMR":"เรียลโอมาน","PAB":"บัลบัวปานามา","PEI":"อินตีเปรู","PEN":"ซอลเปรู","PES":"ซอลเปรู (1863–1965)","PGK":"กีนาปาปัวนิวกินี","PHP":"เปโซฟิลิปปินส์","PKR":"รูปีปากีสถาน","PLN":"ซลอตีโปแลนด์","PLZ":"ซลอตีโปแลนด์ (1950–1995)","PTE":"เอสคูโดโปรตุเกส","PYG":"กวารานีปารากวัย","QAR":"เรียลกาตาร์","RHD":"ดอลลาร์โรดีเซีย","ROL":"ลิวโรมาเนียเก่า","RON":"ลิวโรมาเนีย","RSD":"ดีนาร์เซอร์เบีย","RUB":"รูเบิลรัสเซีย","RUR":"รูเบิลรัสเซีย (1991–1998)","RWF":"ฟรังก์รวันดา","SAR":"ริยัลซาอุดีอาระเบีย","SBD":"ดอลลาร์หมู่เกาะโซโลมอน","SCR":"รูปีเซเชลส์","SDD":"ดีนาร์ซูดานเก่า","SDG":"ปอนด์ซูดาน","SDP":"ปอนด์ซูดานเก่า","SEK":"โครนาสวีเดน","SGD":"ดอลลาร์สิงคโปร์","SHP":"ปอนด์เซนต์เฮเลนา","SIT":"ทอลาร์สโลวีเนีย","SKK":"โครูนาสโลวัก","SLL":"ลีโอนเซียร์ราลีโอน","SOS":"ชิลลิงโซมาเลีย","SRD":"ดอลลาร์ซูรินาเม","SRG":"กิลเดอร์ซูรินาเม","SSP":"ปอนด์ซูดานใต้","STD":"ดอบราเซาตูเมและปรินซิปี (1977–2017)","STN":"ดอบราเซาตูเมและปรินซิปี","SUR":"รูเบิลโซเวียต","SVC":"โคลอนเอลซัลวาดอร์","SYP":"ปอนด์ซีเรีย","SZL":"ลิลันเจนีสวาซิ","THB":"บาท","TJR":"รูเบิลทาจิกิสถาน","TJS":"โซโมนิทาจิกิสถาน","TMM":"มานัตเติร์กเมนิสถาน (1993–2009)","TMT":"มานัตเติร์กเมนิสถาน","TND":"ดีนาร์ตูนิเซีย","TOP":"พาแองกาตองกา","TPE":"เอสคูโดติมอร์","TRL":"ลีราตุรกีเก่า","TRY":"ลีราตุรกี","TTD":"ดอลลาร์ตรินิแดดและโตเบโก","TWD":"ดอลลาร์ไต้หวันใหม่","TZS":"ชิลลิงแทนซาเนีย","UAH":"ฮรีฟเนียยูเครน","UAK":"คาร์โบวาเนตซ์ยูเครน","UGS":"ชิลลิงยูกันดา (1966–1987)","UGX":"ชิลลิงยูกันดา","USD":"ดอลลาร์สหรัฐ","USN":"ดอลลาร์สหรัฐ (วันถัดไป)","USS":"ดอลลาร์สหรัฐ (วันเดียวกัน)","UYI":"เปโซเอนยูนิแดดเซสอินเด็กซาแดสอุรุกวัย","UYP":"เปโซอุรุกวัย (1975–1993)","UYU":"เปโซอุรุกวัย","UYW":"UYW","UZS":"ซอมอุซเบกิสถาน","VEB":"โบลิวาร์เวเนซุเอลา (1871–2008)","VEF":"โบลิวาร์เวเนซุเอลา","VES":"โบลีวาร์เวเนซุเอลา","VND":"ดองเวียดนาม","VNN":"ดองเวียดนาม (1978–1985)","VUV":"วาตูวานูอาตู","WST":"ทาลาซามัว","XAF":"ฟรังก์เซฟาธนาคารรัฐแอฟริกากลาง","XAG":"เงิน","XAU":"ทอง","XBA":"หน่วยคอมโพสิตยุโรป","XBB":"หน่วยโมเนทารียุโรป","XBC":"หน่วยบัญชียุโรป [XBC]","XBD":"หน่วยบัญชียุโรป [XBD]","XCD":"ดอลลาร์แคริบเบียนตะวันออก","XDR":"สิทธิถอนเงินพิเศษ","XEU":"หน่วยสกุลเงินยุโรป","XFO":"ฟรังก์ทองฝรั่งเศส","XFU":"ฟรังก์ยูไอซีฝรั่งเศส","XOF":"ฟรังก์เซฟาธนาคารกลางรัฐแอฟริกาตะวันตก","XPD":"พัลเลเดียม","XPF":"ฟรังก์ซีเอฟพี","XPT":"แพลตินัม","XRE":"กองทุนไรเน็ต","XSU":"ซูเกร","XTS":"รหัสทดสอบสกุลเงิน","XUA":"หน่วยบัญชี เอดีบี","XXX":"ไม่ทราบชื่อสกุลเงิน","YDD":"ดีนาร์เยเมน","YER":"เรียลเยเมน","YUD":"ฮาร์ดดีนาร์ยูโกสลาเวีย","YUM":"โนวิย์ดีนาร์ยูโกสลาเวีย","YUN":"คอนเวอร์ทิเบิลดีนาร์ยูโกสลาเวีย","YUR":"ดีนาร์ปฏิรูปยูโกสลาเวีย (1992–1993)","ZAL":"แรนด์แอฟริกาใต้ (การเงิน)","ZAR":"แรนด์แอฟริกาใต้","ZMK":"ควาชาแซมเบีย (1968–2012)","ZMW":"ควาชาแซมเบีย","ZRN":"นิวแซร์คองโก","ZRZ":"แซร์คองโก","ZWD":"ดอลลาร์ซิมบับเว","ZWL":"ดอลลาร์ซิมบับเว (2009)","ZWR":"ดอลลาร์ซิมบับเว (2008)"},"short":{},"narrow":{}}},"patterns":{"locale":"{0} ({1})"}}},"availableLocales":["th"],"aliases":{},"parentLocales":{}},
    {"data":{"zh":{"types":{"language":{"long":{"aa":"阿法尔语","ab":"阿布哈西亚语","ace":"亚齐语","ach":"阿乔利语","ada":"阿当梅语","ady":"阿迪格语","ae":"阿维斯塔语","af":"南非荷兰语","afh":"阿弗里希利语","agq":"亚罕语","ain":"阿伊努语","ak":"阿肯语","akk":"阿卡德语","ale":"阿留申语","alt":"南阿尔泰语","am":"阿姆哈拉语","an":"阿拉贡语","ang":"古英语","anp":"昂加语","ar":"阿拉伯语","ar-001":"现代标准阿拉伯语","arc":"阿拉米语","arn":"马普切语","arp":"阿拉帕霍语","ars":"纳吉迪阿拉伯语","arw":"阿拉瓦克语","as":"阿萨姆语","asa":"帕雷语","ast":"阿斯图里亚斯语","av":"阿瓦尔语","awa":"阿瓦德语","ay":"艾马拉语","az":"阿塞拜疆语","az-Arab":"南阿塞拜疆语","ba":"巴什基尔语","bal":"俾路支语","ban":"巴厘语","bas":"巴萨语","bax":"巴姆穆语","bbj":"戈马拉语","be":"白俄罗斯语","bej":"贝沙语","bem":"本巴语","bez":"贝纳语","bfd":"巴非特语","bg":"保加利亚语","bgn":"西俾路支语","bho":"博杰普尔语","bi":"比斯拉马语","bik":"比科尔语","bin":"比尼语","bkm":"科姆语","bla":"西克西卡语","bm":"班巴拉语","bn":"孟加拉语","bo":"藏语","br":"布列塔尼语","bra":"布拉杰语","brx":"博多语","bs":"波斯尼亚语","bss":"阿库色语","bua":"布里亚特语","bug":"布吉语","bum":"布鲁语","byn":"比林语","byv":"梅敦巴语","ca":"加泰罗尼亚语","cad":"卡多语","car":"加勒比语","cay":"卡尤加语","cch":"阿灿语","ccp":"查克玛语","ce":"车臣语","ceb":"宿务语","cgg":"奇加语","ch":"查莫罗语","chb":"奇布查语","chg":"察合台语","chk":"楚克语","chm":"马里语","chn":"奇努克混合语","cho":"乔克托语","chp":"奇佩维安语","chr":"切罗基语","chy":"夏延语","ckb":"中库尔德语","co":"科西嘉语","cop":"科普特语","cr":"克里族语","crh":"克里米亚土耳其语","crs":"塞舌尔克里奥尔语","cs":"捷克语","csb":"卡舒比语","cu":"教会斯拉夫语","cv":"楚瓦什语","cy":"威尔士语","da":"丹麦语","dak":"达科他语","dar":"达尔格瓦语","dav":"台塔语","de":"德语","de-AT":"奥地利德语","de-CH":"瑞士高地德语","del":"特拉华语","den":"史拉维语","dgr":"多格里布语","din":"丁卡语","dje":"哲尔马语","doi":"多格拉语","dsb":"下索布语","dua":"都阿拉语","dum":"中古荷兰语","dv":"迪维希语","dyo":"朱拉语","dyu":"迪尤拉语","dz":"宗卡语","dzg":"达扎葛语","ebu":"恩布语","ee":"埃维语","efi":"埃菲克语","egy":"古埃及语","eka":"艾卡朱克语","el":"希腊语","elx":"埃兰语","en":"英语","en-AU":"澳大利亚英语","en-CA":"加拿大英语","en-GB":"英国英语","en-US":"美国英语","enm":"中古英语","eo":"世界语","es":"西班牙语","es-419":"拉丁美洲西班牙语","es-ES":"欧洲西班牙语","es-MX":"墨西哥西班牙语","et":"爱沙尼亚语","eu":"巴斯克语","ewo":"旺杜语","fa":"波斯语","fan":"芳格语","fat":"芳蒂语","ff":"富拉语","fi":"芬兰语","fil":"菲律宾语","fj":"斐济语","fo":"法罗语","fon":"丰语","fr":"法语","fr-CA":"加拿大法语","fr-CH":"瑞士法语","frc":"卡真法语","frm":"中古法语","fro":"古法语","frr":"北弗里西亚语","frs":"东弗里西亚语","fur":"弗留利语","fy":"西弗里西亚语","ga":"爱尔兰语","gaa":"加族语","gag":"加告兹语","gan":"赣语","gay":"迦约语","gba":"格巴亚语","gd":"苏格兰盖尔语","gez":"吉兹语","gil":"吉尔伯特语","gl":"加利西亚语","gmh":"中古高地德语","gn":"瓜拉尼语","goh":"古高地德语","gon":"冈德语","gor":"哥伦打洛语","got":"哥特语","grb":"格列博语","grc":"古希腊语","gsw":"瑞士德语","gu":"古吉拉特语","guz":"古西语","gv":"马恩语","gwi":"哥威迅语","ha":"豪萨语","hai":"海达语","hak":"客家语","haw":"夏威夷语","he":"希伯来语","hi":"印地语","hil":"希利盖农语","hit":"赫梯语","hmn":"苗语","ho":"希里莫图语","hr":"克罗地亚语","hsb":"上索布语","hsn":"湘语","ht":"海地克里奥尔语","hu":"匈牙利语","hup":"胡帕语","hy":"亚美尼亚语","hz":"赫雷罗语","ia":"国际语","iba":"伊班语","ibb":"伊比比奥语","id":"印度尼西亚语","ie":"国际文字（E）","ig":"伊博语","ii":"四川彝语","ik":"伊努皮克语","ilo":"伊洛卡诺语","inh":"印古什语","io":"伊多语","is":"冰岛语","it":"意大利语","iu":"因纽特语","ja":"日语","jbo":"逻辑语","jgo":"恩艮巴语","jmc":"马切姆语","jpr":"犹太波斯语","jrb":"犹太阿拉伯语","jv":"爪哇语","ka":"格鲁吉亚语","kaa":"卡拉卡尔帕克语","kab":"卡拜尔语","kac":"克钦语","kaj":"卡捷语","kam":"卡姆巴语","kaw":"卡威语","kbd":"卡巴尔德语","kbl":"加涅姆布语","kcg":"卡塔布语","kde":"马孔德语","kea":"卡布佛得鲁语","kfo":"克罗语","kg":"刚果语","kha":"卡西语","kho":"和田语","khq":"西桑海语","ki":"吉库尤语","kj":"宽亚玛语","kk":"哈萨克语","kkj":"卡库语","kl":"格陵兰语","kln":"卡伦金语","km":"高棉语","kmb":"金邦杜语","kn":"卡纳达语","ko":"韩语","koi":"科米-彼尔米亚克语","kok":"孔卡尼语","kos":"科斯拉伊语","kpe":"克佩列语","kr":"卡努里语","krc":"卡拉恰伊巴尔卡尔语","krl":"卡累利阿语","kru":"库鲁克语","ks":"克什米尔语","ksb":"香巴拉语","ksf":"巴菲亚语","ksh":"科隆语","ku":"库尔德语","kum":"库梅克语","kut":"库特奈语","kv":"科米语","kw":"康沃尔语","ky":"柯尔克孜语","la":"拉丁语","lad":"拉迪诺语","lag":"朗吉语","lah":"印度-雅利安语","lam":"兰巴语","lb":"卢森堡语","lez":"列兹金语","lg":"卢干达语","li":"林堡语","lkt":"拉科塔语","ln":"林加拉语","lo":"老挝语","lol":"蒙戈语","lou":"路易斯安那克里奥尔语","loz":"洛齐语","lrc":"北卢尔语","lt":"立陶宛语","lu":"鲁巴加丹加语","lua":"卢巴-卢拉语","lui":"卢伊塞诺语","lun":"隆达语","luo":"卢奥语","lus":"米佐语","luy":"卢雅语","lv":"拉脱维亚语","mad":"马都拉语","maf":"马法语","mag":"摩揭陀语","mai":"迈蒂利语","mak":"望加锡语","man":"曼丁哥语","mas":"马赛语","mde":"马坝语","mdf":"莫克沙语","mdr":"曼达尔语","men":"门德语","mer":"梅鲁语","mfe":"毛里求斯克里奥尔语","mg":"马拉加斯语","mga":"中古爱尔兰语","mgh":"马库阿语","mgo":"梅塔语","mh":"马绍尔语","mi":"毛利语","mic":"密克马克语","min":"米南佳保语","mk":"马其顿语","ml":"马拉雅拉姆语","mn":"蒙古语","mnc":"满语","mni":"曼尼普尔语","moh":"摩霍克语","mos":"莫西语","mr":"马拉地语","ms":"马来语","mt":"马耳他语","mua":"蒙当语","mul":"多语种","mus":"克里克语","mwl":"米兰德斯语","mwr":"马尔瓦里语","my":"缅甸语","mye":"姆耶内语","myv":"厄尔兹亚语","mzn":"马赞德兰语","na":"瑙鲁语","nan":"闽南语","nap":"那不勒斯语","naq":"纳马语","nb":"书面挪威语","nd":"北恩德贝勒语","nds":"低地德语","nds-NL":"低萨克森语","ne":"尼泊尔语","new":"尼瓦尔语","ng":"恩东加语","nia":"尼亚斯语","niu":"纽埃语","nl":"荷兰语","nl-BE":"弗拉芒语","nmg":"夸西奥语","nn":"挪威尼诺斯克语","nnh":"恩甘澎语","no":"挪威语","nog":"诺盖语","non":"古诺尔斯语","nqo":"西非书面文字","nr":"南恩德贝勒语","nso":"北索托语","nus":"努埃尔语","nv":"纳瓦霍语","nwc":"古典尼瓦尔语","ny":"齐切瓦语","nym":"尼扬韦齐语","nyn":"尼昂科勒语","nyo":"尼奥罗语","nzi":"恩济马语","oc":"奥克语","oj":"奥吉布瓦语","om":"奥罗莫语","or":"奥里亚语","os":"奥塞梯语","osa":"奥塞治语","ota":"奥斯曼土耳其语","pa":"旁遮普语","pag":"邦阿西南语","pal":"巴拉维语","pam":"邦板牙语","pap":"帕皮阿门托语","pau":"帕劳语","pcm":"尼日利亚皮钦语","peo":"古波斯语","phn":"腓尼基语","pi":"巴利语","pl":"波兰语","pon":"波纳佩语","prg":"普鲁士语","pro":"古普罗文斯语","ps":"普什图语","pt":"葡萄牙语","pt-BR":"巴西葡萄牙语","pt-PT":"欧洲葡萄牙语","qu":"克丘亚语","quc":"基切语","raj":"拉贾斯坦语","rap":"拉帕努伊语","rar":"拉罗汤加语","rm":"罗曼什语","rn":"隆迪语","ro":"罗马尼亚语","ro-MD":"摩尔多瓦语","rof":"兰博语","rom":"吉普赛语","root":"根语言","ru":"俄语","rup":"阿罗马尼亚语","rw":"卢旺达语","rwk":"罗瓦语","sa":"梵语","sad":"桑达韦语","sah":"萨哈语","sam":"萨马利亚阿拉姆语","saq":"桑布鲁语","sas":"萨萨克文","sat":"桑塔利语","sba":"甘拜语","sbp":"桑古语","sc":"萨丁语","scn":"西西里语","sco":"苏格兰语","sd":"信德语","sdh":"南库尔德语","se":"北方萨米语","see":"塞内卡语","seh":"塞纳语","sel":"塞尔库普语","ses":"东桑海语","sg":"桑戈语","sga":"古爱尔兰语","sh":"塞尔维亚-克罗地亚语","shi":"希尔哈语","shn":"掸语","shu":"乍得阿拉伯语","si":"僧伽罗语","sid":"悉达摩语","sk":"斯洛伐克语","sl":"斯洛文尼亚语","sm":"萨摩亚语","sma":"南萨米语","smj":"吕勒萨米语","smn":"伊纳里萨米语","sms":"斯科特萨米语","sn":"绍纳语","snk":"索宁克语","so":"索马里语","sog":"粟特语","sq":"阿尔巴尼亚语","sr":"塞尔维亚语","srn":"苏里南汤加语","srr":"塞雷尔语","ss":"斯瓦蒂语","ssy":"萨霍语","st":"南索托语","su":"巽他语","suk":"苏库马语","sus":"苏苏语","sux":"苏美尔语","sv":"瑞典语","sw":"斯瓦希里语","sw-CD":"刚果斯瓦希里语","swb":"科摩罗语","syc":"古典叙利亚语","syr":"叙利亚语","ta":"泰米尔语","te":"泰卢固语","tem":"泰姆奈语","teo":"特索语","ter":"特伦诺语","tet":"德顿语","tg":"塔吉克语","th":"泰语","ti":"提格利尼亚语","tig":"提格雷语","tiv":"蒂夫语","tk":"土库曼语","tkl":"托克劳语","tl":"他加禄语","tlh":"克林贡语","tli":"特林吉特语","tmh":"塔马奇克语","tn":"茨瓦纳语","to":"汤加语","tog":"尼亚萨汤加语","tpi":"托克皮辛语","tr":"土耳其语","trv":"赛德克语","ts":"聪加语","tsi":"钦西安语","tt":"鞑靼语","tum":"通布卡语","tvl":"图瓦卢语","tw":"契维语","twq":"北桑海语","ty":"塔希提语","tyv":"图瓦语","tzm":"塔马齐格特语","udm":"乌德穆尔特语","ug":"维吾尔语","uga":"乌加里特语","uk":"乌克兰语","umb":"翁本杜语","und":"未知语言","ur":"乌尔都语","uz":"乌兹别克语","vai":"瓦伊语","ve":"文达语","vep":"维普森语","vi":"越南语","vo":"沃拉普克语","vot":"沃提克语","vun":"温旧语","wa":"瓦隆语","wae":"瓦尔瑟语","wal":"瓦拉莫语","war":"瓦瑞语","was":"瓦绍语","wbp":"瓦尔皮瑞语","wo":"沃洛夫语","wuu":"吴语","xal":"卡尔梅克语","xh":"科萨语","xog":"索加语","yao":"瑶族语","yap":"雅浦语","yav":"洋卞语","ybb":"耶姆巴语","yi":"意第绪语","yo":"约鲁巴语","yue":"粤语","za":"壮语","zap":"萨波蒂克语","zbl":"布里斯符号","zen":"泽纳加语","zgh":"标准摩洛哥塔马塞特语","zh":"中文","zh-Hans":"简体中文","zh-Hant":"繁体中文","zu":"祖鲁语","zun":"祖尼语","zxx":"无语言内容","zza":"扎扎语"},"short":{"az":"阿塞语","en-GB":"英式英语","en-US":"美式英语"},"narrow":{}},"region":{"long":{"142":"亚洲","143":"中亚","145":"西亚","150":"欧洲","151":"东欧","154":"北欧","155":"西欧","202":"撒哈拉以南非洲","419":"拉丁美洲","001":"世界","002":"非洲","003":"北美洲","005":"南美洲","009":"大洋洲","011":"西非","013":"中美洲","014":"东非","015":"北非","017":"中非","018":"南部非洲","019":"美洲","021":"美洲北部","029":"加勒比地区","030":"东亚","034":"南亚","035":"东南亚","039":"南欧","053":"澳大拉西亚","054":"美拉尼西亚","057":"密克罗尼西亚地区","061":"玻利尼西亚","AC":"阿森松岛","AD":"安道尔","AE":"阿拉伯联合酋长国","AF":"阿富汗","AG":"安提瓜和巴布达","AI":"安圭拉","AL":"阿尔巴尼亚","AM":"亚美尼亚","AO":"安哥拉","AQ":"南极洲","AR":"阿根廷","AS":"美属萨摩亚","AT":"奥地利","AU":"澳大利亚","AW":"阿鲁巴","AX":"奥兰群岛","AZ":"阿塞拜疆","BA":"波斯尼亚和黑塞哥维那","BB":"巴巴多斯","BD":"孟加拉国","BE":"比利时","BF":"布基纳法索","BG":"保加利亚","BH":"巴林","BI":"布隆迪","BJ":"贝宁","BL":"圣巴泰勒米","BM":"百慕大","BN":"文莱","BO":"玻利维亚","BQ":"荷属加勒比区","BR":"巴西","BS":"巴哈马","BT":"不丹","BV":"布韦岛","BW":"博茨瓦纳","BY":"白俄罗斯","BZ":"伯利兹","CA":"加拿大","CC":"科科斯（基林）群岛","CD":"刚果（金）","CF":"中非共和国","CG":"刚果（布）","CH":"瑞士","CI":"科特迪瓦","CK":"库克群岛","CL":"智利","CM":"喀麦隆","CN":"中国","CO":"哥伦比亚","CP":"克利珀顿岛","CR":"哥斯达黎加","CU":"古巴","CV":"佛得角","CW":"库拉索","CX":"圣诞岛","CY":"塞浦路斯","CZ":"捷克","DE":"德国","DG":"迪戈加西亚岛","DJ":"吉布提","DK":"丹麦","DM":"多米尼克","DO":"多米尼加共和国","DZ":"阿尔及利亚","EA":"休达及梅利利亚","EC":"厄瓜多尔","EE":"爱沙尼亚","EG":"埃及","EH":"西撒哈拉","ER":"厄立特里亚","ES":"西班牙","ET":"埃塞俄比亚","EU":"欧盟","EZ":"欧元区","FI":"芬兰","FJ":"斐济","FK":"福克兰群岛","FM":"密克罗尼西亚","FO":"法罗群岛","FR":"法国","GA":"加蓬","GB":"英国","GD":"格林纳达","GE":"格鲁吉亚","GF":"法属圭亚那","GG":"根西岛","GH":"加纳","GI":"直布罗陀","GL":"格陵兰","GM":"冈比亚","GN":"几内亚","GP":"瓜德罗普","GQ":"赤道几内亚","GR":"希腊","GS":"南乔治亚和南桑威奇群岛","GT":"危地马拉","GU":"关岛","GW":"几内亚比绍","GY":"圭亚那","HK":"中国香港特别行政区","HM":"赫德岛和麦克唐纳群岛","HN":"洪都拉斯","HR":"克罗地亚","HT":"海地","HU":"匈牙利","IC":"加纳利群岛","ID":"印度尼西亚","IE":"爱尔兰","IL":"以色列","IM":"马恩岛","IN":"印度","IO":"英属印度洋领地","IQ":"伊拉克","IR":"伊朗","IS":"冰岛","IT":"意大利","JE":"泽西岛","JM":"牙买加","JO":"约旦","JP":"日本","KE":"肯尼亚","KG":"吉尔吉斯斯坦","KH":"柬埔寨","KI":"基里巴斯","KM":"科摩罗","KN":"圣基茨和尼维斯","KP":"朝鲜","KR":"韩国","KW":"科威特","KY":"开曼群岛","KZ":"哈萨克斯坦","LA":"老挝","LB":"黎巴嫩","LC":"圣卢西亚","LI":"列支敦士登","LK":"斯里兰卡","LR":"利比里亚","LS":"莱索托","LT":"立陶宛","LU":"卢森堡","LV":"拉脱维亚","LY":"利比亚","MA":"摩洛哥","MC":"摩纳哥","MD":"摩尔多瓦","ME":"黑山","MF":"法属圣马丁","MG":"马达加斯加","MH":"马绍尔群岛","MK":"北马其顿","ML":"马里","MM":"缅甸","MN":"蒙古","MO":"中国澳门特别行政区","MP":"北马里亚纳群岛","MQ":"马提尼克","MR":"毛里塔尼亚","MS":"蒙特塞拉特","MT":"马耳他","MU":"毛里求斯","MV":"马尔代夫","MW":"马拉维","MX":"墨西哥","MY":"马来西亚","MZ":"莫桑比克","NA":"纳米比亚","NC":"新喀里多尼亚","NE":"尼日尔","NF":"诺福克岛","NG":"尼日利亚","NI":"尼加拉瓜","NL":"荷兰","NO":"挪威","NP":"尼泊尔","NR":"瑙鲁","NU":"纽埃","NZ":"新西兰","OM":"阿曼","PA":"巴拿马","PE":"秘鲁","PF":"法属波利尼西亚","PG":"巴布亚新几内亚","PH":"菲律宾","PK":"巴基斯坦","PL":"波兰","PM":"圣皮埃尔和密克隆群岛","PN":"皮特凯恩群岛","PR":"波多黎各","PS":"巴勒斯坦领土","PT":"葡萄牙","PW":"帕劳","PY":"巴拉圭","QA":"卡塔尔","QO":"大洋洲边远群岛","RE":"留尼汪","RO":"罗马尼亚","RS":"塞尔维亚","RU":"俄罗斯","RW":"卢旺达","SA":"沙特阿拉伯","SB":"所罗门群岛","SC":"塞舌尔","SD":"苏丹","SE":"瑞典","SG":"新加坡","SH":"圣赫勒拿","SI":"斯洛文尼亚","SJ":"斯瓦尔巴和扬马延","SK":"斯洛伐克","SL":"塞拉利昂","SM":"圣马力诺","SN":"塞内加尔","SO":"索马里","SR":"苏里南","SS":"南苏丹","ST":"圣多美和普林西比","SV":"萨尔瓦多","SX":"荷属圣马丁","SY":"叙利亚","SZ":"斯威士兰","TA":"特里斯坦-达库尼亚群岛","TC":"特克斯和凯科斯群岛","TD":"乍得","TF":"法属南部领地","TG":"多哥","TH":"泰国","TJ":"塔吉克斯坦","TK":"托克劳","TL":"东帝汶","TM":"土库曼斯坦","TN":"突尼斯","TO":"汤加","TR":"土耳其","TT":"特立尼达和多巴哥","TV":"图瓦卢","TW":"台湾","TZ":"坦桑尼亚","UA":"乌克兰","UG":"乌干达","UM":"美国本土外小岛屿","UN":"联合国","US":"美国","UY":"乌拉圭","UZ":"乌兹别克斯坦","VA":"梵蒂冈","VC":"圣文森特和格林纳丁斯","VE":"委内瑞拉","VG":"英属维尔京群岛","VI":"美属维尔京群岛","VN":"越南","VU":"瓦努阿图","WF":"瓦利斯和富图纳","WS":"萨摩亚","XA":"伪地区","XB":"伪双向语言地区","XK":"科索沃","YE":"也门","YT":"马约特","ZA":"南非","ZM":"赞比亚","ZW":"津巴布韦","ZZ":"未知地区"},"short":{"GB":"英国","HK":"香港","MO":"澳门","PS":"巴勒斯坦","UN":"联合国","US":"美国"},"narrow":{}},"script":{"long":{"Adlm":"阿德拉姆文","Afak":"阿法卡文","Aghb":"Aghb","Ahom":"Ahom","Arab":"阿拉伯文","Armi":"皇室亚拉姆文","Armn":"亚美尼亚文","Avst":"阿维斯陀文","Bali":"巴厘文","Bamu":"巴姆穆文","Bass":"巴萨文","Batk":"巴塔克文","Beng":"孟加拉文","Bhks":"拜克舒克文","Blis":"布列斯符号","Bopo":"汉语拼音","Brah":"婆罗米文字","Brai":"布莱叶盲文","Bugi":"布吉文","Buhd":"布希德文","Cakm":"查克马文","Cans":"加拿大土著统一音节","Cari":"卡里亚文","Cham":"占文","Cher":"切罗基文","Cirt":"色斯文","Copt":"克普特文","Cprt":"塞浦路斯文","Cyrl":"西里尔文","Cyrs":"西里尔文字（古教会斯拉夫文的变体）","Deva":"天城文","Dogr":"多格拉文","Dsrt":"德塞莱特文","Dupl":"杜普洛伊速记","Egyd":"后期埃及文","Egyh":"古埃及僧侣书写体","Egyp":"古埃及象形文","Elba":"爱尔巴桑文","Elym":"Elym","Ethi":"埃塞俄比亚文","Geok":"格鲁吉亚文（教堂体）","Geor":"格鲁吉亚文","Glag":"格拉哥里文","Gong":"贡贾拉贡德文","Gonm":"马萨拉姆冈德文","Goth":"哥特文","Gran":"格兰塔文","Grek":"希腊文","Gujr":"古吉拉特文","Guru":"果鲁穆奇文","Hanb":"汉语注音","Hang":"谚文","Hani":"汉字","Hano":"汉奴罗文","Hans":"简体","Hant":"繁体","Hatr":"Hatr","Hebr":"希伯来文","Hira":"平假名","Hluw":"安那托利亚象形文字","Hmng":"杨松录苗文","Hmnp":"尼亚肯蒲丘苗文","Hrkt":"假名表","Hung":"古匈牙利文","Inds":"印度河文字","Ital":"古意大利文","Jamo":"韩文字母","Java":"爪哇文","Jpan":"日文","Jurc":"女真文","Kali":"克耶李文字","Kana":"片假名","Khar":"卡罗须提文","Khmr":"高棉文","Khoj":"克吉奇文字","Knda":"卡纳达文","Kore":"韩文","Kpel":"克佩列文","Kthi":"凯提文","Lana":"兰拿文","Laoo":"老挝文","Latf":"拉丁文（哥特式字体变体）","Latg":"拉丁文（盖尔文变体）","Latn":"拉丁文","Lepc":"雷布查文","Limb":"林布文","Lina":"线形文字（A）","Linb":"线形文字（B）","Lisu":"傈僳文","Loma":"洛马文","Lyci":"利西亚文","Lydi":"吕底亚文","Mahj":"Mahj","Maka":"望加锡文","Mand":"阿拉米文","Mani":"摩尼教文","Marc":"大玛尔文","Maya":"玛雅圣符文","Medf":"梅德法伊德林文","Mend":"门迪文","Merc":"麦罗埃草书","Mero":"麦若提克文","Mlym":"马拉雅拉姆文","Modi":"Modi","Mong":"蒙古文","Moon":"韩文语系","Mroo":"谬文","Mtei":"曼尼普尔文","Mult":"Mult","Mymr":"缅甸文","Nand":"楠迪梵文","Narb":"古北方阿拉伯文","Nbat":"纳巴泰文","Newa":"尼瓦文","Nkgb":"纳西格巴文","Nkoo":"西非书面文字（N’Ko）","Nshu":"女书","Ogam":"欧甘文","Olck":"桑塔利文","Orkh":"鄂尔浑文","Orya":"奥里亚文","Osge":"欧塞奇文","Osma":"奥斯曼亚文","Palm":"帕尔迈拉文","Pauc":"包金豪文","Perm":"古彼尔姆文","Phag":"八思巴文","Phli":"巴列维文碑铭体","Phlp":"巴列维文（圣诗体）","Phlv":"巴列维文（书体）","Phnx":"腓尼基文","Plrd":"波拉德音标文字","Prti":"帕提亚文碑铭体","Qaag":"Qaag","Rjng":"拉让文","Rohg":"哈乃斐罗兴亚文","Roro":"朗格朗格文","Runr":"古代北欧文","Samr":"撒马利亚文","Sara":"沙拉堤文","Sarb":"古南阿拉伯文","Saur":"索拉什特拉文","Sgnw":"书写符号","Shaw":"萧伯纳式文","Shrd":"夏拉达文","Sidd":"悉昙","Sind":"信德文","Sinh":"僧伽罗文","Sogd":"粟特文","Sogo":"古粟特文","Sora":"索朗桑朋文","Soyo":"索永布文","Sund":"巽他文","Sylo":"锡尔赫特文","Syrc":"叙利亚文","Syre":"福音体叙利亚文","Syrj":"西叙利亚文","Syrn":"东叙利亚文","Tagb":"塔格班瓦文","Takr":"泰克里文","Tale":"泰乐文","Talu":"新傣文","Taml":"泰米尔文","Tang":"唐古特文","Tavt":"越南傣文","Telu":"泰卢固文","Teng":"腾格瓦文字","Tfng":"提非纳文","Tglg":"塔加路文","Thaa":"塔安那文","Thai":"泰文","Tibt":"藏文","Tirh":"迈蒂利文","Ugar":"乌加里特文","Vaii":"瓦依文","Visp":"可见语言","Wara":"瓦郎奇蒂文字","Wcho":"Wcho","Wole":"沃莱艾文","Xpeo":"古波斯文","Xsux":"苏美尔-阿卡德楔形文字","Yiii":"彝文","Zanb":"札那巴札尔方块文字","Zinh":"遗传学术语","Zmth":"数学符号","Zsye":"表情符号","Zsym":"符号","Zxxx":"非书面文字","Zyyy":"通用","Zzzz":"未知文字"},"short":{},"narrow":{}},"currency":{"long":{"ADP":"安道尔比塞塔","AED":"阿联酋迪拉姆","AFA":"阿富汗尼 (1927–2002)","AFN":"阿富汗尼","ALK":"阿尔巴尼亚列克(1946–1965)","ALL":"阿尔巴尼亚列克","AMD":"亚美尼亚德拉姆","ANG":"荷属安的列斯盾","AOA":"安哥拉宽扎","AOK":"安哥拉宽扎 (1977–1990)","AON":"安哥拉新宽扎 (1990–2000)","AOR":"安哥拉重新调整宽扎 (1995–1999)","ARA":"阿根廷奥斯特拉尔","ARL":"阿根廷法定比索 (1970–1983)","ARM":"阿根廷比索 (1881–1970)","ARP":"阿根廷比索 (1983–1985)","ARS":"阿根廷比索","ATS":"奥地利先令","AUD":"澳大利亚元","AWG":"阿鲁巴弗罗林","AZM":"阿塞拜疆马纳特 (1993–2006)","AZN":"阿塞拜疆马纳特","BAD":"波士尼亚-赫塞哥维纳第纳尔 (1992–1994)","BAM":"波斯尼亚-黑塞哥维那可兑换马克","BAN":"波士尼亚-赫塞哥维纳新第纳尔 (1994–1997)","BBD":"巴巴多斯元","BDT":"孟加拉塔卡","BEC":"比利时法郎（可兑换）","BEF":"比利时法郎","BEL":"比利时法郎（金融）","BGL":"保加利亚硬列弗","BGM":"保加利亚社会党列弗","BGN":"保加利亚列弗","BGO":"保加利亚列弗 (1879–1952)","BHD":"巴林第纳尔","BIF":"布隆迪法郎","BMD":"百慕大元","BND":"文莱元","BOB":"玻利维亚诺","BOL":"玻利维亚诺 (1863–1963)","BOP":"玻利维亚比索","BOV":"玻利维亚 Mvdol（资金）","BRB":"巴西新克鲁赛罗 (1967–1986)","BRC":"巴西克鲁扎多 (1986–1989)","BRE":"巴西克鲁塞罗 (1990–1993)","BRL":"巴西雷亚尔","BRN":"巴西新克鲁扎多 (1989–1990)","BRR":"巴西克鲁塞罗 (1993–1994)","BRZ":"巴西克鲁塞罗 (1942–1967)","BSD":"巴哈马元","BTN":"不丹努尔特鲁姆","BUK":"缅元","BWP":"博茨瓦纳普拉","BYB":"白俄罗斯新卢布 (1994–1999)","BYN":"白俄罗斯卢布","BYR":"白俄罗斯卢布 (2000–2016)","BZD":"伯利兹元","CAD":"加拿大元","CDF":"刚果法郎","CHE":"欧元 (WIR)","CHF":"瑞士法郎","CHW":"法郎 (WIR)","CLE":"智利埃斯库多","CLF":"智利（资金）","CLP":"智利比索","CNH":"人民币（离岸）","CNX":"中国人民银行元","CNY":"人民币","COP":"哥伦比亚比索","COU":"哥伦比亚币","CRC":"哥斯达黎加科朗","CSD":"旧塞尔维亚第纳尔","CSK":"捷克硬克朗","CUC":"古巴可兑换比索","CUP":"古巴比索","CVE":"佛得角埃斯库多","CYP":"塞浦路斯镑","CZK":"捷克克朗","DDM":"东德奥斯特马克","DEM":"德国马克","DJF":"吉布提法郎","DKK":"丹麦克朗","DOP":"多米尼加比索","DZD":"阿尔及利亚第纳尔","ECS":"厄瓜多尔苏克雷","ECV":"厄瓜多尔 (UVC)","EEK":"爱沙尼亚克朗","EGP":"埃及镑","ERN":"厄立特里亚纳克法","ESA":"西班牙比塞塔（帐户 A）","ESB":"西班牙比塞塔（兑换帐户）","ESP":"西班牙比塞塔","ETB":"埃塞俄比亚比尔","EUR":"欧元","FIM":"芬兰马克","FJD":"斐济元","FKP":"福克兰群岛镑","FRF":"法国法郎","GBP":"英镑","GEK":"乔治亚库蓬拉瑞特","GEL":"格鲁吉亚拉里","GHC":"加纳塞第","GHS":"加纳塞地","GIP":"直布罗陀镑","GMD":"冈比亚达拉西","GNF":"几内亚法郎","GNS":"几内亚西里","GQE":"赤道几内亚埃奎勒","GRD":"希腊德拉克马","GTQ":"危地马拉格查尔","GWE":"葡萄牙几内亚埃斯库多","GWP":"几内亚比绍比索","GYD":"圭亚那元","HKD":"港元","HNL":"洪都拉斯伦皮拉","HRD":"克罗地亚第纳尔","HRK":"克罗地亚库纳","HTG":"海地古德","HUF":"匈牙利福林","IDR":"印度尼西亚盾","IEP":"爱尔兰镑","ILP":"以色列镑","ILR":"以色列谢克尔(1980–1985)","ILS":"以色列新谢克尔","INR":"印度卢比","IQD":"伊拉克第纳尔","IRR":"伊朗里亚尔","ISJ":"冰岛克朗(1918–1981)","ISK":"冰岛克朗","ITL":"意大利里拉","JMD":"牙买加元","JOD":"约旦第纳尔","JPY":"日元","KES":"肯尼亚先令","KGS":"吉尔吉斯斯坦索姆","KHR":"柬埔寨瑞尔","KMF":"科摩罗法郎","KPW":"朝鲜元","KRH":"韩元 (1953–1962)","KRO":"韩元 (1945–1953)","KRW":"韩元","KWD":"科威特第纳尔","KYD":"开曼元","KZT":"哈萨克斯坦坚戈","LAK":"老挝基普","LBP":"黎巴嫩镑","LKR":"斯里兰卡卢比","LRD":"利比里亚元","LSL":"莱索托洛蒂","LTL":"立陶宛立特","LTT":"立陶宛塔咯呐司","LUC":"卢森堡可兑换法郎","LUF":"卢森堡法郎","LUL":"卢森堡金融法郎","LVL":"拉脱维亚拉特","LVR":"拉脱维亚卢布","LYD":"利比亚第纳尔","MAD":"摩洛哥迪拉姆","MAF":"摩洛哥法郎","MCF":"摩纳哥法郎","MDC":"摩尔多瓦库邦","MDL":"摩尔多瓦列伊","MGA":"马达加斯加阿里亚里","MGF":"马达加斯加法郎","MKD":"马其顿第纳尔","MKN":"马其顿第纳尔 (1992–1993)","MLF":"马里法郎","MMK":"缅甸元","MNT":"蒙古图格里克","MOP":"澳门币","MRO":"毛里塔尼亚乌吉亚 (1973–2017)","MRU":"毛里塔尼亚乌吉亚","MTL":"马耳他里拉","MTP":"马耳他镑","MUR":"毛里求斯卢比","MVP":"马尔代夫卢比(1947–1981)","MVR":"马尔代夫卢菲亚","MWK":"马拉维克瓦查","MXN":"墨西哥比索","MXP":"墨西哥银比索 (1861–1992)","MXV":"墨西哥（资金）","MYR":"马来西亚林吉特","MZE":"莫桑比克埃斯库多","MZM":"旧莫桑比克美提卡","MZN":"莫桑比克美提卡","NAD":"纳米比亚元","NGN":"尼日利亚奈拉","NIC":"尼加拉瓜科多巴 (1988–1991)","NIO":"尼加拉瓜科多巴","NLG":"荷兰盾","NOK":"挪威克朗","NPR":"尼泊尔卢比","NZD":"新西兰元","OMR":"阿曼里亚尔","PAB":"巴拿马巴波亚","PEI":"秘鲁印第","PEN":"秘鲁索尔","PES":"秘鲁索尔 (1863–1965)","PGK":"巴布亚新几内亚基那","PHP":"菲律宾比索","PKR":"巴基斯坦卢比","PLN":"波兰兹罗提","PLZ":"波兰兹罗提 (1950–1995)","PTE":"葡萄牙埃斯库多","PYG":"巴拉圭瓜拉尼","QAR":"卡塔尔里亚尔","RHD":"罗得西亚元","ROL":"旧罗马尼亚列伊","RON":"罗马尼亚列伊","RSD":"塞尔维亚第纳尔","RUB":"俄罗斯卢布","RUR":"俄国卢布 (1991–1998)","RWF":"卢旺达法郎","SAR":"沙特里亚尔","SBD":"所罗门群岛元","SCR":"塞舌尔卢比","SDD":"苏丹第纳尔 (1992–2007)","SDG":"苏丹镑","SDP":"旧苏丹镑","SEK":"瑞典克朗","SGD":"新加坡元","SHP":"圣赫勒拿群岛磅","SIT":"斯洛文尼亚托拉尔","SKK":"斯洛伐克克朗","SLL":"塞拉利昂利昂","SOS":"索马里先令","SRD":"苏里南元","SRG":"苏里南盾","SSP":"南苏丹镑","STD":"圣多美和普林西比多布拉 (1977–2017)","STN":"圣多美和普林西比多布拉","SUR":"苏联卢布","SVC":"萨尔瓦多科朗","SYP":"叙利亚镑","SZL":"斯威士兰里兰吉尼","THB":"泰铢","TJR":"塔吉克斯坦卢布","TJS":"塔吉克斯坦索莫尼","TMM":"土库曼斯坦马纳特 (1993–2009)","TMT":"土库曼斯坦马纳特","TND":"突尼斯第纳尔","TOP":"汤加潘加","TPE":"帝汶埃斯库多","TRL":"土耳其里拉 (1922–2005)","TRY":"土耳其里拉","TTD":"特立尼达和多巴哥元","TWD":"新台币","TZS":"坦桑尼亚先令","UAH":"乌克兰格里夫纳","UAK":"乌克兰币","UGS":"乌干达先令 (1966–1987)","UGX":"乌干达先令","USD":"美元","USN":"美元（次日）","USS":"美元（当日）","UYI":"乌拉圭比索（索引单位）","UYP":"乌拉圭比索 (1975–1993)","UYU":"乌拉圭比索","UYW":"乌拉圭票面工资指数单位","UZS":"乌兹别克斯坦苏姆","VEB":"委内瑞拉玻利瓦尔 (1871–2008)","VEF":"委内瑞拉玻利瓦尔 (2008–2018)","VES":"委内瑞拉玻利瓦尔","VND":"越南盾","VNN":"越南盾 (1978–1985)","VUV":"瓦努阿图瓦图","WST":"萨摩亚塔拉","XAF":"中非法郎","XAG":"银","XAU":"黄金","XBA":"欧洲复合单位","XBB":"欧洲货币联盟","XBC":"欧洲计算单位 (XBC)","XBD":"欧洲计算单位 (XBD)","XCD":"东加勒比元","XDR":"特别提款权","XEU":"欧洲货币单位","XFO":"法国金法郎","XFU":"法国法郎 (UIC)","XOF":"西非法郎","XPD":"钯","XPF":"太平洋法郎","XPT":"铂","XRE":"RINET 基金","XSU":"苏克雷","XTS":"测试货币代码","XUA":"非洲开发银行记账单位","XXX":"未知货币","YDD":"也门第纳尔","YER":"也门里亚尔","YUD":"南斯拉夫硬第纳尔 (1966–1990)","YUM":"南斯拉夫新第纳尔 (1994–2002)","YUN":"南斯拉夫可兑换第纳尔 (1990–1992)","YUR":"南斯拉夫改良第纳尔 (1992–1993)","ZAL":"南非兰特 (金融)","ZAR":"南非兰特","ZMK":"赞比亚克瓦查 (1968–2012)","ZMW":"赞比亚克瓦查","ZRN":"新扎伊尔 (1993–1998)","ZRZ":"扎伊尔 (1971–1993)","ZWD":"津巴布韦元 (1980–2008)","ZWL":"津巴布韦元 (2009)","ZWR":"津巴布韦元 (2008)"},"short":{},"narrow":{}}},"patterns":{"locale":"{0}（{1}）"}}},"availableLocales":["zh"],"aliases":{"zh-CN":"zh-Hans-CN","zh-guoyu":"zh","zh-hakka":"hak","zh-HK":"zh-Hant-HK","zh-min-nan":"nan","zh-MO":"zh-Hant-MO","zh-SG":"zh-Hans-SG","zh-TW":"zh-Hant-TW","zh-xiang":"hsn","zh-min":"nan-x-zh-min"},"parentLocales":{"zh-Hant-MO":"zh-Hant-HK"}},
    {"data":{"zh-Hant":{"types":{"language":{"long":{"aa":"阿法文","ab":"阿布哈茲文","ace":"亞齊文","ach":"阿僑利文","ada":"阿當莫文","ady":"阿迪各文","ae":"阿維斯塔文","aeb":"突尼斯阿拉伯文","af":"南非荷蘭文","afh":"阿弗里希利文","agq":"亞罕文","ain":"阿伊努文","ak":"阿坎文","akk":"阿卡德文","akz":"阿拉巴馬文","ale":"阿留申文","aln":"蓋格阿爾巴尼亞文","alt":"南阿爾泰文","am":"阿姆哈拉文","an":"阿拉貢文","ang":"古英文","anp":"昂加文","ar":"阿拉伯文","ar-001":"現代標準阿拉伯文","arc":"阿拉米文","arn":"馬普切文","aro":"阿拉奧納文","arp":"阿拉帕霍文","arq":"阿爾及利亞阿拉伯文","ars":"納吉迪阿拉伯文","arw":"阿拉瓦克文","ary":"摩洛哥阿拉伯文","arz":"埃及阿拉伯文","as":"阿薩姆文","asa":"阿蘇文","ase":"美國手語","ast":"阿斯圖里亞文","av":"阿瓦爾文","avk":"科塔瓦文","awa":"阿瓦文","ay":"艾馬拉文","az":"亞塞拜然文","ba":"巴什喀爾文","bal":"俾路支文","ban":"峇里文","bar":"巴伐利亞文","bas":"巴薩文","bax":"巴姆穆文","bbc":"巴塔克托巴文","bbj":"戈馬拉文","be":"白俄羅斯文","bej":"貝扎文","bem":"別姆巴文","bew":"貝塔維文","bez":"貝納文","bfd":"富特文","bfq":"巴達加文","bg":"保加利亞文","bgn":"西俾路支文","bho":"博傑普爾文","bi":"比斯拉馬文","bik":"比科爾文","bin":"比尼文","bjn":"班亞爾文","bkm":"康姆文","bla":"錫克錫卡文","bm":"班巴拉文","bn":"孟加拉文","bo":"藏文","bpy":"比什奴普萊利亞文","bqi":"巴赫蒂亞里文","br":"布列塔尼文","bra":"布拉杰文","brh":"布拉維文","brx":"博多文","bs":"波士尼亞文","bss":"阿庫色文","bua":"布里阿特文","bug":"布吉斯文","bum":"布魯文","byn":"比林文","byv":"梅敦巴文","ca":"加泰蘭文","cad":"卡多文","car":"加勒比文","cay":"卡尤加文","cch":"阿燦文","ccp":"查克馬文","ce":"車臣文","ceb":"宿霧文","cgg":"奇加文","ch":"查莫洛文","chb":"奇布查文","chg":"查加文","chk":"處奇斯文","chm":"馬里文","chn":"契奴克文","cho":"喬克托文","chp":"奇佩瓦揚文","chr":"柴羅基文","chy":"沙伊安文","ckb":"中庫德文","co":"科西嘉文","cop":"科普特文","cps":"卡皮茲文","cr":"克里文","crh":"土耳其文（克里米亞半島）","crs":"塞席爾克里奧爾法文","cs":"捷克文","csb":"卡舒布文","cu":"宗教斯拉夫文","cv":"楚瓦什文","cy":"威爾斯文","da":"丹麥文","dak":"達科他文","dar":"達爾格瓦文","dav":"台塔文","de":"德文","de-AT":"德文（奧地利）","de-CH":"高地德文（瑞士）","del":"德拉瓦文","den":"斯拉夫","dgr":"多格里布文","din":"丁卡文","dje":"扎爾馬文","doi":"多格來文","dsb":"下索布文","dtp":"中部杜順文","dua":"杜亞拉文","dum":"中古荷蘭文","dv":"迪維西文","dyo":"朱拉文","dyu":"迪尤拉文","dz":"宗卡文","dzg":"達薩文","ebu":"恩布文","ee":"埃維文","efi":"埃菲克文","egl":"埃米利安文","egy":"古埃及文","eka":"艾卡朱克文","el":"希臘文","elx":"埃蘭文","en":"英文","en-AU":"英文（澳洲）","en-CA":"英文（加拿大）","en-GB":"英文（英國）","en-US":"英文（美國）","enm":"中古英文","eo":"世界文","es":"西班牙文","es-419":"西班牙文（拉丁美洲）","es-ES":"西班牙文（西班牙）","es-MX":"西班牙文（墨西哥）","esu":"中尤皮克文","et":"愛沙尼亞文","eu":"巴斯克文","ewo":"依汪都文","ext":"埃斯特雷馬杜拉文","fa":"波斯文","fan":"芳族文","fat":"芳蒂文","ff":"富拉文","fi":"芬蘭文","fil":"菲律賓文","fit":"托爾訥芬蘭文","fj":"斐濟文","fo":"法羅文","fon":"豐文","fr":"法文","fr-CA":"法文（加拿大）","fr-CH":"法文（瑞士）","frc":"卡真法文","frm":"中古法文","fro":"古法文","frp":"法蘭克-普羅旺斯文","frr":"北弗里西亞文","frs":"東弗里西亞文","fur":"弗留利文","fy":"西弗里西亞文","ga":"愛爾蘭文","gaa":"加族文","gag":"加告茲文","gan":"贛語","gay":"加約文","gba":"葛巴亞文","gbz":"索羅亞斯德教達里文","gd":"蘇格蘭蓋爾文","gez":"吉茲文","gil":"吉爾伯特群島文","gl":"加利西亞文","glk":"吉拉基文","gmh":"中古高地德文","gn":"瓜拉尼文","goh":"古高地德文","gom":"孔卡尼文","gon":"岡德文","gor":"科隆達羅文","got":"哥德文","grb":"格列博文","grc":"古希臘文","gsw":"德文（瑞士）","gu":"古吉拉特文","guc":"瓦尤文","gur":"弗拉弗拉文","guz":"古西文","gv":"曼島文","gwi":"圭契文","ha":"豪撒文","hai":"海達文","hak":"客家話","haw":"夏威夷文","he":"希伯來文","hi":"印地文","hif":"斐濟印地文","hil":"希利蓋農文","hit":"赫梯文","hmn":"孟文","ho":"西里莫圖土文","hr":"克羅埃西亞文","hsb":"上索布文","hsn":"湘語","ht":"海地文","hu":"匈牙利文","hup":"胡帕文","hy":"亞美尼亞文","hz":"赫雷羅文","ia":"國際文","iba":"伊班文","ibb":"伊比比奧文","id":"印尼文","ie":"國際文（E）","ig":"伊布文","ii":"四川彝文","ik":"依奴皮維克文","ilo":"伊洛闊文","inh":"印古什文","io":"伊多文","is":"冰島文","it":"義大利文","iu":"因紐特文","izh":"英格里亞文","ja":"日文","jam":"牙買加克里奧爾英文","jbo":"邏輯文","jgo":"恩格姆巴文","jmc":"馬恰美文","jpr":"猶太教-波斯文","jrb":"猶太阿拉伯文","jut":"日德蘭文","jv":"爪哇文","ka":"喬治亞文","kaa":"卡拉卡爾帕克文","kab":"卡比爾文","kac":"卡琴文","kaj":"卡捷文","kam":"卡姆巴文","kaw":"卡威文","kbd":"卡巴爾達文","kbl":"卡念布文","kcg":"卡塔布文","kde":"馬孔德文","kea":"卡布威爾第文","ken":"肯揚文","kfo":"科羅文","kg":"剛果文","kgp":"坎剛文","kha":"卡西文","kho":"和闐文","khq":"西桑海文","khw":"科瓦文","ki":"吉庫尤文","kiu":"北紮紮其文","kj":"廣亞馬文","kk":"哈薩克文","kkj":"卡庫文","kl":"格陵蘭文","kln":"卡倫金文","km":"高棉文","kmb":"金邦杜文","kn":"坎那達文","ko":"韓文","koi":"科米-彼爾米亞克文","kok":"貢根文","kos":"科斯雷恩文","kpe":"克佩列文","kr":"卡努里文","krc":"卡拉柴-包爾卡爾文","kri":"塞拉利昂克裏奧爾文","krj":"基那來阿文","krl":"卡累利阿文","kru":"庫魯科文","ks":"喀什米爾文","ksb":"尚巴拉文","ksf":"巴菲亞文","ksh":"科隆文","ku":"庫德文","kum":"庫密克文","kut":"庫特奈文","kv":"科米文","kw":"康瓦耳文","ky":"吉爾吉斯文","la":"拉丁文","lad":"拉迪諾文","lag":"朗吉文","lah":"拉亨達文","lam":"蘭巴文","lb":"盧森堡文","lez":"列茲干文","lfn":"新共同語言","lg":"干達文","li":"林堡文","lij":"利古里亞文","liv":"利伏尼亞文","lkt":"拉科塔文","lmo":"倫巴底文","ln":"林加拉文","lo":"寮文","lol":"芒戈文","lou":"路易斯安那克里奧爾文","loz":"洛齊文","lrc":"北盧爾文","lt":"立陶宛文","ltg":"拉特加萊文","lu":"魯巴加丹加文","lua":"魯巴魯魯亞文","lui":"路易塞諾文","lun":"盧恩達文","luo":"盧奧文","lus":"米佐文","luy":"盧雅文","lv":"拉脫維亞文","lzh":"文言文","lzz":"拉茲文","mad":"馬都拉文","maf":"馬法文","mag":"馬加伊文","mai":"邁蒂利文","mak":"望加錫文","man":"曼丁哥文","mas":"馬賽文","mde":"馬巴文","mdf":"莫克沙文","mdr":"曼達文","men":"門德文","mer":"梅魯文","mfe":"克里奧文（模里西斯）","mg":"馬達加斯加文","mga":"中古愛爾蘭文","mgh":"馬夸文","mgo":"美塔文","mh":"馬紹爾文","mi":"毛利文","mic":"米克馬克文","min":"米南卡堡文","mk":"馬其頓文","ml":"馬來亞拉姆文","mn":"蒙古文","mnc":"滿族文","mni":"曼尼普爾文","moh":"莫霍克文","mos":"莫西文","mr":"馬拉地文","mrj":"西馬里文","ms":"馬來文","mt":"馬爾他文","mua":"蒙當文","mul":"多種語言","mus":"克里克文","mwl":"米蘭德斯文","mwr":"馬瓦里文","mwv":"明打威文","my":"緬甸文","mye":"姆耶內文","myv":"厄爾茲亞文","mzn":"馬贊德蘭文","na":"諾魯文","nan":"閩南語","nap":"拿波里文","naq":"納馬文","nb":"巴克摩挪威文","nd":"北地畢列文","nds":"低地德文","nds-NL":"低地薩克遜文","ne":"尼泊爾文","new":"尼瓦爾文","ng":"恩東加文","nia":"尼亞斯文","niu":"紐埃文","njo":"阿沃那加文","nl":"荷蘭文","nl-BE":"佛蘭芒文","nmg":"夸西奧文","nn":"耐諾斯克挪威文","nnh":"恩甘澎文","no":"挪威文","nog":"諾蓋文","non":"古諾爾斯文","nov":"諾維亞文","nqo":"曼德文字 (N’Ko)","nr":"南地畢列文","nso":"北索托文","nus":"努埃爾文","nv":"納瓦霍文","nwc":"古尼瓦爾文","ny":"尼揚賈文","nym":"尼揚韋齊文","nyn":"尼揚科萊文","nyo":"尼奧囉文","nzi":"尼茲馬文","oc":"奧克西坦文","oj":"奧杰布瓦文","om":"奧羅莫文","or":"歐迪亞文","os":"奧塞提文","osa":"歐塞奇文","ota":"鄂圖曼土耳其文","pa":"旁遮普文","pag":"潘加辛文","pal":"巴列維文","pam":"潘帕嘉文","pap":"帕皮阿門托文","pau":"帛琉文","pcd":"庇卡底文","pcm":"奈及利亞皮欽文","pdc":"賓夕法尼亞德文","pdt":"門諾低地德文","peo":"古波斯文","pfl":"普法爾茨德文","phn":"腓尼基文","pi":"巴利文","pl":"波蘭文","pms":"皮埃蒙特文","pnt":"旁狄希臘文","pon":"波那貝文","prg":"普魯士文","pro":"古普羅旺斯文","ps":"普什圖文","pt":"葡萄牙文","pt-BR":"葡萄牙文（巴西）","pt-PT":"葡萄牙文（葡萄牙）","qu":"蓋楚瓦文","quc":"基切文","qug":"欽博拉索海蘭蓋丘亞文","raj":"拉賈斯坦諸文","rap":"復活島文","rar":"拉羅通加文","rgn":"羅馬格諾里文","rif":"里菲亞諾文","rm":"羅曼斯文","rn":"隆迪文","ro":"羅馬尼亞文","ro-MD":"摩爾多瓦文","rof":"蘭博文","rom":"吉普賽文","root":"根語言","rtm":"羅圖馬島文","ru":"俄文","rue":"盧森尼亞文","rug":"羅維阿納文","rup":"羅馬尼亞語系","rw":"盧安達文","rwk":"羅瓦文","sa":"梵文","sad":"桑達韋文","sah":"雅庫特文","sam":"薩瑪利亞阿拉姆文","saq":"薩布魯文","sas":"撒撒克文","sat":"桑塔利文","saz":"索拉什特拉文","sba":"甘拜文","sbp":"桑古文","sc":"撒丁文","scn":"西西里文","sco":"蘇格蘭文","sd":"信德文","sdc":"薩丁尼亞-薩薩里文","sdh":"南庫德文","se":"北薩米文","see":"塞訥卡文","seh":"賽納文","sei":"瑟里文","sel":"塞爾庫普文","ses":"東桑海文","sg":"桑戈文","sga":"古愛爾蘭文","sgs":"薩莫吉希亞文","sh":"塞爾維亞克羅埃西亞文","shi":"希爾哈文","shn":"撣文","shu":"阿拉伯文（查德）","si":"僧伽羅文","sid":"希達摩文","sk":"斯洛伐克文","sl":"斯洛維尼亞文","sli":"下西利西亞文","sly":"塞拉亞文","sm":"薩摩亞文","sma":"南薩米文","smj":"魯勒薩米文","smn":"伊納里薩米文","sms":"斯科特薩米文","sn":"紹納文","snk":"索尼基文","so":"索馬利文","sog":"索格底亞納文","sq":"阿爾巴尼亞文","sr":"塞爾維亞文","srn":"蘇拉南東墎文","srr":"塞雷爾文","ss":"斯瓦特文","ssy":"薩霍文","st":"塞索托文","stq":"沙特菲士蘭文","su":"巽他文","suk":"蘇庫馬文","sus":"蘇蘇文","sux":"蘇美文","sv":"瑞典文","sw":"史瓦希里文","sw-CD":"史瓦希里文（剛果）","swb":"葛摩文","syc":"古敘利亞文","syr":"敘利亞文","szl":"西利西亞文","ta":"坦米爾文","tcy":"圖盧文","te":"泰盧固文","tem":"提姆文","teo":"特索文","ter":"泰雷諾文","tet":"泰頓文","tg":"塔吉克文","th":"泰文","ti":"提格利尼亞文","tig":"蒂格雷文","tiv":"提夫文","tk":"土庫曼文","tkl":"托克勞文","tkr":"查庫爾文","tl":"塔加路族文","tlh":"克林貢文","tli":"特林基特文","tly":"塔里什文","tmh":"塔馬奇克文","tn":"塞茲瓦納文","to":"東加文","tog":"東加文（尼亞薩）","tpi":"托比辛文","tr":"土耳其文","tru":"圖羅尤文","trv":"太魯閣文","ts":"特松加文","tsd":"特薩克尼恩文","tsi":"欽西安文","tt":"韃靼文","ttt":"穆斯林塔特文","tum":"圖姆布卡文","tvl":"吐瓦魯文","tw":"特威文","twq":"北桑海文","ty":"大溪地文","tyv":"圖瓦文","tzm":"中阿特拉斯塔馬塞特文","udm":"烏德穆爾特文","ug":"維吾爾文","uga":"烏加列文","uk":"烏克蘭文","umb":"姆本杜文","und":"未知語言","ur":"烏都文","uz":"烏茲別克文","vai":"瓦伊文","ve":"溫達文","vec":"威尼斯文","vep":"維普森文","vi":"越南文","vls":"西佛蘭德文","vmf":"美茵-法蘭克尼亞文","vo":"沃拉普克文","vot":"沃提克文","vro":"佛羅文","vun":"溫舊文","wa":"瓦隆文","wae":"瓦爾瑟文","wal":"瓦拉莫文","war":"瓦瑞文","was":"瓦紹文","wbp":"沃皮瑞文","wo":"沃洛夫文","wuu":"吳語","xal":"卡爾梅克文","xh":"科薩文","xmf":"明格列爾文","xog":"索加文","yao":"瑤文","yap":"雅浦文","yav":"洋卞文","ybb":"耶姆巴文","yi":"意第緒文","yo":"約魯巴文","yrl":"奈恩加圖文","yue":"粵語","za":"壯文","zap":"薩波特克文","zbl":"布列斯符號","zea":"西蘭文","zen":"澤納加文","zgh":"標準摩洛哥塔馬塞特文","zh":"中文","zh-Hans":"簡體中文","zh-Hant":"繁體中文","zu":"祖魯文","zun":"祖尼文","zxx":"無語言內容","zza":"扎扎文"},"short":{"az":"亞塞拜然文","en-GB":"英文（英國）","en-US":"英文（美國）"},"narrow":{}},"region":{"long":{"142":"亞洲","143":"中亞","145":"西亞","150":"歐洲","151":"東歐","154":"北歐","155":"西歐","202":"撒哈拉撒沙漠以南非洲","419":"拉丁美洲","001":"世界","002":"非洲","003":"北美洲","005":"南美洲","009":"大洋洲","011":"西非","013":"中美","014":"東非","015":"北非","017":"中非","018":"非洲南部","019":"美洲","021":"北美","029":"加勒比海","030":"東亞","034":"南亞","035":"東南亞","039":"南歐","053":"澳洲與紐西蘭","054":"美拉尼西亞","057":"密克羅尼西亞群島","061":"玻里尼西亞","AC":"阿森松島","AD":"安道爾","AE":"阿拉伯聯合大公國","AF":"阿富汗","AG":"安地卡及巴布達","AI":"安奎拉","AL":"阿爾巴尼亞","AM":"亞美尼亞","AO":"安哥拉","AQ":"南極洲","AR":"阿根廷","AS":"美屬薩摩亞","AT":"奧地利","AU":"澳洲","AW":"荷屬阿魯巴","AX":"奧蘭群島","AZ":"亞塞拜然","BA":"波士尼亞與赫塞哥維納","BB":"巴貝多","BD":"孟加拉","BE":"比利時","BF":"布吉納法索","BG":"保加利亞","BH":"巴林","BI":"蒲隆地","BJ":"貝南","BL":"聖巴瑟米","BM":"百慕達","BN":"汶萊","BO":"玻利維亞","BQ":"荷蘭加勒比區","BR":"巴西","BS":"巴哈馬","BT":"不丹","BV":"布威島","BW":"波札那","BY":"白俄羅斯","BZ":"貝里斯","CA":"加拿大","CC":"科克斯（基靈）群島","CD":"剛果（金夏沙）","CF":"中非共和國","CG":"剛果（布拉薩）","CH":"瑞士","CI":"象牙海岸","CK":"庫克群島","CL":"智利","CM":"喀麥隆","CN":"中國","CO":"哥倫比亞","CP":"克里派頓島","CR":"哥斯大黎加","CU":"古巴","CV":"維德角","CW":"庫拉索","CX":"聖誕島","CY":"賽普勒斯","CZ":"捷克","DE":"德國","DG":"迪亞哥加西亞島","DJ":"吉布地","DK":"丹麥","DM":"多米尼克","DO":"多明尼加共和國","DZ":"阿爾及利亞","EA":"休達與梅利利亞","EC":"厄瓜多","EE":"愛沙尼亞","EG":"埃及","EH":"西撒哈拉","ER":"厄利垂亞","ES":"西班牙","ET":"衣索比亞","EU":"歐盟","EZ":"歐元區","FI":"芬蘭","FJ":"斐濟","FK":"福克蘭群島","FM":"密克羅尼西亞","FO":"法羅群島","FR":"法國","GA":"加彭","GB":"英國","GD":"格瑞那達","GE":"喬治亞","GF":"法屬圭亞那","GG":"根息","GH":"迦納","GI":"直布羅陀","GL":"格陵蘭","GM":"甘比亞","GN":"幾內亞","GP":"瓜地洛普","GQ":"赤道幾內亞","GR":"希臘","GS":"南喬治亞與南三明治群島","GT":"瓜地馬拉","GU":"關島","GW":"幾內亞比索","GY":"蓋亞那","HK":"中國香港特別行政區","HM":"赫德島及麥唐納群島","HN":"宏都拉斯","HR":"克羅埃西亞","HT":"海地","HU":"匈牙利","IC":"加那利群島","ID":"印尼","IE":"愛爾蘭","IL":"以色列","IM":"曼島","IN":"印度","IO":"英屬印度洋領地","IQ":"伊拉克","IR":"伊朗","IS":"冰島","IT":"義大利","JE":"澤西島","JM":"牙買加","JO":"約旦","JP":"日本","KE":"肯亞","KG":"吉爾吉斯","KH":"柬埔寨","KI":"吉里巴斯","KM":"葛摩","KN":"聖克里斯多福及尼維斯","KP":"北韓","KR":"南韓","KW":"科威特","KY":"開曼群島","KZ":"哈薩克","LA":"寮國","LB":"黎巴嫩","LC":"聖露西亞","LI":"列支敦斯登","LK":"斯里蘭卡","LR":"賴比瑞亞","LS":"賴索托","LT":"立陶宛","LU":"盧森堡","LV":"拉脫維亞","LY":"利比亞","MA":"摩洛哥","MC":"摩納哥","MD":"摩爾多瓦","ME":"蒙特內哥羅","MF":"法屬聖馬丁","MG":"馬達加斯加","MH":"馬紹爾群島","MK":"北馬其頓","ML":"馬利","MM":"緬甸","MN":"蒙古","MO":"中國澳門特別行政區","MP":"北馬利安納群島","MQ":"馬丁尼克","MR":"茅利塔尼亞","MS":"蒙哲臘","MT":"馬爾他","MU":"模里西斯","MV":"馬爾地夫","MW":"馬拉威","MX":"墨西哥","MY":"馬來西亞","MZ":"莫三比克","NA":"納米比亞","NC":"新喀里多尼亞","NE":"尼日","NF":"諾福克島","NG":"奈及利亞","NI":"尼加拉瓜","NL":"荷蘭","NO":"挪威","NP":"尼泊爾","NR":"諾魯","NU":"紐埃島","NZ":"紐西蘭","OM":"阿曼","PA":"巴拿馬","PE":"秘魯","PF":"法屬玻里尼西亞","PG":"巴布亞紐幾內亞","PH":"菲律賓","PK":"巴基斯坦","PL":"波蘭","PM":"聖皮埃與密克隆群島","PN":"皮特肯群島","PR":"波多黎各","PS":"巴勒斯坦自治區","PT":"葡萄牙","PW":"帛琉","PY":"巴拉圭","QA":"卡達","QO":"大洋洲邊疆群島","RE":"留尼旺","RO":"羅馬尼亞","RS":"塞爾維亞","RU":"俄羅斯","RW":"盧安達","SA":"沙烏地阿拉伯","SB":"索羅門群島","SC":"塞席爾","SD":"蘇丹","SE":"瑞典","SG":"新加坡","SH":"聖赫勒拿島","SI":"斯洛維尼亞","SJ":"挪威屬斯瓦巴及尖棉","SK":"斯洛伐克","SL":"獅子山","SM":"聖馬利諾","SN":"塞內加爾","SO":"索馬利亞","SR":"蘇利南","SS":"南蘇丹","ST":"聖多美普林西比","SV":"薩爾瓦多","SX":"荷屬聖馬丁","SY":"敘利亞","SZ":"史瓦帝尼","TA":"特里斯坦達庫尼亞群島","TC":"土克斯及開科斯群島","TD":"查德","TF":"法屬南部屬地","TG":"多哥","TH":"泰國","TJ":"塔吉克","TK":"托克勞群島","TL":"東帝汶","TM":"土庫曼","TN":"突尼西亞","TO":"東加","TR":"土耳其","TT":"千里達及托巴哥","TV":"吐瓦魯","TW":"台灣","TZ":"坦尚尼亞","UA":"烏克蘭","UG":"烏干達","UM":"美國本土外小島嶼","UN":"聯合國","US":"美國","UY":"烏拉圭","UZ":"烏茲別克","VA":"梵蒂岡","VC":"聖文森及格瑞那丁","VE":"委內瑞拉","VG":"英屬維京群島","VI":"美屬維京群島","VN":"越南","VU":"萬那杜","WF":"瓦利斯群島和富圖那群島","WS":"薩摩亞","XA":"偽區域","XB":"偽比迪","XK":"科索沃","YE":"葉門","YT":"馬約特島","ZA":"南非","ZM":"尚比亞","ZW":"辛巴威","ZZ":"未知區域"},"short":{"GB":"英國","HK":"香港","MO":"澳門","PS":"巴勒斯坦","UN":"聯合國","US":"美國"},"narrow":{}},"script":{"long":{"Adlm":"富拉文","Afak":"阿法卡文字","Aghb":"高加索阿爾巴尼亞文","Ahom":"阿洪姆文","Arab":"阿拉伯文","Armi":"皇室亞美尼亞文","Armn":"亞美尼亞文","Avst":"阿維斯陀文","Bali":"峇里文","Bamu":"巴姆穆文","Bass":"巴薩文","Batk":"巴塔克文","Beng":"孟加拉文","Bhks":"梵文","Blis":"布列斯文","Bopo":"注音符號","Brah":"婆羅米文","Brai":"盲人用點字","Bugi":"布吉斯文","Buhd":"布希德文","Cakm":"查克馬文","Cans":"加拿大原住民通用字符","Cari":"卡里亞文","Cham":"占文","Cher":"柴羅基文","Cirt":"色斯文","Copt":"科普特文","Cprt":"塞浦路斯文","Cyrl":"斯拉夫文","Cyrs":"西里爾文（古教會斯拉夫文變體）","Deva":"天城文","Dogr":"Dogr","Dsrt":"德瑟雷特文","Dupl":"杜普洛伊速記","Egyd":"古埃及世俗體","Egyh":"古埃及僧侶體","Egyp":"古埃及象形文字","Elba":"愛爾巴桑文","Elym":"Elym","Ethi":"衣索比亞文","Geok":"喬治亞語系（阿索他路里和努斯克胡里文）","Geor":"喬治亞文","Glag":"格拉哥里文","Gong":"Gong","Gonm":"岡德文","Goth":"歌德文","Gran":"格蘭他文字","Grek":"希臘文","Gujr":"古吉拉特文","Guru":"古魯穆奇文","Hanb":"標上注音符號的漢字","Hang":"韓文字","Hani":"漢字","Hano":"哈努諾文","Hans":"簡體","Hant":"繁體","Hatr":"哈特拉文","Hebr":"希伯來文","Hira":"平假名","Hluw":"安那托利亞象形文字","Hmng":"楊松錄苗文","Hmnp":"Hmnp","Hrkt":"片假名或平假名","Hung":"古匈牙利文","Inds":"印度河流域（哈拉帕文）","Ital":"古意大利文","Jamo":"韓文字母","Java":"爪哇文","Jpan":"日文","Jurc":"女真文字","Kali":"克耶李文","Kana":"片假名","Khar":"卡羅須提文","Khmr":"高棉文","Khoj":"克吉奇文字","Knda":"坎那達文","Kore":"韓文","Kpel":"克培列文","Kthi":"凱提文","Lana":"藍拿文","Laoo":"寮國文","Latf":"拉丁文（尖角體活字變體）","Latg":"拉丁文（蓋爾語變體）","Latn":"拉丁文","Lepc":"雷布查文","Limb":"林佈文","Lina":"線性文字（A）","Linb":"線性文字（B）","Lisu":"栗僳文","Loma":"洛馬文","Lyci":"呂西亞語","Lydi":"里底亞語","Mahj":"印地文","Maka":"Maka","Mand":"曼底安文","Mani":"摩尼教文","Marc":"藏文","Maya":"瑪雅象形文字","Medf":"Medf","Mend":"門德文","Merc":"麥羅埃文（曲線字體）","Mero":"麥羅埃文","Mlym":"馬來亞拉姆文","Modi":"馬拉地文","Mong":"蒙古文","Moon":"蒙氏點字","Mroo":"謬文","Mtei":"曼尼普爾文","Mult":"木爾坦文","Mymr":"緬甸文","Nand":"Nand","Narb":"古北阿拉伯文","Nbat":"納巴泰文字","Newa":"Vote 尼瓦爾文","Nkgb":"納西格巴文","Nkoo":"西非書面語言 (N’Ko)","Nshu":"女書文字","Ogam":"歐甘文","Olck":"桑塔利文","Orkh":"鄂爾渾文","Orya":"歐利亞文","Osge":"歐塞奇文","Osma":"歐斯曼亞文","Palm":"帕米瑞拉文字","Pauc":"鮑欽豪文","Perm":"古彼爾姆諸文","Phag":"八思巴文","Phli":"巴列維文（碑銘體）","Phlp":"巴列維文（聖詩體）","Phlv":"巴列維文（書體）","Phnx":"腓尼基文","Plrd":"柏格理拼音符","Prti":"帕提亞文（碑銘體）","Qaag":"Qaag","Rjng":"拉讓文","Rohg":"Rohg","Roro":"朗格朗格象形文","Runr":"古北歐文字","Samr":"撒馬利亞文","Sara":"沙拉堤文","Sarb":"古南阿拉伯文","Saur":"索拉什特拉文","Sgnw":"手語書寫符號","Shaw":"簫柏納字符","Shrd":"夏拉達文","Sidd":"悉曇文字","Sind":"信德文","Sinh":"錫蘭文","Sogd":"Sogd","Sogo":"Sogo","Sora":"索朗桑朋文字","Soyo":"索永布文字","Sund":"巽他文","Sylo":"希洛弟納格里文","Syrc":"敍利亞文","Syre":"敘利亞文（福音體文字變體）","Syrj":"敘利亞文（西方文字變體）","Syrn":"敘利亞文（東方文字變體）","Tagb":"南島文","Takr":"塔卡里文字","Tale":"傣哪文","Talu":"西雙版納新傣文","Taml":"坦米爾文","Tang":"西夏文","Tavt":"傣擔文","Telu":"泰盧固文","Teng":"談格瓦文","Tfng":"提非納文","Tglg":"塔加拉文","Thaa":"塔安那文","Thai":"泰文","Tibt":"西藏文","Tirh":"邁蒂利文","Ugar":"烏加列文","Vaii":"瓦依文","Visp":"視覺語音文字","Wara":"瓦郎奇蒂文字","Wcho":"Wcho","Wole":"沃雷艾文","Xpeo":"古波斯文","Xsux":"蘇米魯亞甲文楔形文字","Yiii":"彞文","Zanb":"札那巴札爾文字","Zinh":"繼承文字（Unicode）","Zmth":"數學符號","Zsye":"表情符號","Zsym":"符號","Zxxx":"非書寫語言","Zyyy":"一般文字","Zzzz":"未知文字"},"short":{},"narrow":{}},"currency":{"long":{"ADP":"安道爾陪士特","AED":"阿拉伯聯合大公國迪爾汗","AFA":"阿富汗尼 (1927–2002)","AFN":"阿富汗尼","ALK":"阿爾巴尼亞列克 (1946–1965)","ALL":"阿爾巴尼亞列克","AMD":"亞美尼亞德拉姆","ANG":"荷屬安地列斯盾","AOA":"安哥拉寬扎","AOK":"安哥拉寬扎 (1977–1990)","AON":"安哥拉新寬扎 (1990–2000)","AOR":"安哥拉新調寬扎 (1995–1999)","ARA":"阿根廷奧斯特納爾","ARL":"阿根廷披索 (1970–1983)","ARM":"阿根廷披索 (1881–1970)","ARP":"阿根廷披索 (1983–1985)","ARS":"阿根廷披索","ATS":"奧地利先令","AUD":"澳幣","AWG":"阿路巴盾","AZM":"亞塞拜然馬納特 (1993–2006)","AZN":"亞塞拜然馬納特","BAD":"波士尼亞-赫塞哥維納第納爾","BAM":"波士尼亞-赫塞哥維納可轉換馬克","BAN":"波士尼亞-赫塞哥維納新第納爾","BBD":"巴貝多元","BDT":"孟加拉塔卡","BEC":"比利時法郎（可轉換）","BEF":"比利時法郎","BEL":"比利時法郎（金融）","BGL":"保加利亞硬列弗","BGM":"保加利亞社會黨列弗","BGN":"保加利亞新列弗","BGO":"保加利亞列弗 (1879–1952)","BHD":"巴林第納爾","BIF":"蒲隆地法郎","BMD":"百慕達幣","BND":"汶萊元","BOB":"玻利維亞諾","BOL":"玻利維亞玻利維亞諾 (1863–1963)","BOP":"玻利維亞披索","BOV":"玻利維亞幕多","BRB":"巴西克魯薩多農瓦 (1967–1986)","BRC":"巴西克魯賽羅 (1986–1989)","BRE":"巴西克魯賽羅 (1990–1993)","BRL":"巴西里拉","BRN":"巴西克如爾達農瓦","BRR":"巴西克魯賽羅 (1993–1994)","BRZ":"巴西克魯賽羅 (1942 –1967)","BSD":"巴哈馬元","BTN":"不丹那特倫","BUK":"緬甸基雅特","BWP":"波札那普拉","BYB":"白俄羅斯新盧布 (1994–1999)","BYN":"白俄羅斯盧布","BYR":"白俄羅斯盧布 (2000–2016)","BZD":"貝里斯元","CAD":"加幣","CDF":"剛果法郎","CHE":"歐元 (WIR)","CHF":"瑞士法郎","CHW":"法郎 (WIR)","CLE":"智利埃斯庫多","CLF":"卡林油達佛曼跎","CLP":"智利披索","CNH":"人民幣（離岸）","CNX":"CNX","CNY":"人民幣","COP":"哥倫比亞披索","COU":"哥倫比亞幣 (COU)","CRC":"哥斯大黎加科朗","CSD":"舊塞爾維亞第納爾","CSK":"捷克斯洛伐克硬克朗","CUC":"古巴可轉換披索","CUP":"古巴披索","CVE":"維德角埃斯庫多","CYP":"賽普勒斯鎊","CZK":"捷克克朗","DDM":"東德奧斯特馬克","DEM":"德國馬克","DJF":"吉布地法郎","DKK":"丹麥克朗","DOP":"多明尼加披索","DZD":"阿爾及利亞第納爾","ECS":"厄瓜多蘇克雷","ECV":"厄瓜多爾由里達瓦康斯坦 (UVC)","EEK":"愛沙尼亞克朗","EGP":"埃及鎊","ERN":"厄立特里亞納克法","ESA":"西班牙比塞塔（會計單位）","ESB":"西班牙比塞塔（可轉換會計單位）","ESP":"西班牙陪士特","ETB":"衣索比亞比爾","EUR":"歐元","FIM":"芬蘭馬克","FJD":"斐濟元","FKP":"福克蘭群島鎊","FRF":"法國法郎","GBP":"英鎊","GEK":"喬治亞庫旁拉里","GEL":"喬治亞拉里","GHC":"迦納賽地 (1979–2007)","GHS":"迦納塞地","GIP":"直布羅陀鎊","GMD":"甘比亞達拉西","GNF":"幾內亞法郎","GNS":"幾內亞西里","GQE":"赤道幾內亞埃奎勒","GRD":"希臘德拉克馬","GTQ":"瓜地馬拉格查爾","GWE":"葡屬幾內亞埃斯庫多","GWP":"幾內亞比索披索","GYD":"圭亞那元","HKD":"港幣","HNL":"洪都拉斯倫皮拉","HRD":"克羅埃西亞第納爾","HRK":"克羅埃西亞庫納","HTG":"海地古德","HUF":"匈牙利福林","IDR":"印尼盾","IEP":"愛爾蘭鎊","ILP":"以色列鎊","ILR":"以色列謝克爾 (1980–1985)","ILS":"以色列新謝克爾","INR":"印度盧比","IQD":"伊拉克第納爾","IRR":"伊朗里亞爾","ISJ":"冰島克朗 (1918–1981)","ISK":"冰島克朗","ITL":"義大利里拉","JMD":"牙買加元","JOD":"約旦第納爾","JPY":"日圓","KES":"肯尼亞先令","KGS":"吉爾吉斯索姆","KHR":"柬埔寨瑞爾","KMF":"科摩羅法郎","KPW":"北韓元","KRH":"南韓圜","KRO":"南韓圓","KRW":"韓元","KWD":"科威特第納爾","KYD":"開曼群島元","KZT":"哈薩克堅戈","LAK":"寮國基普","LBP":"黎巴嫩鎊","LKR":"斯里蘭卡盧比","LRD":"賴比瑞亞元","LSL":"賴索托洛蒂","LTL":"立陶宛立特","LTT":"立陶宛特羅","LUC":"盧森堡可兌換法郎","LUF":"盧森堡法郎","LUL":"盧森堡金融法郎","LVL":"拉脫維亞拉特銀幣","LVR":"拉脫維亞盧布","LYD":"利比亞第納爾","MAD":"摩洛哥迪拉姆","MAF":"摩洛哥法郎","MCF":"摩納哥法郎","MDC":"摩爾多瓦券","MDL":"摩杜雲列伊","MGA":"馬達加斯加阿里亞里","MGF":"馬達加斯加法郎","MKD":"馬其頓第納爾","MKN":"馬其頓第納爾 (1992–1993)","MLF":"馬里法郎","MMK":"緬甸元","MNT":"蒙古圖格里克","MOP":"澳門元","MRO":"茅利塔尼亞烏吉亞 (1973–2017)","MRU":"茅利塔尼亞烏吉亞","MTL":"馬爾他里拉","MTP":"馬爾他鎊","MUR":"模里西斯盧比","MVP":"馬爾地夫盧比","MVR":"馬爾地夫盧非亞","MWK":"馬拉維克瓦查","MXN":"墨西哥披索","MXP":"墨西哥銀披索 (1861–1992)","MXV":"墨西哥轉換單位 (UDI)","MYR":"馬來西亞令吉","MZE":"莫三比克埃斯庫多","MZM":"莫三比克梅蒂卡爾 (1980–2006)","MZN":"莫三比克梅蒂卡爾","NAD":"納米比亞元","NGN":"奈及利亞奈拉","NIC":"尼加拉瓜科多巴","NIO":"尼加拉瓜金科多巴","NLG":"荷蘭盾","NOK":"挪威克朗","NPR":"尼泊爾盧比","NZD":"紐西蘭幣","OMR":"阿曼里亞爾","PAB":"巴拿馬巴波亞","PEI":"祕魯因蒂","PEN":"秘魯太陽幣","PES":"秘魯太陽幣 (1863–1965)","PGK":"巴布亞紐幾內亞基那","PHP":"菲律賓披索","PKR":"巴基斯坦盧比","PLN":"波蘭茲羅提","PLZ":"波蘭茲羅提 (1950–1995)","PTE":"葡萄牙埃斯庫多","PYG":"巴拉圭瓜拉尼","QAR":"卡達里亞爾","RHD":"羅德西亞元","ROL":"舊羅馬尼亞列伊","RON":"羅馬尼亞列伊","RSD":"塞爾維亞戴納","RUB":"俄羅斯盧布","RUR":"俄羅斯盧布 (1991–1998)","RWF":"盧安達法郎","SAR":"沙烏地里亞爾","SBD":"索羅門群島元","SCR":"塞席爾盧比","SDD":"蘇丹第納爾","SDG":"蘇丹鎊","SDP":"舊蘇丹鎊","SEK":"瑞典克朗","SGD":"新加坡幣","SHP":"聖赫勒拿鎊","SIT":"斯洛維尼亞托勒","SKK":"斯洛伐克克朗","SLL":"獅子山利昂","SOS":"索馬利亞先令","SRD":"蘇利南元","SRG":"蘇利南基爾","SSP":"南蘇丹鎊","STD":"聖多美島和普林西比島多布拉 (1977–2017)","STN":"聖多美島和普林西比島多布拉","SUR":"蘇聯盧布","SVC":"薩爾瓦多科郎","SYP":"敘利亞鎊","SZL":"史瓦濟蘭里朗吉尼","THB":"泰銖","TJR":"塔吉克盧布","TJS":"塔吉克索莫尼","TMM":"土庫曼馬納特 (1993–2009)","TMT":"土庫曼馬納特","TND":"突尼西亞第納爾","TOP":"東加潘加","TPE":"帝汶埃斯庫多","TRL":"土耳其里拉","TRY":"新土耳其里拉","TTD":"千里達及托巴哥元","TWD":"新台幣","TZS":"坦尚尼亞先令","UAH":"烏克蘭格里夫納","UAK":"烏克蘭卡本瓦那茲","UGS":"烏干達先令 (1966–1987)","UGX":"烏干達先令","USD":"美元","USN":"美元（次日）","USS":"美元（當日）","UYI":"烏拉圭披索（指數單位）","UYP":"烏拉圭披索 (1975–1993)","UYU":"烏拉圭披索","UYW":"UYW","UZS":"烏茲別克索姆","VEB":"委內瑞拉玻利瓦 (1871–2008)","VEF":"委內瑞拉玻利瓦 (2008–2018)","VES":"委內瑞拉玻利瓦","VND":"越南盾","VNN":"越南盾 (1978–1985)","VUV":"萬那杜瓦圖","WST":"西薩摩亞塔拉","XAF":"法郎 (CFA–BEAC)","XAG":"白銀","XAU":"黃金","XBA":"歐洲綜合單位","XBB":"歐洲貨幣單位 (XBB)","XBC":"歐洲會計單位 (XBC)","XBD":"歐洲會計單位 (XBD)","XCD":"格瑞那達元","XDR":"特殊提款權","XEU":"歐洲貨幣單位 (XEU)","XFO":"法國金法郎","XFU":"法國法郎 (UIC)","XOF":"法郎 (CFA–BCEAO)","XPD":"帕拉狄昂","XPF":"法郎 (CFP)","XPT":"白金","XRE":"RINET 基金","XSU":"蘇克雷貨幣","XTS":"測試用貨幣代碼","XUA":"亞洲開發銀行計價單位","XXX":"未知貨幣","YDD":"葉門第納爾","YER":"葉門里亞爾","YUD":"南斯拉夫第納爾硬幣","YUM":"南斯拉夫挪威亞第納爾","YUN":"南斯拉夫可轉換第納爾","YUR":"南斯拉夫改革第納爾 (1992–1993)","ZAL":"南非蘭特（金融）","ZAR":"南非蘭特","ZMK":"尚比亞克瓦查 (1968–2012)","ZMW":"尚比亞克瓦查","ZRN":"薩伊新扎伊爾","ZRZ":"薩伊扎伊爾","ZWD":"辛巴威元 (1980–2008)","ZWL":"辛巴威元 (2009)","ZWR":"辛巴威元 (2008)"},"short":{},"narrow":{}}}}},"availableLocales":["zh-Hant"],"aliases":{"zh-CN":"zh-Hans-CN","zh-guoyu":"zh","zh-hakka":"hak","zh-HK":"zh-Hant-HK","zh-min-nan":"nan","zh-MO":"zh-Hant-MO","zh-SG":"zh-Hans-SG","zh-TW":"zh-Hant-TW","zh-xiang":"hsn","zh-min":"nan-x-zh-min"},"parentLocales":{"zh-Hant-MO":"zh-Hant-HK"}},
    {"data":{},"availableLocales":["zh-Hans"],"aliases":{"zh-CN":"zh-Hans-CN","zh-guoyu":"zh","zh-hakka":"hak","zh-HK":"zh-Hant-HK","zh-min-nan":"nan","zh-MO":"zh-Hant-MO","zh-SG":"zh-Hans-SG","zh-TW":"zh-Hant-TW","zh-xiang":"hsn","zh-min":"nan-x-zh-min"},"parentLocales":{"zh-Hant-MO":"zh-Hant-HK"}});
    }

})));
//# sourceMappingURL=polyfill-with-locales-for-test262.js.map
